## PageHelper分页插件错误分页问题 

一、引言

在Java项目中，PageHelper分页插件是一个常用的分页查询工具。然而，在使用过程中，偶尔会出现一些SQL语句莫名分页的问题。本文将针对这一问题进行深入分析，并提供相应的解决方案。

二、问题分析

1. PageHelper插件的工作原理

PageHelper插件是通过ThreadLocal实现分页功能的。在每次请求处理过程中，PageHelper会在ThreadLocal中设置分页参数，并在后续的SQL查询中自动应用这些参数。然而，当请求处理完毕后，线程会被返回到线程池中，导致ThreadLocal中的数据残留，从而影响到下一个请求的分页查询。

1. 问题产生的原因

问题产生的原因主要有两个方面：一是在使用PageHelper插件时，没有正确地调用PageHelper.startPage方法，导致分页参数设置不当；二是在项目配置中，开启了supportMethodsArguments属性，导致PageHelper插件会自动分析传入的对象，从而可能产生不必要的分页操作。

三、解决方案

针对上述问题，我们提出以下解决方案：

1. 确保每次使用PageHelper插件时，都严格按照以下顺序进行操作：先调用PageHelper.startPage方法设置分页参数，然后再执行具体的查询操作。这样可以确保分页参数的正确性，并避免出现垃圾数据影响新的请求的情况。
2. 在项目配置中，将supportMethodsArguments属性设置为false，以关闭PageHelper插件的自动分析功能。这样可以避免PageHelper插件对传入对象进行不必要的分析，从而减少不必要的分页操作。
3. 对于继承自BaseReqEntity的查询类，需要确保在调用PageHelper.startPage方法之前，将不需要分页的查询类中的分页参数设置为null或默认值，以避免出现不需要分页而分了页的情况。

四、结论

PageHelper分页插件是一个强大的分页查询工具，但在使用过程中需要注意一些问题。通过本文的分析和解决方案，我们可以更好地理解和使用PageHelper插件，避免出现不必要的分页问题，提高项目的稳定性和性能。

http://192.168.1.14:5000/d/f/xLh1un6zvUith2gtFjkaHueWpLXX7arR



## Spring事务方法调用不当

“Spring事务方法调用不当”是一个在Spring框架开发中常见的问题，它涉及到Spring的事务管理。当开发者在使用Spring的事务管理功能时，如果没有正确地调用事务方法，就可能导致事务无法正确生效，从而引发一系列问题。

在Spring中，通常使用`@Transactional`注解来声明一个方法是事务性的。然而，如果在同一个类中，一个非事务方法（没有`@Transactional`注解的方法）调用了另一个有`@Transactional`注解的事务方法，那么这个事务方法的事务性将不会被触发。这是因为Spring的AOP（面向切面编程）代理机制默认只在类的外部起作用，对于同一个类内部的调用，代理机制不会生效。

下面是一个简单的问题代码示例：

```java
@Service  
public class MyService {  
  
    @Transactional  
    public void transactionalMethod() {  
        // ... 事务性操作  
    }  
  
    public void nonTransactionalMethod() {  
        // ... 非事务性操作  
        transactionalMethod(); // 这里调用事务方法，但事务不会生效  
    }  
}
```

在这个示例中，`nonTransactionalMethod`方法内部调用了`transactionalMethod`方法，但由于它们都在同一个类中，`transactionalMethod`的事务性将不会被触发。

1. **避免在同一个类中调用事务方法**：尽量将需要事务管理的方法调用放在不同的类中，以确保代理机制能够生效。
2. **使用`AopContext.currentProxy()`获取代理对象**：如果确实需要在同一个类中调用事务方法，可以通过`AopContext.currentProxy()`获取当前类的代理对象，然后使用该代理对象来调用事务方法。但这种方法不推荐使用，因为它破坏了封装性，并可能导致代码难以维护。
3. **重新设计代码结构**：考虑重新设计代码结构，将需要事务管理的逻辑拆分到不同的类中，以符合Spring的事务管理规则。

Spring的事务管理功能非常强大，但也需要开发者正确使用。在设计和编写代码时，应充分考虑事务管理的需求，避免不当的调用方式，以确保事务能够正确生效。

http://192.168.1.14:5000/d/f/xLh1w6R4h8sRkvfZC2uLMZuOUAYc6QF6



## 被除数为0问题

被除数为0的问题是一个常见的编程错误，通常出现在使用除法运算时。在大多数编程语言中，除以0是未定义的行为，会导致程序抛出异常或错误。

具体来说，当被除数为0时，除数无法将其分割成等份，因此无法进行除法运算。这种情况下，程序会抛出`java.lang.ArithmeticException: / by zero`异常，表示发生了除以0的错误。

为了避免这种错误，程序员应该在进行除法运算之前，先判断被除数是否为0。如果被除数为0，则应该采取相应的处理措施，例如抛出异常、返回默认值或者进行其他逻辑处理。这样可以确保程序的稳定性和正确性。

在处理被除数为0的问题时，还需要注意一些特殊情况。例如，在处理浮点数除法时，如果除数为0，结果应该是正无穷大或负无穷大，而不是抛出异常。此外，在处理整数除法时，如果除数为0，结果应该是整数溢出，而不是抛出异常。

总之，被除数为0的问题是编程中需要特别注意的一个问题。程序员应该在进行除法运算之前，先判断被除数是否为0，并采取相应的处理措施，以确保程序的正确性和稳定性。

http://192.168.1.14:5000/d/f/xLh200Q75g1n8PALcumb0Xq7s2SNuiQz



## 多线程流程提交设置公用参数导致流程提交错乱问题

多线程流程提交设置公用参数导致流程提交错乱问题是一个在多线程编程中常见的问题。这个问题主要发生在多个线程同时访问和修改共享资源时，如果没有采取适当的同步措施，就可能导致数据混乱和流程提交错乱。

在多线程环境中，如果多个线程同时执行并调用公共方法或使用全局变量来设置流程参数，可能会引发参数混乱的问题。每个线程都有自己的执行顺序和上下文，如果它们在没有同步的情况下访问和修改全局变量，那么这些变量可能会被不同的线程随意修改，从而导致流程的提交顺序和参数设置出现混乱。

下面是一个简单的示例代码，展示了可能导致多线程流程提交错乱的情况：

```java
public class PlanFlowServiceImpl implements PlanFlowService {  
    // 全局变量，用于存储流程参数  
    private static HashMap<String, Object> postMap = new HashMap<>();  
  
    // 计划提报流程提交方法  
    private void submitPlanSubProc(String planId) {  
        // 设置流程参数  
        postMap.put("procInstId", "某个流程实例ID");  
        postMap.put("planId", planId);  
  
        // 提交流程  
        submitFlow(postMap);  
    }  
  
    // 提交流程方法  
    private void submitFlow(HashMap<String, Object> params) {  
        // 省略流程提交的具体实现  
    }  
  
    // 在多线程环境中调用 submitPlanSubProc 方法  
    public void executeSubmitInParallel(List<String> planIds) {  
        for (String planId : planIds) {  
            new Thread(() -> submitPlanSubProc(planId)).start();  
        }  
    }  
}
```



在上述代码中，`submitPlanSubProc` 方法被多个线程同时调用，并且它们都使用同一个全局变量 `postMap` 来存储流程参数。由于缺少同步措施，不同线程可能同时访问和修改 `postMap`，导致参数混乱和流程提交错乱。

为了解决这个问题，可以采取以下几种解决方案：

1. **使用局部变量**：避免使用全局变量，每个线程使用自己的局部变量来存储流程参数。这样可以确保每个线程独立处理自己的业务逻辑，不会互相干扰。
2. **线程同步**：如果必须使用全局变量或共享资源，可以使用线程同步机制来确保同一时间只有一个线程能够访问和修改这些资源。例如，可以使用 `synchronized` 关键字来同步代码块，或者使用 `Lock` 接口及其实现类来实现更灵活的同步控制。
3. **使用线程安全的集合类**：如果需要在多个线程之间共享集合类数据，可以使用线程安全的集合类，如 `ConcurrentHashMap`、`CopyOnWriteArrayList` 等。这些集合类内部实现了适当的同步机制，可以确保多线程环境下的数据安全。
4. **避免过度同步**：虽然同步可以控制线程间的访问冲突，但过度同步也可能导致性能下降和死锁等问题。因此，在设计多线程程序时，应该尽量减少同步的范围和持续时间，只在必要时进行同步。

多线程流程提交设置公用参数导致流程提交错乱问题是一个常见的多线程编程问题。解决这个问题的关键在于正确地使用局部变量、线程同步和线程安全的集合类等机制来确保多线程环境下的数据安全和流程正确性。在实际开发中，应该根据具体情况选择合适的解决方案，并避免过度同步和性能下降等问题。

http://192.168.1.14:5000/d/f/xLh1whTjAek4mMXPUF3VWCkNWMjtwBpW



## 关于BigDecimal丢失精度问题

在Java应用中，BigDecimal常用于精确计算，但使用不当可能导致精度丢失。例如，如果直接将BigDecimal对象相加，结果可能不精确。为避免此问题，建议使用BigDecimal的add方法进行计算，并考虑使用ROUND_HALF_UP等舍入模式来确保精度。此外，创建BigDecimal对象时，应使用字符串或数值类型的参数，避免因自动类型转换导致精度损失。正确使用BigDecimal，能确保金融和其他需要高精度计算的领域中的准确性。

http://192.168.1.14:5000/d/f/xLh1xWZWaLnJoAtxtKED4XscZfCBKlKU



## 关于switch case的使用

在Java的switch语句中，每个case分支都需要通过break、return等语句来终止，否则会继续执行后续的case分支，直到遇到break或switch块结束。此外，建议在switch块内包含一个default语句，并将其放在最后，以便处理一些异常值或未匹配的情况。如果忽略了break语句，可能会导致程序逻辑错误或不可预测的行为。为了避免这种情况，应该仔细检查每个case分支，确保它们都正确地终止了。同时，default语句可以用来处理一些特殊的异常情况或未知的值，提供更好的错误处理机制。在编写代码时，应该遵循这些规则和最佳实践，以确保代码的正确性和可维护性。通过正确的使用switch语句，可以提高代码的可读性和可维护性，并减少潜在的错误和缺陷。

http://192.168.1.14:5000/d/f/xLh1zJqHZvauW3KunVNYAAqlCq9ycMky



## 空指针问题 

代码中存在空指针风险，可能导致NullPointerException。问题在于未对对象是否为null进行判断，直接调用了对象的方法或属性。为避免此问题，建议在使用对象前进行null检查，特别是方法参数、返回值和成员变量。当比较方法返回值与常量时，应将常量放在前面以避免调用null对象的equals方法。此外，遵循java变量使用准则，确保局部变量在使用前已声明和初始化，而类成员变量会有默认值（如未初始化）。通过这些措施，可有效预防空指针异常，提高代码的健壮性。

http://192.168.1.14:5000/d/f/xLh20lOj7ZJBoObEl2x2M6FGsgM7SmMK



## 魔术值问题

Java代码中存在未定义的常量，导致代码可读性差，易出现遗漏和BUG。针对此问题，可以使用常量替代字符串，以提高代码可读性和减少出错。例如，将"ApproverID"替换为final static String KEY_APPROVE_ID = "ApproverID";，并在需要的地方使用该常量。这样可以避免硬编码和重复的字符串，使代码更加简洁和易于维护。通过定义常量，还可以在需要修改字符串时，只需修改一处即可。因此，使用常量是解决这类问题的有效方法。

http://192.168.1.14:5000/d/f/xLh1vWfcIvevYFpu3tx0excsskibo540



## 文件流、端口、连接等没有关闭

一、问题描述

在使用文件流、端口、连接等资源时，如果没有及时关闭，可能会导致资源泄漏。长时间下来，这种资源泄漏可能会耗尽系统资源，从而导致应用程序出现性能问题，甚至崩溃。在Java、C++等语言中，这种问题尤为常见。

二、影响

1. 内存泄漏：如果文件流、连接等对象在使用后未关闭，它们将一直占用内存空间，导致内存泄漏。当内存泄漏达到一定程度时，可能会引发OutOfMemoryError，导致应用程序崩溃。
2. 端口耗尽：如果服务器应用程序没有正确关闭已使用的端口，那么随着时间的推移，可用的端口资源可能会被耗尽。这将导致新的连接无法建立，从而影响服务的正常运行。
3. 系统性能下降：资源泄漏可能导致系统性能下降。大量的未关闭资源会占用系统资源，降低系统的整体性能。

三、解决方案

1. 使用try-with-resources语句（Java）：在Java中，可以使用try-with-resources语句来自动关闭实现了AutoCloseable接口的资源。这可以确保在try块结束时，资源会被自动关闭，从而避免资源泄漏。

```java
try (InputStream fis = new BufferedInputStream(new FileInputStream(fileUrl))) {  
    // 使用文件流进行操作  
} catch (Exception e) {  
    // 处理异常  
}
```

1. 手动关闭资源：对于没有实现AutoCloseable接口的资源，需要在finally块中手动关闭。例如，在C++中，需要使用delete来释放动态分配的内存；在Java中，需要调用close()方法来关闭文件流、连接等。

```java
InputStream fis = null;  
try {  
    fis = new BufferedInputStream(new FileInputStream(fileUrl));  
    // 使用文件流进行操作  
} catch (Exception e) {  
    // 处理异常  
} finally {  
    if (fis != null) {  
        try {  
            fis.close();  
        } catch (IOException e) {  
            // 处理关闭资源时的异常  
        }  
    }  
}
```

1. 使用连接池：对于数据库连接、网络连接等资源，可以使用连接池来管理。连接池可以复用已经创建的连接，减少创建和关闭连接的次数，从而降低资源泄漏的风险。
2. 定期检查并关闭空闲连接：对于服务器应用程序，可以定期检查并关闭空闲的连接，以释放占用的端口资源。

四、总结

资源泄漏是一个常见的问题，可能导致应用程序性能下降、崩溃等问题。为了避免资源泄漏，开发者应该在使用完资源后及时关闭它们，并采用适当的策略来管理资源。通过合理的资源管理和错误处理，可以确保应用程序的稳定性和性能。

http://192.168.1.14:5000/d/f/xLh1u7fYvzHGLNZUFAop8VGGPK6IoPqR



## 在事务里面进行线程异步调用的问题

该问题描述了CRM系统中保存订单的服务方法中线程异步调用的问题。在事务中保存订单后，通过异步线程处理订单缺货问题，但有时因为事务未提交导致该线程查询不到订单信息。代码示例中，使用@Transactional注解开启事务，然后在方法最后使用异步线程处理订单缺货问题。但当保存订单的事务还未提交时，异步线程查询订单信息可能会失败。建议在事务提交后再进行异步处理，或使用数据库连接池等技术优化数据库查询。该段代码主要实现保存订单的功能，包括订单的保存和后续操作。首先，通过调用`selfOrderErpService.saveOrder()`方法保存订单，并根据参数`lower`决定是否发送缺货通知。然后，通过创建两个异步线程执行后续操作：一是检验订单明细是否足够，二是进行后续操作。为了保证数据的一致性，将异步线程与事务方法区分开来，并确保保存数据的事务已经提交。通过这种方式，可以避免因异步操作导致的数据不一致问题。

http://192.168.1.14:5000/d/f/xLh1y6KyyYyoBT7Y7qbiFC8sndazBzbL



## Count统计数量不准确问题

"Count统计数量不准确问题" 是在使用SQL语句进行数据库查询时常见的一个问题。当你尝试使用`COUNT`函数来统计数据库中的行数或特定列的非NULL值时，可能会因为各种原因得到不准确的结果。

http://192.168.1.14:5000/d/f/xLh1rfWZD568VcPfsX47fzgSRzqwe3Ey



## sql查询导致磁盘空间不足

SQL查询导致磁盘空间不足的问题通常是由于查询处理过程中产生了大量的临时数据，这些数据需要存储在磁盘上，如果磁盘空间不足，就会导致这个问题。

http://192.168.1.14:5000/d/f/xLh1srbsA0aNlChEnVpyO23FKp1rbvvH



## PC端打开浏览器的移动端模式van-search的清除按钮无效问题

一、问题描述

在PC端打开浏览器，并将浏览器模式调整为移动端模式后，使用van-search组件时发现清除按钮无效。具体表现为：在输入框内输入内容后，点击清除按钮，但输入的内容并没有被清空。

二、原因分析

官方解释是：Vant是一个面向移动端的组件库，因此默认只适配了移动端设备。这意味着组件只监听了移动端的touch事件，而没有监听桌面端的mouse事件。所以，在移动端设备上使用van-search的清除功能是正常的，但在PC端打开浏览器的移动端模式下，由于使用的是mouse事件而非touch事件，导致清除按钮无效。

三、解决方案

为了解决这个问题，我们可以在PC端引入@vant/touch-emulator库。这个库会自动将桌面端的mouse事件转换成对应的touch事件，从而使得Vant组件在桌面端也能正常工作。

具体操作步骤如下：

1. 安装@vant/touch-emulator模块：通过npm或yarn安装@vant/touch-emulator模块。例如，使用npm安装可以在命令行中执行`npm i @vant/touch-emulator -S`命令。
2. 引入@vant/touch-emulator：在需要使用van-search组件的页面中，引入@vant/touch-emulator。可以通过在页面的<script>标签中添加`import 'vant/lib/index.css'; import Touch from '@vant/touch-emulator'; Touch.init();`代码来实现。
3. 确保在引入Vant组件之前引入@vant/touch-emulator：为了确保@vant/touch-emulator能够正确生效，需要确保在引入Vant组件之前引入@vant/touch-emulator。

通过以上步骤，就可以在PC端打开浏览器的移动端模式下使用van-search组件的清除按钮功能了。

需要注意的是，如果项目中没有适配PC端的需求，那么完全可以不用处理这个问题。因为这个问题只会在PC端打开浏览器的移动端模式下出现，在正常的移动端设备上使用是不会出现这个问题的。

http://192.168.1.14:5000/d/f/xLh24Wrnc0UPXBGiqBJ4bnnsUl42u808



## 调用微信js-sdk的wx.getLocalImgData问题

在调用微信JS-SDK的`wx.getLocalImgData`方法时，可能会遇到一些问题。`wx.getLocalImgData`是用于获取本地图片的数据的API，可以将选择的图片转换为Base64编码，以便在网页中使用。

http://192.168.1.14:5000/d/f/xLh22VghFILGQhSIQnqg1YL2K7vJ3TuD



## 使用v-if导致页面组件卡死问题

在使用Vue.js框架开发时，有时会遇到使用v-if指令导致页面组件卡死的问题。具体表现为，当v-if控制的组件或元素在条件切换时，页面会出现卡顿或无法响应的现象。

v-if是Vue.js中的一个条件渲染指令，它根据表达式的值的真假来决定是否渲染一个元素或组件。当v-if的值为false时，Vue.js会从DOM中移除该元素或组件；当v-if的值为true时，Vue.js会将该元素或组件添加到DOM中。这种频繁的DOM操作可能会导致页面性能下降，尤其是在处理大量数据或复杂组件时。

此外，如果在使用v-if的同时，还有其他的JavaScript代码在操作这些被v-if控制的元素或组件，就可能会出现报错或异常，从而导致页面卡死。

http://192.168.1.14:5000/d/f/xLh23I5IvNLuSW5sN2CL3erK0MjC6Yp7



## 在js直接使用store容器拿不到对象

无法直接在JavaScript中使用store容器获取对象可能是由于异步操作、作用域问题或Vuex Store配置问题导致的。你可以通过使用计算属性、`watch`选项、确保正确的作用域绑定和检查Vuex Store配置来解决这些问题。

http://192.168.1.14:5000/d/f/xLh23qQlfHIobIw8Wv8ULnTq1tUCxB9G



## SQL注入

SQL注入是一种常见的攻击方式。攻击者通过在表单或URL中输入特定SQL片段，可能入侵参数验证不足的应用程序。问题代码中，前端传入的值可能导致恶意SQL语句执行，如删除表操作。处理建议是将定义变量的符号替换为#，因为#会将传入数据视为字符串并添加双引号，而则直接将数据嵌入SQL中。使用#可以避免SQL注入攻击。此外，建议使用预编译的SQL语句并使用参数化查询，以提高安全性。

http://192.168.1.14:5000/d/f/xLh1tbAUXUP4eHNkfTWxpCYXOpHTTaE4



## HTML

http://192.168.1.14:5000/d/f/xLh1qsqMOuGi8x6dMYL1kgHUp57TjaNF



## 容器服务平台-操作手册

这是一个关于容器服务平台操作手册的更新记录，详细记录了对应用部署、集成和应用查看等功能的具体更新。在创建应用方面，增加了应用的基本信息、源码信息和部署配置等。在应用集成方面，增加了接口管理功能。在应用查看方面，增加了构建日志查看和运行实例查看等功能。此外，还对一些名词术语进行了定义和解释，如应用、容器、平台等。整个操作手册旨在指导开发人员如何在平台上完成基于微服务理念开发的应用部署、集成工作。通过这个平台，开发人员可以更加方便地管理和监控自己的应用，提高开发效率和应用的稳定性。

http://192.168.1.14:5000/d/f/xLh32KGfe3wrbI3WMpixFRbsYbvY1LWp



## 搭建与使用遥测系统

这是一个关于容器服务平台-操作手册的介绍，其中包括了遥测系统的部署和使用的相关内容。通过docker-compose文件启动应用，其中包括了遥测数据采集、踪迹存储、日志存储、指标存储和可视化等组件。各个组件的容器镜像、容器名称、网络配置、卷挂载、重启策略等都有详细的说明。此外，还提供了关于Grafana配置和运行的详细参考指南，包括如何将Grafana部署在反向代理后面等。整个部署使用了Docker Compose进行编排和管理，使得各个组件能够协同工作，形成一个完整的遥测系统。通过这个容器服务平台，用户可以轻松地部署和管理遥测系统，提高系统的可靠性和可维护性。

http://192.168.1.14:5000/d/f/xLh31Jov1mXI5crwzi8GRH5Au6bgvvOi



## Anyshare Family 7 安装手册

该文主要介绍了平台的软件模块、安装过程、配置要求以及参考资料。安装过程涉及安装环境依赖、Anyshare Server模块、创建Kubernetes集群、激活系统、配置Eceph对象存储和部署服务等。配置要求未提及。参考资料包括Helm指南和Kubernetes指南等。

http://192.168.1.14:5000/d/f/xLh2rmPfV04wfTrhwB3IH0x8g9GaPjQS



## API测试平台Metersphere2.2版本地化部署手册（WIN10环境）

本文档旨在为用户提供MeterSphere 2.2版本在Windows 10环境下的本地化部署指南。MeterSphere是一款开源的、可持续集成/持续部署（CI/CD）的API测试平台，支持接口测试、性能测试、UI测试等多种测试类型。本手册将详细介绍如何在Windows 10环境下进行MeterSphere 2.2版本的部署。

http://192.168.1.14:5000/d/f/xLh2zj2Vl8Zv154wHfsWhsZKiZx8x6AZ



## dubbo框架分析

Dubbo是一个分布式服务框架，旨在提供高性能和透明化的RPC远程服务调用方案，以及SOA服务治理方案。它是为解决分布式系统中的服务调用问题而设计的，通过RPC协议实现跨进程通信。随着业务复杂性的增加，垂直架构无法满足需求，Dubbo作为RPC框架应运而生，将核心业务抽取出来作为独立的服务，提高业务复用和整合。此外，Dubbo还提供了丰富的能力支持、协议兼容性、模型定义和调用性能等方面的优势。然而，Dubbo也存在一些不足之处，如服务治理的复杂性、超时控制机制的缺失和对非Java语言的支持有限等。尽管如此，Dubbo仍然是一个功能强大的分布式服务框架，适用于大规模分布式系统的服务治理和调用。在选择分布式服务框架时，需要根据实际需求进行综合考虑，以选择最适合自己的框架。

http://192.168.1.14:5000/d/f/xLh2xescWlE9iqVIvMGGf5GpQz74wyji



## GS1-128条码规范GB_T 15425-2014研读和最小条码长度算法

GS1-128条码规范GB/T 15425-2014，无标签，最小条码长度算法需研读。

http://192.168.1.14:5000/d/f/xLh2yN1FFs9hFTvbbp2A6z2ZeNNkivZj



## Java面试题库

http://192.168.1.14:5000/d/f/xLh2iFQof4DtjTCL3E0eh731XDFcFDCc



## Kali Linux使用教程



http://192.168.1.14:5000/d/f/xLh2v164SrljAIIemAKh6oVhYsvIAvBN



## kibana日志查看-操作手册v0.2

Kibana是一个为Logstash和ElasticSearch提供的日志分析的Web接口。使用Kibana，您可以对日志进行高效的搜索、可视化、分析等各种操作。

http://192.168.1.14:5000/d/f/xLh2kJjVSjE3hrB32f8mzymtArQ0biaF



## langchain-chatchat[知识库]大模型私有化部署手册（win10环境）

该手册提供了在Windows 10环境下部署大模型的完整步骤，涵盖了服务器部署和大模型部署两个部分。在服务器部署部分，详细介绍了安装conda和显卡相关依赖的步骤，如CUDA Toolkit和cuDNN的安装。在大模型部署部分，他给出了创建和激活虚拟机、安装PyTorch CUDA以及后续步骤，如安装GCC、下载离线模型、更新配置文件、初始化数据库等。此外，还提供了其他参考信息和界面效果。这些步骤详细且具有指导性，能够帮助用户顺利完成大模型的部署。

http://192.168.1.14:5000/d/f/xLh2tZOpMJ886pPLq47azjuuRZ09hlNf



## OnlyOffice安装手册 

该文章提供了安装OnlyOffice的详细步骤，包括安装前的准备工作、运行onlyoffice镜像、访问特定网址、检测是否正常、添加到自启动以及获取token等步骤。其中，安装前的准备工作包括创建OnlyOffice社区服务器数据和日志、文档数据和日志以及控制面板数据和日志。在运行onlyoffice镜像时，需要使用sudo docker命令并指定相关参数，如端口映射和卷挂载。在访问特定网址后，需要执行一系列命令来检测OnlyOffice是否正常工作。最后，将OnlyOffice添加到自启动中并获取token以便进行官方集成。整个安装过程需要使用sudo命令来获取管理员权限，并注意在各个步骤中输入正确的命令和参数。	

http://192.168.1.14:5000/d/f/xLh2liJA8Zlm1xXPsrCghosVWFZHHXcW



## OpenAPI接口文档Redoc使用手册

Redoc是一个接口文档UI工具，能够将Swagger工具生成的json格式接口文档进行良好展示。通过SpringBoot应用获取swagger.json接口地址，在前端工程中创建redoc.html文件，并添加路由，部署后即可查看redoc文档效果。参考资料包括Github和在线调试地址。使用Redoc可以方便地查看和管理接口文档，提高开发效率。

http://192.168.1.14:5000/d/f/xLh2jREWUGwMR1C5aYKhAsxmeclKjmgJ



## spring cloud

Spring Cloud 是微服务架构的翘楚，它通过抽象出一套通用的开发模式，让开发者能更快更好地开发业务。其核心组件包括服务注册与发现、配置中心、客户端代理、负载均衡、熔断降级限流、网关、链路追踪等。其中，Spring Cloud Netflix 是由 Netflix 公司提供的一套成熟方案，包括 Ribbon、Feign、Eureka、Hystrix 等组件。而 Spring Cloud Alibaba 是由 Alibaba 公司提供的新晋方案，包括 Nacos、Sentinel、Dubbo、Seata 等开源套件。这些组件都为微服务架构提供了强大的支持，如服务治理、负载均衡、容错管理、外部化配置等。通过这些组件，我们可以构建稳定、高效的微服务应用。Spring Cloud 是一个非常优秀的微服务架构解决方案，它提供了丰富的组件和规范，使得开发者能够更加高效地开发业务。同时，Spring Cloud 的生态圈也非常活跃，不断有新的技术和组件涌现，为微服务架构的发展提供了强大的支持。

http://192.168.1.14:5000/d/f/xLh2wUM6mlLY93pWJa1ibJ1jEGEpJ2ka



## Vue面试题库



http://192.168.1.14:5000/d/f/xLh2vnUg8wzo7fXVZA9VA9EFhkLOZTsN



## windows环境安装zabbix客户端

1. 下载Zabbix客户端

首先，需要从Zabbix官方网站上下载最新版本的Zabbix Agent。在下载页面中，选择适合Windows系统的版本，例如Zabbix Agent 5.2 for Windows。下载完成后，解压缩文件，得到Zabbix Agent的安装程序。

1. 安装Zabbix客户端

双击Zabbix Agent的安装程序，开始安装过程。在安装过程中，需要按照提示进行操作，例如选择安装路径、设置服务名称等。在安装过程中，还需要输入Zabbix Server的地址和端口号，以便Agent能够与Server进行通信。

1. 配置Zabbix客户端

安装完成后，需要对Zabbix Agent进行配置。可以通过编辑Zabbix Agent的配置文件来实现。配置文件通常位于Zabbix Agent的安装目录下的“conf”文件夹中，文件名为“zabbix_agentd.conf”。在配置文件中，可以设置Agent的名称、Server的地址和端口号、HostMetadata等参数。

1. 启动Zabbix客户端服务

配置完成后，需要启动Zabbix Agent服务。可以通过Windows服务管理器来启动服务，也可以在命令行中输入相应的命令来启动服务。启动服务后，可以通过任务管理器查看Zabbix Agent服务的状态，确保服务正常运行。

1. 测试Zabbix客户端连接

最后，需要测试Zabbix Agent是否能够与Zabbix Server正常通信。可以通过在Zabbix Server上运行Zabbix Get命令来测试连接。如果能够成功获取到Agent的数据，则说明连接正常。

http://192.168.1.14:5000/d/f/xLh2kxBkXm1DZp8Qelg0pmkPBSe2fLcb



## workflow应用162部署手册

在199服务器上，将六个工程应用部署模块放置在homeworkflow-deploy-199helm目录中，并按照卸载原有Workflow、上传安装包、安装、解压、进入目录、编辑文件、获取SVCIP、调用API重新初始化服务的顺序进行操作。

http://192.168.1.14:5000/d/f/xLh2nthpBaRXZrR1U03Ukqlq8KlMFSQB



## workflow应用171部署手册

**1. 下载与准备**

- 第一步：从指定的URL或文件存储位置下载Workflow应用171的部署压缩包。
- 第二步：确保你有足够的权限和必要的工具来执行接下来的部署步骤。

**2. 上传到服务器**

- 第三步：将下载的压缩包上传到目标服务器（例如171服务器）。这可以通过FTP、SCP或其他文件传输工具完成。

**3. 卸载旧版本（如有）**

- 第四步：如果服务器上已有旧版本的Workflow应用，需要先执行卸载命令以释放资源和避免冲突。

**4. 配置服务通信**

- 第五步：修改或创建配置文件（如`applicationcommunication.conf`），确保服务之间的通信设置正确。

**5. 安装与部署**

- 第六步：进入部署目录，并执行安装命令以安装Workflow应用171。
- 第七步：执行部署命令，等待应用实例启动并检查其状态。确保所有实例都已成功启动并正在运行。

**6. 验证与测试**

- 第八步：一旦应用部署完成，进行必要的验证和测试以确保应用按预期工作。这可能包括功能测试、性能测试等。

**7. 监控与维护**

- 第九步：设置监控工具以监控应用的运行状态和性能。确保有适当的警报和通知机制，以便在出现问题时及时响应。

**8. 文档与备份**

- 第十步：记录整个部署过程和相关配置，以便将来参考和恢复。同时，定期备份重要数据和配置文件。

http://192.168.1.14:5000/d/f/xLh2odGRZ1Ie2l8TULrK0d6BuNbN05kE



## workflow应用200部署手册

在部署流程中，首先需要构建四个应用的docker镜像，并上传至公司仓库。然后，登录200服务器，切换到相应目录，并执行脚本拉取镜像。接着，进行helm chart的打包操作。最后，在指定目录下建立workflow-service目录，并将镜像文件和chart包移至相应文件夹中，完成整体打包。如果是重新部署，需要配置docker的信任仓库，并从已部署的服务器复制helm文件夹。执行命令进行模板打包后，保存并执行命令即可完成部署。在部署过程中，需要注意各个步骤的细节和操作顺序，确保部署的正确性和稳定性。

http://192.168.1.14:5000/d/f/xLh30U17mtVS3dlVXEZye24L7OIIYYbM



## zabbix监测平台-操作手册v0.1

Zabbix监测平台操作手册概述了如何完成业务系统web监测。应用集是监控项的分类目录，监控项负责收集数据，触发器则为数据定义阈值。Web监测可监控web程序的下载速度、返回码等。使用流程包括配置web监测和触发器，以及设置报警媒介。平台访问地址及账号密码在表格中列出。用户可根据手册完成配置和查看监测结果。此手册为开发人员提供指导，助其高效完成web监测工作。

http://192.168.1.14:5000/d/f/xLh2uIxRjkGtosTob22t3U909GUHvaya



## Zabbix监控SQL Server数据库

介绍了如何使用Zabbix监控SQL Server数据库。首先，选择适合的监控模板并下载。然后，将下载的脚本和用户参数拷贝到Zabbix代理安装目录。接着，修改配置文件zabbix_agentd.conf，添加用户参数，并修改相关文件。最后，在Zabbix前台管理界面导入模板、导入Zabbix参数，并为主机添加模板。通过这些步骤，可以有效地监控SQL Server数据库的状态和性能。

http://192.168.1.14:5000/d/f/xLh2nHFB3lMlAuHqFWv3Sq6fgKajf07j



## 斑马打印语言-ZPL规则整理 

本文主要介绍了斑马打印语言的ZPL（Zebra Programming Language）规则整理。本文首先介绍了制作打印模板的过程，包括使用斑马模板设计软件设计原型，转出ZPL语言，开发人员编辑ZPL内容等。接着，文章详细描述了ZPL语言的操作流程，包括修改字体、修改字段内容、修改浓度、偏移量等。此外，文章还介绍了开发工具与文档，包括ZebraDesigner模板设计器、字体转换与安装工具、字体免费下载网站、斑马打印机驱动和ZPL官方文档等。文章还提供了ZPL语言实例，供读者参考。最后，文章强调了自定义标签模板生成ZPL的重要性，以提高打印效率。总之，本文为开发ZPL的同事提供了一些参考和帮助，有助于更好地理解和应用斑马打印语言的ZPL规则。

http://192.168.1.14:5000/d/f/xLh2z70GKPmn07ZfE2ZoxopLLVDUSCQG



## 公司VPN配置

本文件旨在提供关于在公司内部配置VPN的一般说明。首先，介绍了VPN的概念和功能，包括它如何保护网络安全、提高数据传输速度等。接着，详细说明了VPN服务的部署过程，包括选择VPN服务提供商、购买VPN许可证、设置VPN服务器等步骤。此外，还提供了VPN客户端的使用指南，以帮助用户远程访问公司的内部网络资源。最后，强调了VPN配置过程中的注意事项和常见问题解决方法。总之，本文为公司内部实施VPN提供了详细的指导，有助于确保网络安全和高效的数据传输。

http://192.168.1.14:5000/d/f/xLh2mZFLtg54jgStDnToqn99w9P9TlKT



## 微服务进程支持非root权限启动

在微服务架构中，进程的安全性和稳定性至关重要。通常，为了降低安全风险，不建议使用root权限运行微服务进程。因此，我们需要探索如何在非root权限下启动微服务进程。

http://192.168.1.14:5000/d/f/xLh2x0zykGm0mtuKbfkIOb2wTQicgaii



## 应用构建速度优化

优化Docker镜像构建速度，避免拷贝不必要文件，使用.dockerignore文件忽略无用文件。放置在docker构建上下文的根路径下，可以显著提升构建速度并减少镜像体积。

http://192.168.1.14:5000/d/f/xLh2qLzcTTPpj2aPtyQKt02QCbgJp21p



## 主要开源协议简介

MPL许可证对软件专利的态度较为特殊，不直接反对但有明确要求。它要求源代码提供者不能提供受专利保护的源代码，除非自己是专利权人并已向公众免费许可。此外，MPL许可证对源代码有明确定义，并要求所有再发布者对源代码修改的时间和方式进行描述。这些规定旨在保护公众利益，防止专利滥用，确保源代码的开放性和共享。

http://192.168.1.14:5000/d/f/xLh2pgyaB3GAxZXAUP4ZhPBbaSSPEaxR



## EditorConfig + Prettier + ESLint 代码规范化

"EditorConfig + Prettier + ESLint 代码规范化" 是一个在软件开发中常用的代码质量保障策略。这个策略结合了三种工具来确保代码风格的一致性、可读性和可维护性。以下是这三种工具的简要介绍和它们如何协同工作：

1. **EditorConfig**：EditorConfig 是一个用于定义和维护代码编辑器设置（如缩进风格、制表符宽度等）的文件格式。通过在一个项目的根目录下放置一个 `.editorconfig` 文件，开发者可以确保无论他们使用哪种编辑器，都能得到一致的代码格式和风格。EditorConfig 主要是用来规范开发者的编辑环境，确保每个人都在相同的设置下工作。
2. **Prettier**：Prettier 是一个代码格式化工具，它可以自动调整你的代码以满足特定的风格规则。这些规则可以在 Prettier 的配置文件中定义，也可以通过命令行参数传递。Prettier 的主要优点是它可以自动修复大部分格式问题，而不需要开发者手动调整。
3. **ESLint**：ESLint 是一个用于识别和报告 JavaScript 代码中的模式问题的工具。这些问题可以是编程错误，也可以是风格问题。ESLint 使用一个名为 ESLint Config 的配置文件来定义哪些模式是需要报告的。与 Prettier 不同，ESLint 需要开发者手动修复它报告的问题。

这三种工具可以协同工作，以确保代码的质量。通常，Prettier 用于自动修复代码格式问题，而 ESLint 用于识别和报告更复杂的代码问题。EditorConfig 则用于确保每个开发者都在相同的编辑环境下工作。

在使用这些工具时，需要注意避免它们之间的冲突。例如，Prettier 和 ESLint 都可能对代码格式进行调整，因此需要确保它们的配置是兼容的。一种常见的做法是让 Prettier 负责代码格式的自动调整，而让 ESLint 负责报告代码风格和其他问题。这样，开发者就可以使用 Prettier 来自动修复大部分格式问题，然后手动修复 ESLint 报告的其他问题。

总的来说，"EditorConfig + Prettier + ESLint 代码规范化" 是一种非常有效的代码质量保障策略。通过合理地配置和使用这三种工具，开发者可以大大提高代码的可读性、可维护性和一致性。

http://192.168.1.14:5000/d/f/xLh2GGo6ieFfm1RQaMl739hRQKwPjnMF



## uniapp获取浏览器缓存的坑--同步和异步API

在将常见的H5端项目转移到移动端并使用uniapp进行开发时，我们可能会遇到获取浏览器缓存的问题。uniapp提供了原生的API用于处理浏览器缓存，但这些API有同步和异步之分。本文将探讨这两种API的使用及其潜在的问题。

http://192.168.1.14:5000/d/f/xLh28jaMbLPXHmoJHkE1Nif1xPnFcWw7



## uni-app图片上传_拖拽排序_替换图片_删除图片

该段内容主要介绍了uni-app图片上传拖拽排序替换图片删除图片的功能和参数说明。用户可以创建图片列表，并对图片进行拖动排序、替换和删除操作。这些功能已在APP和H5测试中正常。此外，还提供了一些参数说明，包括图片列表、显示模式、可拖动区域大小、图片父容器大小、图片间距和拖动选项等。这些参数可以通过触发事件进行控制，如添加图片、点击图片、长按图片和排序完成等。使用示例也给出了一个模板，其中包含了拖动排序组件和其他相关组件的代码。

http://192.168.1.14:5000/d/f/xLh2HZzNvJrwt08LWGMKCWZCpqMMTtAW



## vue使用v-for循环的极致优化

Vue.js 的 `v-for` 指令是用于渲染列表数据的关键工具。然而，如果不正确使用，可能会导致性能问题。下面是一些关于如何使用 `v-for` 进行极致优化的建议：

1. **为项目添加唯一的 `key`**
2. **避免在 `v-for` 中使用 `v-if`**
3. **使用索引作为 `key` 的注意事项**
4. **使用 `track-by`（在 Vue 2.x 中）**
5. **避免在循环中执行复杂计算**

http://192.168.1.14:5000/d/f/xLh2GugkUprCSXNfgGgQBFkLkOiykE0c



## webpack5通用配置

这是一个关于使用webpack5进行通用配置的指南。首先，确保Node版本在10.13.0以上。需要安装webpack、webpack-cli、webpack-dev-server等基础依赖，以及html-webpack-plugin、html-loader、clean-webpack-plugin等生成HTML所需的依赖。对于CSS处理，需要安装css-loader、style-loader、sass、sass-loader和mini-css-extract-plugin等。如果需要处理图片和字体，可以使用url-loader和file-loader。同时，为了给不同内核的浏览器添加CSS前缀，需要安装postcss-loader和autoprefixer。最后，使用webpack进行配置，包括设置回调函数或直接返回对象，优化配置nodeEnv为false，目标环境为web等。

http://192.168.1.14:5000/d/f/xLh2CAl7IPpow2HIkvnZbYPZgIobnWNL



## 基于qiankun框架实现微前端架构

微前端架构是一种将微服务理念应用于浏览器端的架构，将单页面前端应用转变为多个小型前端应用的聚合。这种架构具备技术栈无关、独立开发与部署、并行开发、增量升级等核心价值。qiankun框架是阿里推出的基于single-spa封装的微前端框架，提供了HTML Entry接入方式、样式隔离、JS沙箱和资源预加载等特性，使得接入微应用像使用iframe一样简单。通过qiankun框架，可以实现主应用和子应用的注册与管理，实现微前端架构的应用。对于应用来说，需要在主应用中安装qiankun、配置main.js、router.js和vue.config.js等文件，并在App.vue中配置主应用入口。通过使用微前端架构，可以实现技术的渐进式重构，提高开发效率和可维护性。

http://192.168.1.14:5000/d/f/xLh29S9O1YZ2gBiy4L84iWcsWNuQq8pV



## 前端数组快速去重

除了基于对象属性的去重方法外，还有其他多种去重方法，如使用 Set 数据结构、使用 filter 方法等。具体选择哪种方法取决于具体的需求和场景。

http://192.168.1.14:5000/d/f/xLh2D665Zh0IqeGCVNOlqX1KpW2CwZJ5



## 使用decimal.js解决前端页面计算精度问题

使用decimal.js可以很好地解决前端页面计算精度问题。decimal.js提供了丰富的方法和函数，可以满足各种高精度计算的需求。同时，它还提供了一些实用的功能，比如保留指定的小数位数等。在进行需要高精度的计算时，我们可以考虑使用decimal.js来提高计算的准确性。

http://192.168.1.14:5000/d/f/xLh284QWjulCkwzyyw6iW4ktgTIjhXoE



## 通过highlight.js在vue中实现代码高亮 

highlight.js用于在web界面对pre标签的美化

http://192.168.1.14:5000/d/f/xLh26PfjeO8Kha2XD6jU1vBnrrmiGNyi



## 通过zh-address-parse.js实现对国内地址智能解析

1. **安装zh-address-parse.js**

2. **引入zh-address-parse.js**

3. **使用zh-address-parse.js进行地址解析**

http://192.168.1.14:5000/d/f/xLh2BUK5LQit6Hj8yUjw2uH2tfB4SGbj



## 微前端：qiankun

微前端是一种解决巨石应用维护问题的技术手段，通过独立发布功能来共同构建现代化web应用。它具备技术栈无关、独立开发、独立部署、增量升级等核心价值。微前端将功能按业务划分成一个主项目和多个子项目，每个子项目负责自身功能，同时具备和其他子项目和主项目进行通信的能力。qiankun在原有single-spa的基础上提供了子应用的加载、更多的生命周期、样式和JS隔离、全局状态管理、全局错误处理等功能。微前端项目搭建流程包括注入依赖、注册微应用、页面节点挂载和使用start。如果你的微应用容器在index.html里的话，是没有多大问题的。微前端是一种非常好的实施渐进式重构的手段和策略，尤其在企业级Web应用中常见。通过微前端，我们可以将原本把所有功能集中于一个项目中的方式转变为按业务划分成一个主项目和多个子项目，达到更细化更易于管理的目的。

http://192.168.1.14:5000/d/f/xLh2FYfTzXKj2ipeUhTv0Ifrep6Zk6go



## 药监局官网接口调用

主要目的是通过API接口获取数据。代码中提到了多个接口调用，包括从药监局官网获取数据。根据环境变量配置，PC端和手机端使用了不同的代理设置。在PC端，需要配置代理才能正常访问；而在手机端，无需配置代理，可以直接访问。此外，代码中还使用了Vue.js框架进行开发，通过uni.request方法发送请求，并根据返回结果进行相应的处理。如果返回的数据为空，则设置udiCheckExist为false；否则，设置udiCheckExist为true，并调用getUdiDetail方法处理返回的数据。
总的来说，这段代码实现了在不同环境下通过API接口获取数据的功能，并根据返回结果进行相应的处理。其中涉及到前端开发和网络通信等方面。需要注意的是，在使用代理时需要注意配置正确，否则可能导致无法正常访问接口。

http://192.168.1.14:5000/d/f/xLh27P7tJR1XRP0WBMMk4tlXEvK8Gjxe



## 在h5端使用扫一扫功能扫码二维码

1. **选择或开发扫码组件**
2. **安装和引入组件**
3. **在模板中使用组件**
4. **处理扫码结果**

http://192.168.1.14:5000/d/f/xLh259BeArBGMqGiprkWMk1Mwvzq5rHd



## 在vue使用clipboard.js进行一键复制文本

clipboard.js库是基于浏览器原生的Clipboard API实现的，因此在一些老版本的浏览器中可能无法正常工作。在实际项目中，需要考虑到浏览器兼容性问题，并采取相应的措施来处理兼容性问题。

http://192.168.1.14:5000/d/f/xLh2ApJ331QiB6lbE1cZ0mLuZliqmLww



## 针对移动端keepAlive的使用

移动端列表详情页使用keepAlive实现高亮定位与刷新
在移动端应用中，从列表进入详情页再返回时，通常需要高亮显示之前打开的详情位置，并刷新页面。为了实现这一功能，可以使用Vue的keepAlive组件。
首先，在路由配置中加入meta字段，指定页面需要缓存，例如：`{ path: 'xxx', name: 'xxx', component: () => import('xxx'), meta: { keepAlive: true } }`。
在Vuex中，配置一个控制刷新的属性，例如`listRefreshFlag`。在详情页的activated钩子函数中，如果`listRefreshFlag`为真，则重置滚动位置并刷新页面。
为了实现锚点定位，我们需要获取当前节点的scrollTop。如果无法直接获取，可以使用当前打开详情的下标和总列表数组长度来计算当前锚点。将这个值设置到vuex中，以便在返回列表时使用。
在activated钩子函数中，如果`listRefreshFlag`为真，重置滚动位置并刷新页面；否则，如果当前锚点有值，设置当前锚点。
通过以上步骤，可以在移动端实现从列表进入详情页再返回时的高亮定位与刷新功能。

http://192.168.1.14:5000/d/f/xLh2Ep6rc65f6a7BFtJ03x1Okg98kNJL



## easypoi的简单使用

这是一个关于EasyPoi工具的介绍和使用说明。EasyPoi是一个通过简单注解和模板，实现Excel导出、模板导出、导入和Word模板导出的工具。它简化了POI的操作，使得Excel处理更为便捷。
要使用EasyPoi，首先需要导入相应的依赖，包括base、web和annotation三个模块。
在Excel导入导出方面，EasyPoi提供了注解支持，例如@Excel(name = "列名", needMerge = false, orderNum = "0", replace = "", savePath = "upload", type = 1)等，方便开发者进行功能开发。
此外，还介绍了模板渲染方面的内容，包括指令介绍、excel示例和word示例等。
总体来说，EasyPoi是一个功能强大、易于使用的Excel处理工具，适用于需要频繁处理Excel的场景，能够显著提高开发效率。通过简单注解和模板，可以轻松完成各种Excel操作，极大地简化了POI的操作流程。
http://192.168.1.14:5000/d/f/xLh2PlEZNiXSrIbL3fDWv3tF1LOTccOR



## IDEA导出API到Yapi

​		代均雄在2024-01-03使用IDEA通过EasyYapi插件将API导出到Yapi。安装插件后配置远程地址和token，获取项目token并配置插件。导出时输入token，监控日志显示同步成功。

http://192.168.1.14:5000/d/f/xLh2SoHQ1U2nDCoRxhT3ORbpIwRwVrp7



## Java8 lambda 排序 筛选 分组 求和 最大值 平均值

这是一个关于Java Stream API的测试代码，主要用于处理和操作一个Person对象的列表。首先，代码中定义了一个Person类，包含了id、name、age和gender等属性。然后，创建了一个Person对象的列表，并添加了几个Person对象。
在主函数中，首先输出了"hello"和"foreach循环"，然后使用传统的for-each循环遍历列表并打印每个Person对象的toString()方法。接着，使用Java 8的forEach方法同样遍历并打印Person对象。然后，对每个Person对象的年龄加1岁，并打印出修改后的年龄。
最后，使用stream的map方法将Person对象列表转换为一个id的List集合，然后将其打印出来。
总体来说，这个测试代码演示了如何使用Java Stream API对集合进行各种操作，包括映射、过滤、转换等。这些操作使得处理集合变得更加方便和高效。

http://192.168.1.14:5000/d/f/xLh2MApqxoYZejbaQ42Ro8jewivuflhS



## Java8集合List排序、筛选、求和、求最大值、平均值 

该文主要介绍了Java中List的排序、筛选、求和、求最大值和平均值等操作。首先介绍了ArrayList和LinkedList两种常见的List实现方式，比较了它们的查询、增删性能和线程安全性。然后介绍了如何使用Java8对List进行过滤筛选和排序。最后，文章还提到了List转Map、求和、求最大值和平均值等操作。
在排序方面，Java8引入了stream API，可以通过sorted()方法对List进行排序。此外，还可以使用Comparator进行自定义排序。在筛选方面，可以使用filter()方法对List进行筛选。在求和、求最大值和平均值方面，可以使用reduce()方法。
需要注意的是，对于大量数据的处理，应该选择合适的List实现方式以提高性能。同时，在使用stream API时，应该注意避免内存溢出等问题。

http://192.168.1.14:5000/d/f/xLh2MljhsHhxd6if635BrREwc5Cs8hRF



## Java8实战

《Java 8实战》是学习Java 8的终极指南，通过新特性如Stream API和Lambda表达式等示例讲解Java 8，开启函数式编程大门。全书电子书请见附件。

http://192.168.1.14:5000/d/f/xLh2YZeOnRzl0SG7LTe77XgOp2aLb4rx



## javamelody在项目中实施监控cpu,内存等资源使用情况

一、引言

在软件开发过程中，对项目的资源使用情况进行监控是至关重要的。这可以帮助我们了解系统的性能瓶颈，优化资源分配，提高系统的稳定性和效率。Javamelody是一个强大的Java应用程序性能监控工具，它可以轻松地集成到Spring Boot项目中，帮助我们实时监控CPU、内存等资源的使用情况。

二、Javamelody简介

Javamelody是一个开源的性能监控工具，它提供了丰富的监控指标，包括CPU使用率、内存使用情况、数据库连接、HTTP请求等。它支持多种Java应用服务器，如Tomcat、Jetty等，并且可以轻松地集成到Spring Boot项目中。

三、在Spring Boot项目中集成Javamelody

1. 添加依赖

在Spring Boot项目的pom.xml文件中添加Javamelody的starter依赖：

```xml
<dependency>  
    <groupId>net.bull.javamelody</groupId>  
    <artifactId>javamelody-spring-boot-starter</artifactId>  
    <version>1.88.0</version>  
</dependency>
```

1. 配置Javamelody

在application.properties或application.yml文件中添加Javamelody的配置项，例如：

```properties
javamelody.enabled=true  
javamelody.user=admin  
javamelody.password=admin
```

1. 访问监控页面

启动Spring Boot项目后，可以通过访问/monitoring路径来查看Javamelody的监控页面。在监控页面中，我们可以看到CPU使用率、内存使用情况、线程状态、HTTP请求等详细信息。

四、监控指标分析

1. CPU使用率

CPU使用率是衡量系统性能的重要指标之一。通过监控CPU使用率，我们可以了解系统的负载情况，判断是否存在性能瓶颈。如果CPU使用率持续过高，可能需要考虑优化代码或增加服务器资源。

1. 内存使用情况

内存使用情况也是我们需要关注的重要指标。通过监控内存使用情况，我们可以了解系统的内存分配情况，判断是否存在内存泄漏等问题。如果内存使用率持续过高，可能需要考虑调整JVM参数或优化代码。

五、总结

Javamelody是一个强大的Java应用程序性能监控工具，它可以帮助我们实时监控项目的CPU、内存等资源使用情况。通过集成Javamelody到Spring Boot项目中，我们可以更方便地了解系统的性能状况，及时发现并解决问题。在实际开发中，我们应该充分利用Javamelody等监控工具，提高系统的稳定性和效率。

http://192.168.1.14:5000/d/f/xLh2TbxDmr8aRQ75z1lOdCqJlwLwD4bS



## mybatis-plus 判断参数是否为空并作为查询条件

"mybatis-plus 判断参数是否为空并作为查询条件" 是在使用 MyBatis-Plus 这个 Java 的持久层框架时，经常需要处理的一个问题。MyBatis-Plus 是 MyBatis 的增强工具，在 MyBatis 的基础上只做增强不做改变，简化开发、提高效率。

在构建查询条件时，我们通常需要判断传入的参数是否为空，如果为空则不将该参数作为查询条件，如果不为空则将其作为查询条件。这可以通过 MyBatis-Plus 提供的 QueryWrapper 类来实现。

以下是一个简单的例子，演示了如何使用 MyBatis-Plus 的 QueryWrapper 来判断参数是否为空，并作为查询条件：

```java
QueryWrapper<User> queryWrapper = new QueryWrapper<>();  
if (StringUtils.isNotBlank(userName)) {  
    queryWrapper.lambda().eq(User::getUserName, userName);  
}  
if (null != userId) {  
    queryWrapper.lambda().eq(User::getUserId, userId);  
}  
List<User> userList = userMapper.selectList(queryWrapper);
```

在这个例子中，我们首先创建了一个 QueryWrapper 对象。然后，我们检查 userName 是否为空，如果不为空，我们就使用 lambda 表达式将其添加到查询条件中。接着，我们检查 userId 是否为 null，如果不为 null，我们也将其添加到查询条件中。最后，我们调用 userMapper 的 selectList 方法来执行查询，并获取结果。

需要注意的是，以上代码中的 `StringUtils.isNotBlank()` 方法用于判断一个字符串是否为空或只包含空格。如果你使用的是其他版本的 MyBatis-Plus 或者其他的工具类，可能需要使用不同的方法来判断参数是否为空。

此外，你提到的 ".pdf" 后缀可能表示这是一个 PDF 格式的文件。如果这是一个关于 "mybatis-plus 判断参数是否为空并作为查询条件" 的 PDF 文件，你可能需要使用 PDF 阅读器来查看和阅读该文件的内容。

http://192.168.1.14:5000/d/f/xLh2LTpckxup1Su4bClbCbkIbW28IFtc



## Optional —— 优雅地处理NullPointerException

在Java 8中，Stream和Optional两个类为流式编程带来了新的可能性。Stream主要用于集合操作，使得Java能进行类似SQL的操作，并方便地处理并行集合。而Optional则旨在减少if-else语句的使用，提高代码的可读性，优雅地处理NullPointerException。通过Optional，我们可以避免直接与null值进行交互，而是使用链式调用方式进行操作。例如，传统方式需要判断对象是否为null以及其属性是否为null，而使用Optional则可以简化这一过程。此外，Optional还提供了orElse方法，可以在值不存在时提供一个默认值，进一步增强了代码的健壮性。使用Optional可以大大提高代码的可读性和健壮性，减少NullPointerException的可能性。

http://192.168.1.14:5000/d/f/xLh2NcOIVLTD7ZOdsOxnOxipNwlDi2zW



## RuntimeException

运行时异常，也称RuntimeException，是Exception的子类，具有一般异常的特点。如果不处理RuntimeException，系统会将其一直向上抛，直至遇到处理代码或主线程被终止。常见的RuntimeException有NullPointerException、ClassCastException等。对于队列中的异常数据，正常的处理方式是舍弃并记录日志，以避免影响正常数据的处理。但在其他场景，如果退出程序是更好的选择，可以忽略RuntimeException或显式控制程序退出。在代码实现中，可以使用封装统一实现类、自定义异常封装类、枚举错误编码、全局异常处理器等方式来处理异常。根据具体情况选择合适的处理方式，确保程序的稳定性和可靠性。

http://192.168.1.14:5000/d/f/xLh2QRO0Cr4UkGii1OqPqCl6YroXm7xm



## 从ReentrantLock的实现看AQS的原理及应用

一、引言

在Java中，ReentrantLock是一种可重入的互斥锁，它提供了与synchronized关键字类似的同步功能，但具有更高的灵活性和可扩展性。ReentrantLock的底层实现是基于AbstractQueuedSynchronizer（简称AQS）的。AQS是Java并发包java.util.concurrent.locks中的一个核心组件，它提供了一个基于FIFO队列的用于构建锁和其他同步组件的框架。

二、ReentrantLock与AQS的关联

ReentrantLock的底层实现依赖于AQS，AQS为ReentrantLock提供了原子式管理同步状态、阻塞和唤醒线程的功能以及队列模型。ReentrantLock通过继承AQS并实现其相关方法来实现锁的获取和释放。

三、AQS的原理

AQS使用一个整型的同步状态（state）来表示同步资源的状态，通过原子操作来更新状态。AQS内部维护了一个FIFO队列，用于管理等待获取同步状态的线程。当线程尝试获取同步状态时，如果状态允许，则获取成功；否则，线程将被加入到等待队列中，并在适当的时候被唤醒并重新尝试获取同步状态。

四、ReentrantLock的实现

ReentrantLock的获取锁过程大致如下：

1. 首先，线程尝试获取同步状态。如果同步状态允许，则获取成功；否则，进入获取锁的逻辑。
2. 如果当前线程不是独占线程（即当前线程尚未获取锁），则尝试通过CAS操作将同步状态设置为当前线程。如果CAS操作成功，则获取锁成功；否则，进入等待队列。
3. 如果当前线程是独占线程（即当前线程已经获取锁），且支持重入，则更新同步状态并获取锁成功。

ReentrantLock的释放锁过程大致如下：

1. 线程释放锁时，将同步状态设置为0，表示锁已经被释放。
2. 如果等待队列中有线程在等待获取锁，则唤醒队列头部的线程并重新尝试获取锁。

五、AQS的应用

除了ReentrantLock外，Java中的许多其他同步组件也是基于AQS实现的，如CountDownLatch、Semaphore、FutureTask等。这些组件都利用了AQS提供的原子式管理同步状态、阻塞和唤醒线程的功能以及队列模型，从而实现了各种复杂的同步需求。

六、总结

通过从ReentrantLock的实现看AQS的原理及应用，我们可以更深入地理解Java并发编程中的锁机制。AQS作为一个核心组件，为构建各种同步组件提供了强大的支持。同时，ReentrantLock作为AQS的一个典型应用，展示了AQS在实际编程中的灵活性和可扩展性。掌握AQS的原理和应用对于提高Java并发编程能力具有重要意义。

http://192.168.1.14:5000/d/f/xLh2aFxz6JSgu54be4hTzP6XANfSJu0F



## 对接流程平台脚手架

UserInterfaceImpl类实现了UserInterface接口，提供了根据角色查询接收人的功能。它使用Autowired注解注入IBpmnService实例，用于处理流程相关操作。同时，NextInterceptor接口的实现和业务数据入库后发起流程的功能也值得关注。综合来看，这是一个涉及到用户界面、流程处理和数据入库的完整代码实现。

http://192.168.1.14:5000/d/f/xLh2ULedjKoJL45A7QNEASmFVmdQUhsQ



## 公司环境和31环境网关工程自动构建部署操作步骤 

黄胜在2024-02-04创建了公司环境和31环境网关工程，提供了自动构建部署操作步骤，包括进入git管理页面、进入网关系统管理界面复制回调地址等。

http://192.168.1.14:5000/d/f/xLh2RFd0EMyvhAhPVuyOhCvPhdkmb5Fn



## 基于OpenResty做访问权限

基于OpenResty做访问权限是一个涉及网络安全和服务器配置的重要话题。OpenResty是一个基于Nginx的全功能Web平台，它提供了丰富的模块和功能，使得开发人员能够更加灵活地处理Web请求和构建高性能的Web应用。

在访问权限控制方面，OpenResty可以通过配置Nginx来实现各种访问控制策略。以下是一些常用的方法：

1. IP访问控制：通过Nginx的`allow`和`deny`指令，可以限制特定IP地址或IP地址段的访问。例如，可以允许某个IP地址段内的用户访问，而拒绝其他所有用户的访问。
2. 基于用户的访问控制：通过Nginx的HTTP认证模块，可以实现基于用户名和密码的访问控制。用户需要在请求中提供正确的用户名和密码才能访问受保护的资源。
3. 角色和权限管理：可以结合Lua脚本和OpenResty的第三方模块来实现更复杂的角色和权限管理。通过编写Lua脚本，可以定义用户角色、权限和访问规则，并在Nginx配置中引用这些规则来实现细粒度的访问控制。
4. 跨域资源共享（CORS）：对于涉及跨域请求的场景，可以通过配置Nginx的CORS相关指令来允许或拒绝跨域请求。这有助于保护Web应用的安全性，并控制哪些域名可以访问受保护的资源。

除了上述方法外，还可以结合其他安全策略和技术来增强访问权限控制的效果。例如，可以使用HTTPS协议来加密传输的数据，防止数据泄露；可以使用防火墙或入侵检测系统来监控和阻止恶意访问；可以定期更新和审查访问控制策略，以确保其适应业务需求和安全要求。

需要注意的是，具体的访问权限控制方案应根据实际应用场景和需求进行设计和实现。同时，应定期评估和调整访问控制策略，以应对不断变化的安全威胁和业务需求。

http://192.168.1.14:5000/d/f/xLh2VV2kweSJwBoxT6IZZv9GB9b6Yi6F



##  配置文件数据库密码加密

"配置文件数据库密码加密"是一个关于如何安全地存储和传输数据库密码的重要主题。由于数据库密码通常以明文形式存储在配置文件中，如果配置文件被未经授权的用户访问，那么数据库的安全性就可能受到威胁。因此，对数据库密码进行加密是一种常见且推荐的安全措施。

在加密数据库密码时，通常会使用公钥和私钥进行加密和解密。公钥和私钥是一对密钥，公钥用于加密数据，私钥用于解密数据。只有拥有相应私钥的用户才能解密和访问加密的数据。

以下是配置文件数据库密码加密的一般步骤：

1. 生成公钥和私钥：使用加密算法（如RSA）生成一对公钥和私钥。公钥将用于加密数据库密码，私钥将由数据库管理员或授权用户持有，用于解密密码。
2. 加密数据库密码：使用公钥和适当的加密算法（如AES）对数据库密码进行加密。加密后的密码将存储在配置文件中，而不再是明文形式。
3. 安全存储私钥：私钥必须妥善保管，以防止未经授权的用户访问。私钥可以存储在安全的地方，如硬件安全模块（HSM）或加密的文件中。
4. 配置数据库连接：在配置文件中使用加密的数据库密码。当应用程序需要连接到数据库时，它将使用私钥解密密码，并使用解密后的密码建立数据库连接。

需要注意的是，虽然加密数据库密码可以提高安全性，但并不能完全消除安全风险。因此，还需要采取其他安全措施来保护数据库的安全性，如使用强密码、限制数据库访问权限、定期备份数据库等。

此外，一些数据库管理系统（DBMS）也提供了内置的数据库密码加密功能。例如，MySQL提供了透明数据加密（TDE）功能，可以对存储在数据库中的数据进行加密。使用这些内置功能可以进一步增强数据库的安全性。

总的来说，配置文件数据库密码加密是一种重要的安全措施，可以帮助保护数据库的安全性。通过合理地使用公钥和私钥进行加密和解密，可以有效地防止未经授权的用户访问数据库密码。同时，还需要采取其他安全措施来增强数据库的整体安全性。

http://192.168.1.14:5000/d/f/xLh2S21buR4mo5yaEP48g89I138k7I8E



## 使用easyPOI替换字典

一、概述

在开发过程中，我们有时会遇到需要将数据库中的字典数据导出到Excel表格中的需求。而easyPOI是一个优秀的Java库，可以帮助我们快速实现这一功能。本文将介绍如何使用easyPOI替换字典，包括导出model配置dict属性、编写自定义字典处理类以及设置字典处理类。

二、导出model配置dict属性

首先，我们需要在导出的model中配置dict属性。这个属性通常用来表示字典的父级code。例如，我们有一个用户表，其中有一个性别字段，该字段的值是字典中的code，如“01”表示男性，“02”表示女性。那么，我们需要在用户表的model中添加一个dict属性，用于指定这个性别字段对应的字典。

三、编写自定义字典处理类

接下来，我们需要编写一个自定义的字典处理类，实现IExcelDictHandler接口。这个接口有两个方法：toName和toValue。toName方法用于将字典的code转换成中文，而toValue方法则用于将中文转换成字典的code。

在实现toName方法时，我们可以通过查询数据库或其他方式获取到字典数据，然后根据传入的code找到对应的中文。同样地，在实现toValue方法时，我们也需要根据传入的中文找到对应的code。

四、设置字典处理类

最后，我们需要在导出Excel时设置字典处理类。这样，当easyPOI遇到字典字段时，就会调用我们自定义的字典处理类来处理这些字段。在设置字典处理类时，我们还需要指定租户id等参数。这些参数的具体含义和设置方式可能会因项目的不同而有所差异，需要根据实际情况进行设置。

总之，使用easyPOI替换字典可以大大提高我们的开发效率。通过合理地配置model和编写自定义的字典处理类，我们可以轻松地实现字典数据的导出和转换。同时，也需要注意根据项目的实际情况进行适当的调整和配置。

http://192.168.1.14:5000/d/f/xLh2OMNJZsQerlPu2BevFAMGXG6oSlhm



## 通用日志服务模块SDK说明文档

通用日志服务模块的SDK，旨在解决项目中日志功能的实现问题，减少代码冗余，简化使用。该SDK提供了多种日志类型的相关功能，包括接口日志、操作日志、预览日志、系统异常日志和业务相关日志等。通过YAML配置和AOP实现操作日志、预览日志的捕获，默认开启系统异常日志的捕获。该文档还描述了数据库表的设计，包括id、infcode、appid、busiid、content、syscode、createtime、result和resultcontent等字段。总的来说，该文档提供了一个全面、易用的日志服务模块SDK，可以帮助开发人员快速实现项目中的日志功能，提高开发效率和代码质量。

http://192.168.1.14:5000/d/f/xLh2ZNkbFu8Z5cLIvudyhXO898CLPn4D



## 网关部署应用实例，实现请求无缝切换

一、概述

在微服务架构中，网关作为服务的入口，负责请求的路由、认证、限流等功能。当网关背后的应用实例进行升级、扩容或故障转移时，如何保证请求的无缝切换是一个关键问题。本文将介绍如何通过网关部署应用实例，实现请求的无缝切换。

二、方案设计

1. 容器化部署

将应用实例以容器的形式进行部署，每个容器运行一个应用实例。通过容器编排工具（如Docker Swarm、Kubernetes等）对容器进行管理，实现应用的自动部署、扩容和故障转移。

1. 负载均衡

在网关层面，使用负载均衡器（如Nginx、HAProxy等）将请求分发到多个应用实例上。负载均衡器可以根据应用的健康状态、权重等因素进行请求分发，保证请求的高可用性和负载均衡。

1. 服务注册与发现

使用服务注册与发现组件（如Consul、Etcd等），将应用实例的信息注册到注册中心。网关通过注册中心获取应用实例的列表，并根据负载均衡策略将请求分发到相应的实例上。当应用实例发生变化（如新增、删除、故障等）时，注册中心会实时更新实例信息，网关会感知到这些变化并自动调整请求分发策略。

三、实现步骤

1. 部署应用实例容器

使用容器编排工具部署应用实例容器，并配置相应的端口映射、环境变量等。

1. 配置负载均衡器

在网关层面配置负载均衡器，指定应用实例的访问地址和端口。配置负载均衡策略，如轮询、加权轮询、IP哈希等。

1. 集成服务注册与发现组件

在应用实例启动时，将其信息注册到服务注册与发现组件中。网关通过注册中心获取应用实例的列表，并根据负载均衡策略将请求分发到相应的实例上。

1. 测试与验证

对网关进行压力测试、性能测试等，验证请求无缝切换的效果。同时，模拟应用实例的故障、扩容等场景，观察网关是否能够自动调整请求分发策略。

四、总结

通过容器化部署、负载均衡和服务注册与发现等技术手段，我们可以实现网关部署应用实例的请求无缝切换。这种方案不仅提高了应用的高可用性和负载均衡能力，还降低了运维成本和复杂度。在实际应用中，我们可以根据具体需求和场景选择合适的技术和工具来实现无缝切换。

http://192.168.1.14:5000/d/f/xLh2Xhic56i50YxwyfUiUUIHDx0VH0qC



## linux服务器在内网环境下平滑升级openssh至9.3

在数字中台项目“护网行动”中，云平台服务器Linux version 4.19.90-2112.8.0.0131.oe1.x8664被发现存在安全漏洞。为了解决这个问题，需要将openssh进行升级。考虑到升级过程的复杂性和安全性，我们整理了一份最佳实践。服务器处于纯内网环境，无法使用Yum、Wget等命令执行外网下载，因此需要提前下载相关文件。华为云平台服务器提供了控制台web访问入口，即使升级过程中ssh服务损坏，也可以通过web控制台登录服务器执行回退操作。升级的核心思路是直接编译安装最新版的openssh，然后替换配置文件，最后停用老版本openssh服务并启动新版本的openssh服务。在升级前需要先升级zlib库和openssl依赖库，均升级到最新版本。整个升级过程属于平滑升级，不涉及其他复杂操作。通过这样的方式，可以确保服务器安全并提高系统的稳定性。

http://192.168.1.14:5000/d/f/xLh2gMlgCHXXO75PpKB8k0fa6HSGwjAK



## linux服务器在内网环境下升级apache zookeeper 

在护网行动背景下，云平台服务器在Linux环境下存在安全漏洞，需升级Apache Zookeeper。升级目标服务器位于纯内网环境，无法使用Yum、Wget等命令执行外网下载，需提前官网下载相关文件。升级依赖于netcat，若系统未安装netcat，需先完成安装。具体操作步骤如下：

1. 判断服务器是否已安装netcat，若未安装，则通过源码方式进行安装。
2. 下载最新版本的Zookeeper安装包至服务器，解压缩后将老版本Zookeeper的配置文件复制到新版本目录下。
3. 停止老版Zookeeper服务，启动新版Zookeeper服务。
   通过以上步骤，可成功在内网环境下升级Apache Zookeeper，确保系统安全。

http://192.168.1.14:5000/d/f/xLh2feuebELtZINNgM2m3b8IUTgnjJ5H



## openssh升级至8.5p1

一、升级须知

在升级OpenSSH至8.5p1之前，您需要确保了解以下几点：

1. 备份当前OpenSSH配置文件和相关数据，以防升级过程中出现问题。
2. 确保您的服务器具备足够的权限和资源进行升级操作。
3. 升级过程中可能会中断SSH连接，请提前通知相关用户或采取其他措施确保升级过程的顺利进行。

二、安装依赖项

在升级OpenSSH之前，您需要安装一些依赖项，包括zlib和OpenSSL。请按照以下步骤进行安装：

1. 安装zlib：
   - 下载zlib的最新版本并解压。
   - 进入解压后的目录，执行配置和编译安装命令。
2. 升级OpenSSL：
   - 访问OpenSSL官方网站下载最新版本（当前最新版本为1.1.1k），并解压。
   - 进入解压后的目录，执行配置、编译和安装命令。
   - 备份原有的OpenSSL文件，并将新安装的OpenSSL文件替换原有的文件。

三、编译和安装OpenSSH

完成依赖项的安装后，您可以开始编译和安装OpenSSH 8.5p1。请按照以下步骤进行操作：

1. 通过Telnet方式登录到服务器。
2. 下载OpenSSH 8.5p1的源代码并解压。
3. 进入解压后的目录，执行配置命令。配置选项可能包括指定安装目录、配置文件目录、OpenSSL和zlib的路径等。
4. 执行编译和安装命令。这将编译OpenSSH源代码并将其安装到指定的目录中。
5. 完成安装后，您需要修改OpenSSH的配置文件。打开配置文件（通常位于/etc/ssh/sshd_config），根据您的需求进行相应的配置修改。确保其他配置保持不变。

四、启动OpenSSH服务

完成配置文件的修改后，您可以启动OpenSSH服务。请执行以下命令：

1. 启动Telnet服务（可选）：

```bash
bash复制代码

systemctl start telnet.socket
```

1. 停止原有的SSH服务：

```bash
bash复制代码

systemctl stop sshd
```

1. 启动新的OpenSSH服务：

```bash
bash复制代码

/usr/local/openssh-8.5p1/sbin/sshd
```

请注意，上述命令中的路径可能因您的安装配置而有所不同。确保使用正确的路径来启动OpenSSH服务。

五、验证升级结果

完成OpenSSH服务的启动后，您可以验证升级结果。请执行以下命令查看OpenSSH的版本信息：

```bash
bash复制代码

ssh -V
```

如果输出信息显示为OpenSSH 8.5p1，则表示升级成功。

六、注意事项

在升级OpenSSH后，请注意以下几点：

1. 确保测试新的OpenSSH版本以验证其功能和安全性。
2. 监控OpenSSH服务的日志，以发现任何潜在的问题或错误。
3. 定期更新和维护OpenSSH，以确保其安全性和稳定性。

通过遵循上述指南，您应该能够成功将OpenSSH升级至8.5p1版本。

http://192.168.1.14:5000/d/f/xLh2ha8BEZfooXRAEobksLuacBj9g0vw



## 基于iptables限制端口指定IP访问 

iptables是Linux系统下一款强大的防火墙工具，它允许你配置复杂的防火墙规则来保护你的服务器。通过iptables，你可以限制对特定端口的访问，只允许指定的IP地址访问这些端口。

http://192.168.1.14:5000/d/f/xLh2gugkF4U2qhMnejOCcpUnCakYVSyV



## db2数据库备份脚本

该脚本是一个用于自动备份DB2数据库的Shell脚本，由管理员创建，最后修改于2021年3月18日。它首先获取当前日期和时间，然后定义备份目录。接着，它检查当前日期的备份目录是否存在，如果不存在则创建该目录。然后，它设置DB2环境变量并检查是否存在DB2配置文件，如果存在则进行配置。之后，它执行数据库的导出操作，分别针对BPMN6和CZ_STDD数据库，将它们导出为DDL文件，并将它们分别放入BPMN6和CZ_STDD目录中。最后，它使用tar命令将当前日期的备份目录打包为tar.gz文件，然后删除该目录，并输出备份成功的消息。
这个脚本旨在自动化DB2数据库的备份过程，确保数据库的安全性和可用性。通过定期备份数据库，可以在数据丢失或损坏的情况下快速恢复数据，减少损失。此外，该脚本还提供了DB2数据库的导出功能，可以将数据库的结构和数据导出为DDL文件，便于备份和迁移。最后，该脚本还使用了tar命令对备份数据进行压缩和归档，进一步节省存储空间并方便传输和存储。
总的来说，这是一个功能强大且易于使用的DB2数据库备份脚本，可以帮助管理员自动完成数据库的备份、导出和归档工作，确保数据的安全性和可用性。

http://192.168.1.14:5000/d/f/xLh2czHiC7IDFRUoHarlkLsNOTFbbdI8



## mysql查询优化

这篇文章讨论了MySQL查询优化的两个关键方面：使用LIKE或NOT LIKE模糊查询和涉及多个表数据去重的查询。对于模糊查询，优化建议是将LIKE和NOT LIKE条件放在查询的最后面，这样可以提高查询效率。测试数据表明，优化前后的查询时间从1秒左右减少到0.6秒左右。对于涉及多个表数据且需要去重的查询，建议使用子查询而不是关联查询。通过优化，测试数据的查询时间从12秒左右减少到0.9秒左右。
文章还给出了两个具体的查询示例，包括优化前后的SQL语句和相关的性能数据。第一个查询涉及筛选特定条件的订单记录，通过将NOT LIKE条件放在最后，提高了查询效率。第二个查询涉及从多个表中获取不重复的数据，通过使用子查询，减少了查询时间。
总结来说，文章提供了关于MySQL查询优化的实用建议，包括如何优化模糊查询和如何处理涉及多个表数据且需要去重的查询。这些技巧可以帮助提高数据库的性能和响应速度。在实际应用中，根据具体情况选择合适的优化方法是很重要的。

http://192.168.1.14:5000/d/f/xLh2c2oLOjC8jioHFPq0u8roit784r4o



## mysql数据库备份脚本

该段代码是一个MySQL数据库备份脚本，用于备份数据库并删除过期备份。如果开启了删除过期备份，则进行删除操作。脚本会查找备份位置，删除过期天数的目录和文件。如果所有数据库备份成功，则显示"All database backup success! Thank you!"并退出脚本。

http://192.168.1.14:5000/d/f/xLh2bKfifcbaGzGnjIEB7hbPGbqvjPc1



## Oracle数据库备份脚本

Oracle数据库备份脚本是一种用于备份Oracle数据库的脚本文件，通常使用Oracle提供的RMAN（Recovery Manager）工具来实现。备份脚本通常包含一系列RMAN命令，用于执行数据库备份、恢复和校验等操作。

通过编写和执行Oracle数据库备份脚本，可以实现自动化备份、定期备份和一致性备份等操作，确保数据库的安全性和可用性。

http://192.168.1.14:5000/d/f/xLh2em84UfipV8tEr0U5mh9e6205uDmL



## SQL优化步骤

SQL优化是一个复杂的过程，需要从多个方面进行分析和改进。首先，通过慢查询日志等工具定位执行效率较低的SQL语句，然后使用EXPLAIN分析其执行计划，重点关注type、rows、filtered、extratype等指标。根据这些信息，可以对SQL语句进行优化，如修改SQL语句、使用合适的索引、优化查询条件等。此外，还可以使用SHOW PROFILE等工具分析SQL执行的线程状态和消耗的时间，进一步了解性能瓶颈。同时，开启optimizer_trace可以分析优化器如何选择执行计划，有助于了解为什么选择某种执行计划。对于数据碎片等问题，需要进行相应的处理。总之，SQL优化需要综合考虑多个方面，不断尝试和调整，才能获得最佳的性能提升。

http://192.168.1.14:5000/d/f/xLh2e1IG1wYkNZSpyTDmh5plFEc8iSFi



## uniapp集成第三方SDK 

1. 集成企业微信SDK：由于uniapp官方没有提供企业微信登录的API，开发者采用了安卓原生方式集成。其中涉及了下载企业微信SDK、回调获取code、以及解决软件卡死问题。最终通过定义静态属性和方法，成功获取企业微信返回的code。
2. 微信分享功能的实现：由于使用了离线打包，uniapp自带的分享功能失效，开发者通过导入相关jar包和配置，实现了微信分享功能。
3. 集成第三方SDK的开发流程：主要包括获取SDK、阅读接口文档、导入相关配置、编写功能代码以及打包运行。
   综上所述，页面主要介绍了在移动端应用开发中，如何应对集成第三方SDK和各种开发技巧的问题，如企业微信登录和微信分享功能的实现，以及解决软件卡死问题的方法。这些技巧和经验有助于开发者更高效地完成移动端应用的开发和集成工作。

http://192.168.1.14:5000/d/f/xLh2Jr41ZrNSJHkRA0HnqikZSUwMnwPj



## uniapp开发微信小程序

UniApp是一种非常适合开发微信小程序的框架，它可以帮助开发者提高开发效率，减少代码量，实现一次编写，多端运行的效果。在使用UniApp开发微信小程序时，需要注意微信小程序的规范和要求，确保小程序的功能和页面都符合微信的要求。

http://192.168.1.14:5000/d/f/xLh2Kt4ZPUIJiSe3oooNni1lwnYybPnn



## uniapp相关所有文档

uniapp是一种使用Vue.js开发所有前端应用的框架，可以发布到iOS、Android、H5、以及各种小程序（微信/支付宝/百度等）。它的文档包含了开发者需要了解的所有内容，从基本的API调用，到组件的使用，再到高级性能优化等。

http://192.168.1.14:5000/d/f/xLh2J271jCUCJeHW8VnILIf250oA1YSn



## 原生app开发（Android）

HbuilderX是一款强大的开发工具，可用于创建uniapp项目。使用HBuilderX登录开发者账号后，可以新建项目并进行打包。离线打包需要进入Dcloud开发者后台获取离线APPKEY。此外，开发中还需要注意消息推送、相机模块等功能的实现，以及使用阿里云OSS API和任务调度等技巧。

http://192.168.1.14:5000/d/f/xLh2IPeNbAvFAuwvh71SSgGfkCYKHujg



## 模板标签定义说明 

常见的模板标签有{% load xxxx %}, {% block xxxx %}, {% if xxx %}, {% url 'xxxx' %}。这些模板标签的本质也是函数，标签名一般即为函数名。这些标签的主要作用包括载入代码渲染模板或对传递过来的参数进行一定的逻辑判断或计算后返回。

http://192.168.1.14:5000/d/f/xLh3gihWOEd4IOTr6S9FQiamCRGQZuL9





## Web前端开发规范

本文是一份非常详尽的Web前端开发规范，涵盖了页面开发规范的命名规范和编程规范、工程结构技术栈规范以及开发服务器配置等方面的内容。遵循这些规范可以保证代码的可读性、可维护性和一致性，提高开发效率和质量。

http://192.168.1.14:5000/d/f/xLh3DiLrjVqM6YgGbURp3K20IT0bSJoE



## TypeScript

TypeScript的Web前端开发规范涵盖了多个方面，包括声明、声明文件、进阶声明、类与接口以及泛型。在声明部分，TypeScript特有类型void声明以及基本数据类型被详细介绍。此外，还有任意值类型、联合类型以及对象类型-接口。类型别名、字符串字面量、元组、枚举等进阶声明也被涵盖。类部分介绍了普通类、抽象类等，类与接口的关系以及实现和接口继承等内容也被深入探讨。最后，泛型部分包括泛型类和为泛型指定默认类型等内容。这些规范为开发者提供了详尽的指导，有助于提高代码的可读性和可维护性。遵循这些规范有助于避免类型错误，提高代码质量。

http://192.168.1.14:5000/d/f/xLh3F0Fwqp91ehiYrTuOm7GTUVS7yE23



## Vue3风格指南

这份Vue3风格指南为前端开发提供了一些有价值的建议和最佳实践，旨在帮助开发者避免常见错误和提高代码质量。然而，每个项目和团队的需求都是独特的，因此在实际应用中需要根据实际情况进行适当的调整和修改。

http://192.168.1.14:5000/d/f/xLh3EGhKTONF49lWjY3lbCGWdIbayOLr





## nacos使用规范

1. 请确保在使用Nacos时遵循最佳实践，包括适当的配置管理、服务发现等。
2. 如有任何更改或更新，请及时通知相关团队或人员。
3. 遵循公司的安全政策和规定，确保Nacos的使用是安全和合规的。

http://192.168.1.14:5000/d/f/xLh36MU4obcauwwo5UI9COU6qd7dC5AL



## RESTful API设计规范

这篇文章主要是关于API设计的规范和标准，包括URL定义格式、资源表述、资源名和资源值、统一接口、响应状态码等。首先明确了对外提供服务的API格式和系统资源划分的方式，然后详细解释了URL的各个部分，包括Scheme、Port、Path和Query。接着讨论了资源的表述方式，包括命名规范、时间戳格式、枚举类型定义规范、标准字段和通用参数名。此外，还介绍了统一接口和各种响应状态码。最后，文章提到了批量操作、重载POST、授权等方面的注意事项，并给出了一些参考链接。总的来说，这是一篇非常全面的API设计规范文章，有助于提高API的设计质量和可维护性。

http://192.168.1.14:5000/d/f/xLh36xx7zCCycgvxp9ldpP2n72YJNUMT



## RESTful设计重点

RESTful设计要点包括：服务地址采用指定格式，避免动词和驼峰命名；时间字段统一使用RFC3339格式；服务调用失败时返回特定格式的body；所有API响应遵循HTTP规范，并选择合适的HTTP状态码；分页搜索接口参数和实体使用通用名称。遵循这些要点，可提高API的可读性、规范性和可靠性。

http://192.168.1.14:5000/d/f/xLh3550OOC2dh0rO2qWsryT6MFYbevDL



## 安全规范 

在开发规范中，安全问题至关重要。为了从代码层面规避已知的安全问题，开发人员采取了多种措施。首先，对前端JavaScript代码进行合并与压缩处理，增加代码可读性难度，降低注入或暴力破解等风险。其次，减少使用第三方插件，对第三方插件进行升级处理，避免插件中可能存在的风险。此外，采用SessionStorage技术进行数据缓存，限制数据读取范围，并使用Token验证机制，验证接口调用属于用户登录后的行为。对于用户输入内容，加强组件输入限制和正则验证，并对用户输入内容进行原样输出显示。同时，添加服务器配置，验证接口来源的同源信息。另外，强制要求用户在初次登录后修改密码，并定期修改密码，避免被盗用的风险。最后，去除接口请求和响应中可能暴露服务器端环境的相关信息。总之，通过这些措施，可以有效地规避常见的安全问题，提高系统的安全性。

http://192.168.1.14:5000/d/f/xLh37YZNlbHYmPoZkukUWPVhYR2mILGe



## 版本管理及开发流程

该文档主要介绍了版本管理和开发流程的规范，包括分支管理和开发流程两个部分。在分支管理方面，文档详细说明了各个分支类型的命名规范、使用场景和合并规则，包括Develop分支、Feature分支、Release分支和Hotfix分支。这些分支类型的使用场景和规范为团队协作开发提供了明确的管理方式和规范，提高了开发效率和质量。在开发流程方面，文档简要介绍了功能开发、版本发布、缺陷修复和测试等流程，但未给出具体的操作步骤和细节。总体来说，该文档为团队提供了完整的版本管理和开发流程的规范，有助于提高开发效率和质量，同时为团队之间的协作提供了明确的指导和规范。

http://192.168.1.14:5000/d/f/xLh3C60fFVV2dTiFKHCDp2d0xsXz1l41



## 搭建个人开发环境

在软件开发过程中，一个舒适、高效的开发环境是必不可少的。本文将为您介绍如何搭建一个适合个人使用的开发环境，包括前端开发环境、后端开发环境以及相关的工具和库。

http://192.168.1.14:5000/d/f/xLh389kpo8dhz4e6yZZfRALf8GOJsxX3



## 开发测试上线流程

页面开发规范文档，参考行业采购管理系统的上线申请表.doc。

http://192.168.1.14:5000/d/f/xLh34MaAX1j5FqVARGQ9SPLissjxOzzO



## 开源软件选型规范 

开源软件选型对于公司非常重要，需谨慎考虑。在选择时，应查看第三方横向对比，了解技术概况。此外，还需考虑如何打包、配置、升级和生产。对于开源软件的缺点和整合代价也要有明确认知。在选择时，需注意功能、性能、许可证、兼容性和测试等方面。只有全面考虑，才能做出最佳选择，确保项目的顺利进行。

http://192.168.1.14:5000/d/f/xLh3ADd7uZBBdAfTiZ39zypxFq45uOQj



## 前后端开发工具与框架手册



http://192.168.1.14:5000/d/f/xLh35kJ1oqyBMrjO0hWCJAqxsWLnZtxB



## 睿展知识库系统使用手册

睿展知识库系统为用户提供了从环境地址、连接到公司git文档空间、文档编辑维护、导入导出到个性化设置的全面支持。用户可以通过系统访问地址和公司gitea仓库地址进行访问和连接。在文档编辑维护方面，用户可以创建、编辑、删除、重命名和搜索文档，并可手动同步更新至Gitea仓库。系统支持Markdown与HTML的导入和导出，并支持阅读与编辑模式的切换以及编辑区域的折叠。但目前编辑区对Markdown的可视化操作项并不完整，需要用户自行在编辑器中直接进行编辑或复制外部编辑好的Markdown文档。

http://192.168.1.14:5000/d/f/xLh33mX70jKIHCqLRlclEkcAf4nJ2JdO



## 数据加密规范

本文规定了数据加密规范目标，旨在加强加密算法控制并淘汰不安全加密方法。安全要求包括禁用不安全算法、使用安全随机数和推荐使用AES等算法。密钥管理和IV管理是实现这些安全要求的关键。密钥管理要求独立的密钥管理组件/服务，采用分层存储策略，并确保密钥在内存中的安全。IV管理要求每次加密使用的IV值都安全随机，并在加密算法内部实现。这些措施有助于提高数据加密的安全性和性能。

http://192.168.1.14:5000/d/f/xLh3Cm1IV8AzStPrPU64TwwO2JfK9mdE



## 系统开发环境规范

本文旨在为系统开发过程中的环境配置提供全面的指导，以确保项目/产品的顺利开发和高质量交付。通过在不同阶段进行验证和测试，可以有效地提高产品的质量和可靠性。同时，提供各环境下应用的访问地址和相关备注，有助于开发人员和测试人员在工作中更加高效地协作和沟通。

http://192.168.1.14:5000/d/f/xLh38nUg1FPzvEhZQVmgGrzrNVTKH9Op



## 源码编写规范

源码编写规范是软件开发过程中的重要准则，它规定了编写源代码时应遵循的一系列规则和最佳实践。这些规范旨在提高代码的可读性、可维护性、可扩展性和可重用性，从而确保软件的质量和稳定性。

http://192.168.1.14:5000/d/f/xLh3B7GVPIMJlOlMwxByykm8VjMlzk4o



## el-table自适应高度指令v-adaptive

这段代码主要实现了一个自适应高度的el-table组件，通过监听窗口的resize事件，动态计算并设置表格的高度。该组件可以用于Element UI的el-table组件，使其能够自适应屏幕高度，同时保持滚动条在表格内部，避免页面出现滚动条。
具体实现方式是在模板中添加v-adaptive指令，该指令会绑定一个自适应高度的处理函数。在处理函数中，首先获取表格的DOM对象和调用传递过来的数据。然后根据数据中的bottomOffset值计算表格的高度，并设置表格的布局高度。
在组件的bind和inserted钩子函数中，分别添加和移除窗口的resize监听。当窗口大小发生变化时，会重新计算表格的高度并设置布局。
需要注意的是，在使用该组件时需要设置表格的高度属性，否则会出现错误。同时，bottomOffset的值可以根据实际需求进行调整，以适应不同的页面布局。

http://192.168.1.14:5000/d/f/xLh3PmRh4bezJoHPHIqFpawHL7Wfr4bo



## NTKO Office文件在线预览

这是一个前端组件，用于湖南中烟相关应用系统在线打开Word、PDF文件。组件类别为展示组件，可以通过新建officeview.vue文件并在路由文件中配上相应路由地址进行引入。文件明细未给出相关代码文件，但在使用中需注意其他如需在线打开文档，可使用window.open方式打开对应的路由地址。此外，需要注意的是在初始化控件对象后，需要在destroyed生命周期钩子中释放资源。总体来说，这是一个用于在线预览Office文件的Vue组件，具有一定的实用性和灵活性。在使用过程中，需要遵循相应的规范和注意事项，以确保组件的正常运行和性能优化。

http://192.168.1.14:5000/d/f/xLh3Rg6QUmotCUhQdbOm73pVaXd88FIv



## RZUI组件库 

RZUI是一个使用pnmp搭建的Monorepo项目，提供基础的UI组件，开发者可以基于此框架开发符合业务需求的组件。RZUI项目包括组件库、组件文档和Demo。计划开发的组件包括高级查询、文件分片上传、字典和省市区等。项目仓库提供了相关的命令和使用说明，如安装pnmp、安装依赖、启动本地测试、打包组件库、发布、启动文档、打包文档和进行单元测试等。RZUI旨在为开发者提供一套完整的前端解决方案，帮助快速构建高质量的应用。



## vue excel文件处理

Vue项目用于处理Excel文件，通过安装xlsx库，将JSON数据转换成Excel文件。该项目由李志强创建，余艺进行了修改。主要功能是将总统信息从JSON数据中筛选、扁平化并转换成Excel文件。通过axios获取JSON数据并解析，筛选出总统信息，将对象扁平化并转换成数组。使用xlsx的json_to_sheet方法生成工作表和工作簿，并添加标题行。计算列宽度并导出Excel文件，为进一步数据分析提供基础数据。此项目生成的Excel文件可用于生日分析等场景。
此外，还有代码片段用于将Excel数据转换为JSON格式。通过使用xlsx库，可以将Excel文件读取并解析为JSON对象数组。在解析过程中，可以通过指定表头来提取所需的数据列。例如，在产品信息表中，可以通过指定'serial'、'rangeName'和'name'等列名来提取相应的数据。转换后的JSON数据可以用于进一步的处理或存储。该代码适用于处理具有固定列和表头的Excel表格数据，并且可以通过调整参数来适应不同的数据结构。
总之，该项目为数据处理和分析提供了便捷的方式，通过将JSON数据转换成Excel文件和将Excel数据转换为JSON格式，实现了数据的快速处理和存储。适用于需要处理大量数据的场景，如生日分析、产品信息管理等。

http://192.168.1.14:5000/d/f/xLh3TRfahvZLRkt4v0rVIPiCbWijsRfk



## Vue3 二次封装Element Plus的el-pagination 分页组件

在使用Vue3和Element Plus开发过程中，分页组件是常见且重要的组件之一。Element Plus自带的el-pagination分页组件虽然功能强大，但在某些场景下，我们可能需要对其进行二次封装，以满足特定的业务需求。本文将介绍如何在Vue3中二次封装Element Plus的el-pagination分页组件，使其更加符合我们的使用习惯。

http://192.168.1.14:5000/d/f/xLh3R6lMnfgzWru9kOejEfjS0fnd1yVp	



## vue使用jsMind思维导图类库

这段文本描述了一个使用Vue.js和jsMind的思维导图组件的前端开发过程。首先，安装了vue-jsmind库，然后在main.js中引入并使用了该库。通过Vue.use()方法，将jsMind添加到了Vue的原型中，使得在任何组件中都可以通过this.$jsMind访问到jsMind实例。同时，还设置了jsMind的一些配置项，如节点选项的字体大小等。在页面的底部添加了一个footer，设置了其样式和位置。最后，通过在Vue实例中绑定数据和监听数据变化，动态地生成了思维导图。
这个思维导图组件具有丰富的功能和灵活的配置项，可以方便地生成各种类型的思维导图，如知识导图、服务导图等。同时，它还支持自定义主题，使得生成的思维导图更加符合用户的需求。通过使用Vue.js和jsMind库，可以快速地开发出功能强大、样式美观的思维导图组件，提高开发效率和用户体验。

http://192.168.1.14:5000/d/f/xLh3LtSFdAta58Xuq0tNQfDhbXWoarlV



## 表格跨页面选取数据

这是一个名为"acrossPagesSelected.vue"的表格组件，由刘康创建，用于设备健康管理平台。当列表多页显示时，它保存了所有页面的已选项，避免了切换页面已选择项被清空的问题。该组件提供了"list"和"selected"两个插槽，分别用于未选择项列表和已选择项列表的显示。它接受多个参数，如行数据的Key、显示的数据、已选中的数据、设置、分页参数等。此外，还提供了一个设置对象，用于配置是否显示已选择项表格、未选择项和已选择项所占页面比例、列表标签等。这是一个基础组件，其他需求需要自行添加和更新知识库。使用该组件可以方便地实现跨页面的数据选择和管理，提高了数据选择的灵活性和便利性。

http://192.168.1.14:5000/d/f/xLh3Mcs4RZlHl0yQJMn8YSdaa5q9JufW



## 常用的可视化组件Echarts组件的使用

Echarts是一个常用的可视化前端组件，特别是在医疗数据项目中，它能够直观地展示数据变化和占比。Echarts有多种图形形式，如折线图、环形图、表格背景的折线图和柱状图。引入和使用Echarts组件主要分为两步，首先通过npm安装Echarts，然后在组件中引入并初始化。关键的绘制方法是setOption，其中涉及许多属性配置，如tooltip、legend、grid和series等。option属性中的tooltip用于悬浮提示，通过点击或悬浮方式展示数据。环形图是一个很好的例子，通过radius属性设置内外半径，color属性设置颜色，data属性设置数据。总的来说，使用Echarts可以方便地创建各种形式的图形，为数据可视化提供强大的支持。

http://192.168.1.14:5000/d/f/xLh3UfJgsHbb9A3VGHFBNibKTjpYgfnX



## 常用自定义指令封装

在Vue.js项目中，开发者通过自定义指令封装了一些常用的功能。其中，`v-debounce`是一个防抖指令，用于防止按钮在短时间内被多次点击。它使用了防抖函数来限制规定时间内只能点击一次。另一个自定义指令是`v-permission`，用于自定义权限控制展示与隐藏。通过它，开发者可以根据权限值来控制DOM元素的显示与隐藏。这些自定义指令的使用简化了代码，提高了开发效率。
在项目中，开发者通过import语句引入这些自定义指令，并使用Vue.use()方法将其注册到Vue实例中。然后，在模板中通过v-debounce和v-permission指令将它们应用到相应的元素上。例如，在按钮元素上使用v-debounce指令可以防止用户连续点击按钮，而使用v-permission指令则可以根据权限值来控制按钮的显示与隐藏。
这些自定义指令的封装和运用，使得代码更加简洁、易读和维护。同时，也提高了开发效率和代码复用性。在实际开发中，开发者可以根据具体需求自定义更多的指令，以满足项目的各种需求。这些自定义指令可以大大简化开发过程，提高开发效率，使项目更加健壮和易于维护。

http://192.168.1.14:5000/d/f/xLh3SEJ5fdeEoCyHLnjrEkGJf7d2AeLU



## 高级查询组件 SeniorQuery 

CRM PC端高级查询组件SeniorQuery，支持多种查询条件和表单组件，如文本框、数字输入框、下拉选择、日期picker和remoteSelect等。该组件还允许用户保存定制的查询方案，并可扩展更多组件。为优化方向，应将获取数据方法作为props传递，并将用户定制的查询方案保存在localStorage中，以实现脱离后端独立使用。在父组件中使用时，需传入columnList、searchParam、selectedColumn等属性，并监听search事件。

http://192.168.1.14:5000/d/f/xLh3Nf1PqG0F4KfMrJlVPGSMt5qPvO6n



## 前端分片上传组件

用于文件分片上传。开发者需在main.js中注册上传器或在单页面引入。上传成功后，可使用ref获取文件。此外，该组件支持头像上传和word文档预览编辑等功能，需配合相关组件使用。

http://192.168.1.14:5000/d/f/xLh3PBGF1qzbpLixPMb1PS5PJZIPkhaF



## 强大的查询组件帮你方便找到目标信息

强大查询组件，方便查找目标信息。支持多条件筛选和模糊查询，导入组件库后可在vue中使用。默认配置及说明详见效果图。

http://192.168.1.14:5000/d/f/xLh3SnvkUovOthqVutqEW8Y05WNcCctq



## 扫码枪组件

扫码枪组件通常是一种用于处理二维码和条形码数据的软件组件。它可能是一个独立的模块，也可以是集成在更大系统中的一个部分。这个组件的主要功能是通过扫码枪设备读取二维码或条形码，然后将读取的数据进行处理，最后返回给系统或页面需要的信息。

http://192.168.1.14:5000/d/f/xLh3QMmLj8wUf1nv7nWNZXf93cvncZ1C



## 使用Vite+Ts+Pinia打造的Vue3的后台解决方案

使用Vite+Ts+Pinia打造的Vue3后台解决方案，地址为http://www.rzdata.net:82/yuyi/ViteX💡。项目技术栈包括Vue3、Vite、TypeScript等，正在快速迭代中，期待贡献。

http://192.168.1.14:5000/d/f/xLh3OLbFM1WHayXTLJmuNtBD63df5ipu



## Apache ShardingSphere JDBC 分库分表插件

Apache ShardingSphere 是一款开源的分布式数据库解决方案套件，它提供了数据分片、读写分离、分布式事务和数据库治理等功能。ShardingSphere JDBC 是其 Java 语言的轻量级解决方案，它可以在 Java 应用中以 JDBC 驱动的形式提供数据库分片、读写分离等能力。

分库分表，也称作数据分片，是 ShardingSphere JDBC 的核心功能之一。通过将数据水平拆分到多个数据库或多个表中，可以有效地解决单一数据库的性能瓶颈、存储容量限制以及高可用性等问题。

http://192.168.1.14:5000/d/f/xLh3HzkoMO2Pi2heN0QEiUBs0Lkh0Nj3



## redis分布式锁工具

Redis分布式锁的实现主要依赖于Redis的SETNX命令。SETNX命令的功能是尝试将一个键值对插入到Redis中，如果键不存在则插入成功并返回1，如果键已存在则插入失败并返回0。利用这个特性，我们可以将锁的信息存储到Redis中，从而实现分布式锁。

具体来说，当需要获取锁时，我们向Redis发送一个SETNX命令，尝试将一个代表锁的键值对插入到Redis中。如果插入成功，说明我们获取到了锁，可以执行后续的任务。如果插入失败，说明锁已被其他节点获取，我们需要等待或者尝试获取其他锁。

为了避免死锁的发生，我们还需要设置锁的超时时间。当锁被获取后，如果在一定时间内没有被释放，那么Redis会自动删除该锁，从而避免死锁的发生。

http://192.168.1.14:5000/d/f/xLh3KYiBDAhkSRm5ENJ9bJ2ILVDZCM86



## vue+springboot前后端合并部署,分离开发

cro-ui后端组件是一个集成了Vue.js的前端工程，通过Maven进行构建和打包。该工程采用了Spring Boot进行后端开发，实现前后端分离部署。在代码结构上，保持了清晰的结构，使前端代码成为整个工程的一个模块。为了实现自动编译Vue工程，需要配置相应的POM.xml文件。同时，为了解决404提示问题，需要配置访问首页或默认页面的路径。此外，还需设置匿名权限以保护资源安全。整个工程通过合理配置和组织代码结构，实现了高效开发和维护。

http://192.168.1.14:5000/d/f/xLh3IbeGE61Yf0OaIcwqCcNl86wwSI6C



## Zebra网络打印

该文主要介绍了如何安装和使用Zebra网络打印的相关步骤。首先需要安装Maven，并在项目的pom.xml中添加Zebra网络打印的依赖项。其次，需要添加Zebra的工具类，并导入相关类库。最后，可以使用ZebraUtil类中的静态方法来连接打印机并打印内容。在ZebraUtil类中，定义了打印机端口和连接打印的方法，其中printString方法用于连接打印机并打印指定语言的字符串。需要注意的是，连接打印机可能会抛出ConnectionException异常，因此需要在方法声明中声明该异常。同时，在连接打印机后需要调用close方法来关闭连接。此外，该文还提到了Zebra网络打印的相关知识库和平台，可以进一步了解该技术。综上所述，本文介绍了如何安装和使用Zebra网络打印，以及相关的工具类和异常处理等内容。

http://192.168.1.14:5000/d/f/xLh3FfGz9IFtqdMSGGWOWkJR5H2slISP



## 国际化工具

该文档主要介绍了在Spring Boot项目中实现后端服务的国际化的过程。为了支持不同语言的用户，需要在项目中实现国际化。具体步骤包括：在resources文件夹中新建一个i18n文件夹，修改application.yml配置，创建SpringUtil类，增加配置类从请求头获取多语言关键字，创建I18nUtils工具类以获取message，并进行测试。测试时，可以设置请求头的lang参数为特定语言，例如zhTW，或通过携带参数形式进行测试。
总结来说，该文档提供了在Spring Boot项目中实现后端服务国际化的详细步骤，包括创建文件夹、配置文件、工具类等，以及进行测试的方法。通过这些步骤，可以确保项目能够适应不同语言的用户，提供正确的信息。

http://192.168.1.14:5000/d/f/xLh3LIGnab20i3ZQ9uUZ2V4N7EHJOMp5



## 后端常用工具类梳理

**1. Hutool**

Hutool是一个Java工具包，它提供了许多实用的工具类和方法，帮助开发者提高开发效率。Hutool的设计哲学是“简单、易用、全面”，它旨在减少开发者的重复劳动，并提供稳定、可靠的工具类。

**2. Commons**

Apache Commons是Apache软件基金会提供的一系列Java工具类库。这些库提供了许多实用的功能，帮助开发者解决常见的编程问题。

**3. Guava**

Guava是Google开发的一套Java核心库，提供了许多Google内部广泛使用的工具类。这些工具类可以帮助开发者编写更高效、更简洁的代码。

总的来说，Hutool、Commons和Guava都是后端开发中常用的工具类库。它们各自有着独特的特点和优势，开发者可以根据自己的需求选择合适的工具类库来提高开发效率和代码质量。

http://192.168.1.14:5000/d/f/xLh3K4uIYJFsv6todm7NdiAOUtgiYxul



## 基于SpringBoot Starter机制开发后端组件

SpringBoot Starter机制是一种简化Spring应用构建的快速入门方式，通过定义自己的Starter类可以实现应用的自动装配和初始化。在项目中创建自定义Starter类通常是为了提供特定的功能集或解决特定问题，开发流程包括创建属性配置类、服务提供类、配置自动装配类、编写spring.factories文件等步骤。通过Maven打包到私服并清除本地仓库的相关jar包后，即可成功使用自定义Starter机制构建Spring应用。

http://192.168.1.14:5000/d/f/xLh3JIeURGdzWmuIjVmKN00GM5pYm9d2



## 微服务技术选型

项目需采用微服务技术框架，以满足技术规范要求。选型需遵循开放API、松耦合、自治、无状态、多版本兼容等原则。微服务拆分应遵循单一职责、高内聚低耦合、演进式拆分等原则，避免环形依赖与双向依赖，拥有独立数据库。总体框架选型包括Spring Cloud和Spring Cloud Alibaba，前者是服务治理平台，提供了全套分布式系统解决方案，后者是阿里巴巴的微服务解决方案。技术框架落地需进一步细化，以满足项目的具体需求。

http://192.168.1.14:5000/d/f/xLh3GSEn5VQKCx2mKBciuYt8In0NUDmm



## 消息发送API接口说明

本文档旨在详细说明消息发送API接口的使用方法和注意事项。通过阅读本文档，您将了解如何调用API接口，发送消息，以及处理相关的请求和响应参数。

http://192.168.1.14:5000/d/f/xLh3H2r2rvRuLORoB3TauMp4yn7swrbE



## vue单元测试操作说明

Vue单元测试操作说明涵盖了Vue Test Utils和JEST的相关概念和使用流程。Vue Test Utils是Vue.js官方的单元测试工具库，提供了多种实用的测试工具。JEST则是常用的JavaScript测试框架，具有零配置、快照、隔离和优秀API等特点。使用流程包括安装依赖、编写jest配置文件、编写启动文件、加入启动jest的npm script等步骤。
在搭建基于JEST的Vue单元测试环境方面，需要安装依赖、编写jest配置文件、编写启动文件和加入启动jest的npm script。常用的断言语句包括expect和toBe等。这些工具和框架为开发者提供了便利的测试手段，有助于提高代码质量和可靠性。

http://192.168.1.14:5000/d/f/xLh3g85Gbnb9UUwFion9OGHmSeMuOh1o



## vue单元测试示例

Vue单元测试示例提供了一个全面的测试方案，涵盖了JS工具类、按钮、Props和计算属性等方面的测试。测试案例清晰地描述了如何使用Vue Test Utils进行单元测试，包括定义测试套件、测试用例和断言的判断条件。其中，工具类JS的测试是为了保证其准确性，避免影响调用方的正常使用。通过选择定义测试所需常量，编写各个测试用例逻辑，可以全面验证工具类JS的功能。此外，测试按钮、Props和计算属性也是必不可少的环节，以确保组件的正常运行和准确性。该示例不仅提供了详细的测试步骤，还通过举例进一步说明了测试方法的应用。通过遵循这些测试案例，开发者可以更好地进行Vue组件的单元测试，提高代码质量和可靠性。

http://192.168.1.14:5000/d/f/xLh3fR52OwVd5vQ3eIroHjeS012SvWSd



## 单元测试代码编写教程（Java）

1. 安装JUnit

2. 编写测试类

3. 编写测试方法
4. 运行测试

http://192.168.1.14:5000/d/f/xLh3do1q5mIt477mfbdRIXNRro7VDZOX



## 单元测试示例

单元测试是软件开发中至关重要的一环，而JUnit是Java中常用的单元测试框架。在JUnit中，有多个注解可用于控制测试的执行流程，如@BeforeClass、@Before、@Test、@After和@AfterClass等。这些注解可以帮助我们更好地组织和管理测试代码，确保每个测试方法都能在干净的环境中运行。此外，JUnit还提供了超时测试和套件测试等功能，帮助我们更好地管理复杂的测试场景。对于需要测试的Controller，我们可以通过模拟请求和响应来测试其功能。对于异常测试，我们可以故意触发异常并验证其处理方式。最后，事务控制可以帮助我们在测试中保持数据的一致性。总之，编写好的单元测试代码需要综合考虑多个方面，包括测试流程、测试数据、异常处理和事务控制等。只有通过不断地实践和积累经验，才能写出更加健壮和可靠的代码。
可以参考下面的提问方式：

http://192.168.1.14:5000/d/f/xLh3egFDwB0rfNu0zW8U8G0a8HyUwYLX



## Eslint检测规则

ESLint 是一套开源的 JavaScript 代码检查工具，可以帮助开发者自动检测代码中的错误和不规范的写法。在 ESLint 中，可以通过配置规则来强制要求开发者遵循一定的编码规范。

这些规则可以帮助开发者编写更加规范、易于维护的代码，提高代码质量。同时，ESLint 还支持自定义规则，可以根据项目需求来制定更加具体的编码规范。使用 ESLint 可以有效地减少代码中的错误和漏洞，提高代码的可读性和可维护性。

http://192.168.1.14:5000/d/f/xLh3XQToJqhhs8prgyRDVshDIBOJh1vw



## IntelliJ IDEA阿里编码规约插件安装和使用

随着软件行业的不断发展，代码规范的重要性日益凸显。阿里巴巴Java开发手册作为业界知名的编码规范，为开发者提供了详尽的编码指导。为了方便开发者在编码过程中遵循这些规范，阿里巴巴为IntelliJ IDEA开发了一款编码规约插件。本指南将详细介绍该插件的安装和使用方法。

http://192.168.1.14:5000/d/f/xLh3Wi3aSfpuxxkVN4b2h1yxPNOtjMG4



## sonarlint插件安装 

在软件开发过程中，代码质量是保证项目成功的关键因素之一。SonarLint是一款强大的代码质量检查工具，它可以集成到各种主流的开发工具中，如IntelliJ IDEA、Eclipse等。通过安装SonarLint插件，开发者可以在编写代码的同时实时检查代码质量，从而及时发现并修复潜在的问题。本文将详细介绍SonarLint插件的安装和配置过程。

http://192.168.1.14:5000/d/f/xLh3Y2erJbLcaJCs8kqk7tZOztpNkM2S



## vue-test-utils wrapper方法总结

Vue-test-utils的wrapper方法是一组用于模拟和测试Vue组件的工具。这些方法提供了对DOM节点属性和类的访问，销毁组件实例，获取自定义事件对象以及判断Wrapper或WrapperArray的存在性等功能。Wrapper方法还提供了一些查找和设置组件属性的方法，例如findComponent和setProps。在使用这些方法时，需要确保导入相应的模块，并按照Vue组件的结构进行测试。例如，使用mount方法挂载组件，然后使用wrapper方法来获取对DOM节点或Vue实例的引用。通过这些引用，可以方便地测试组件的行为和状态。总的来说，Vue-test-utils的wrapper方法是Vue组件测试中非常有用的工具，它们可以帮助开发者更轻松地编写测试用例，确保组件的正确性和稳定性。

http://192.168.1.14:5000/d/f/xLh3a5FxKXhtceFJcXOO72W20LnIzm5f



## vue代码检查工具操作说明

Vue.js是一个流行的前端框架，用于构建用户界面。在开发Vue应用时，代码质量和一致性非常重要，这可以确保代码的健壮性、可维护性和可读性。为了实现这一目标，开发者通常使用代码检查工具，来检查代码中的潜在错误和不一致之处。

ESLint是一个广泛使用的JavaScript代码检查工具，也可以用于Vue代码的检查。ESLint可以帮助开发者识别和修复代码中的问题，遵循一致的编码风格，并确保代码符合特定的质量规范。

http://192.168.1.14:5000/d/f/xLh3Z8vO6C6orW3uhtmZrGJ508coIHX9



## 单元测试规范 

单元测试规范包括范围、工具、覆盖率和规约。后端使用Junit5，前端使用Jest。覆盖率要求70%语句覆盖率，100%核心模块覆盖率。规约参考阿里Java开发手册。

http://192.168.1.14:5000/d/f/xLh3VYoGoIXiDBmsdRuIP9l0WnDGx8JW



## 功能测试用例设计原则及测试方法

测试用例设计是软件测试中的重要环节，需要遵循三大原则：明确性、代表性和可判断性。明确性要求用例描述清晰，结果唯一；代表性则要求用例能够覆盖各种场景，包括正常和异常情况；可判断性则强调测试执行结果的正确性可判定。测试用例的主要构成因素包括用例ID、测试功能模块、功能点、测试标题、前置条件、输入数据、操作步骤、预期结果和实际结果。常用的用例设计方法有等价类分析法、边界值分析法、场景法等。其中，等价类分析法根据需求文档，将所有可能的输入数据划分成若干部分子集，然后从每个子集中选取具有代表性的数据作为测试用例；边界值分析法则针对输入或输出的边界值进行测试，通常作为对等价类划分法的补充。在测试方法上，常用的有黑盒测试和白盒测试。综上所述，一个完整的测试用例设计需要综合考虑以上各个因素和方法，以确保软件测试的全面性和准确性。

http://192.168.1.14:5000/d/f/xLh3W70vz9CTtDhdrgPq447crc7NGqGz



## 如何编写测试用例 

1. 确定测试范围和目标：根据版本描述确定测试范围和目标，以便更好地安排测试计划和资源。
2. 收集整理测试所需资料：根据版本中描述的需求和功能点，收集整理相关的需求文档、设计文档等资料，以便更好地理解测试对象和需求。
3. 设计测试用例：根据需求文档中的功能描述，梳理需要测试的功能点，并设计相应的测试用例，包括输入、操作步骤、预期结果等。
4. 确定测试环境与账号信息：根据需求文档中的要求，确定测试环境和正式环境的地址以及访问账号等信息，以便更好地进行测试。
5. 执行测试：按照设计的测试用例执行测试，记录实际结果并与预期结果进行比较，确保软件功能符合需求并能够正常工作。
6. 跟踪问题：在测试过程中发现的问题需要及时跟踪并修复，确保软件质量得到保障。
   通过以上步骤，可以编写出完整的测试用例并保证软件质量。

http://192.168.1.14:5000/d/f/xLh3c8HS2br3QjZDmar0RvKiqPxA0qCQ



## 质量管理规范

这是一份关于质量管理的规范文档，主要目的是确保后台接口服务的测试质量。文档涉及范围、引用文件、工具和技术、组织分工等相关内容。文档详细说明了代码审查和单元测试的评分标准，包括代码是否符合开发规范、单元测试代码覆盖率等。该文档由技术中心编写，归属部门为技术中心，文档版本号为V1.0。

http://192.168.1.14:5000/d/f/xLh3ap6Aq2FTjhbpE4twXkJjiLkfB9LX



## 项目DevOps禅道配置操作说明 

配置指南：1. 设置有权访问源码的用户。2. 提交代码时填写注释，需为纯文本。格式示例：Start Task #1,2 Cost:1h Left:3hFinish Task #1,2 Cost:10hEffort Task #1,2 Cost:1h Left:3hFix Bug #1,2。

http://192.168.1.14:5000/d/f/xLh3hIbmLVt5XKGWKew6kpmBWq9nTazL



## workflow-流程中心（ASP-124794）

http://192.168.1.14:5000/d/f/xLh9AY6DHkkufzIbEVjwXdILMuKRQruM



## Workflow-设计文档

http://192.168.1.14:5000/d/f/xLh99rEmdvkTuc6IXo0GXcH41Ck5hOwF



## 实名共享审核交互设计-客户端

这是一个关于实名共享审核交互设计的说明文档。当用户共享文件或文件夹时，需要提交给匹配的审核员进行审核。审核内容包括新增访问者、修改现有访问者权限和有效期等。审核员必须匹配文件密级才能进行审核，若没有匹配的审核员，则提示用户联系管理员。审核员只能查看待审核文件内容，不允许修改或删除。对于文件夹共享，涉密模式开关决定共享生效范围。此外，禁用恢复继承权限的共享操作会产生相应审核记录。该设计旨在规范文件共享流程，确保安全性和合规性。通过合理的交互设计，使用户能够方便地发起和查看共享，同时提高审核效率和准确性。这有助于保护企业数据安全，减少风险，提升管理效率。

http://192.168.1.14:5000/d/f/xLh9CK5mCUWwi0iJZn9w8sQdKTM4YBuD



## 实名共享审核交互设计-控制台

爱数实名共享审核交换设计-控制台设计及管理控制台-操作日志

http://192.168.1.14:5000/d/f/xLh9BOknvNXpD9WLLEBZFzR72JrEcTJx



## Anyshare Family 7 安装手册

AnyShare Family 7的定位是：数字化时代的生产力平台，释放非结构化数据无限潜能。作为一款全新的企业内容管理平台，利用AI和云计算技术作为其系统架构和核心技术能力，它是为每一个组织专程而打造的智能内容云。

http://192.168.1.14:5000/d/f/xLh9MkZCxjf3RIsl5yx7gKT41wGvfWSf



## AnyShare产品部署过程文档

本文档旨在详细阐述AnyShare产品的部署过程，包括必要的步骤、可能遇到的问题以及相应的解决方案。通过本文档，读者可以全面了解AnyShare产品的部署流程，从而顺利完成产品的安装与配置。

http://192.168.1.14:5000/d/f/xLh9Gw4dkpHdHdi5t9GHAg4JJa409ziH



## workflow应用32部署手册

第一步：更新代码

第二步：上传压缩包到爱数远程桌面

第三步：将代码上传至GitLab

第四步：构建镜像

第五步：更新workflow

http://192.168.1.14:5000/d/f/xLh9GGdClJXokvSO3NakgZjaUJNHAKpd



## workflow应用162部署手册

"Workflow应用162部署手册"是一份详细指导如何在特定环境中部署Workflow应用162的文档。它旨在帮助用户顺利完成应用的安装、配置和验证，确保应用能够正常运行并达到预期效果。

http://192.168.1.14:5000/d/f/xLh9LMz9F4YwtdTn6KuYPk6yn4U71f9Y



## workflow应用171部署手册

1. 下载压缩包：登录200服务器，切换到相应目录，下载压缩包。
2. 上传到171服务器：先上传压缩包到爱数云盘，再登录爱数远程桌面，下载到171服务器上。
3. 卸载安装包：切换到特定目录，全新部署可忽略此步骤，否则先执行卸载命令。
4. 配置服务通信：切换到特定目录，在配置文件中添加相应内容。
   以上步骤涉及多个目录和命令，需要仔细执行。部署过程需谨慎操作，遵循相应命令和流程，以确保产品成功部署。

http://192.168.1.14:5000/d/f/xLh9JFqT91aNKuwqRENXh2KPCSAZ2gid



## workflow应用200部署手册

1. 切换至 homeworkflow-deploy-200 目录，创建 workflow-service 目录。
2. 在 workflow-service 下建 image 和 charts 文件夹。
3. 将镜像文件移至 image，将 4 个 chart 包移至 charts。
4. 打包 workflow-service 目录，保存为压缩格式安装包。
5. 切换至 sysvolapphomeappThriftAPIgen-py-tmpDeploy 目录，执行安装命令。

http://192.168.1.14:5000/d/f/xLh9JzXt5USpOIhU5zRFpf5lXGXBlPnF



## Anyshare运维命令

该文主要介绍了在Anyshare运维中，通过执行相关命令来查看各个服务的日志、进入数据库、查看NSQ和Redis，以及查看所有服务状态。具体操作包括使用kubectl logs命令查看Workflow各个服务的日志，使用kubectl exec命令进入特定容器，使用mysql命令进入数据库，使用curl命令查看NSQ状态，以及使用kubectl get pods命令查看所有服务的状态。

http://192.168.1.14:5000/d/f/xLh9M28z6WlE7aMqs3Gnamkf7ATZ5QRv



## Dev Ops构建



http://192.168.1.14:5000/d/f/xLh9IUj3YEauBmWZUD39gwHrateImHFY



## Anyshare Family 7 - 4.0安装手册

这是一个关于安装和配置平台的说明。首先需要准备环境依赖，然后安装Anyshare Server模块。接下来创建Kubernetes集群，激活Anyshare Server并重启系统。之后配置Eceph对象存储，并部署服务如workflow服务。最后参考Helm和Kubernetes指南等参考资料

http://192.168.1.14:5000/d/f/xLh9KovHdFG1fSbdbB4gmSADLsGc6NDt



## Workflow分支管理

页面详细介绍了版本管理的分支管理策略，包括分支类型、命名规范、创建与合并信息。主要有三种分支类型：主线代码的Mission分支、功能开发的Feature分支和版本发布的Release分支。其中，Mission分支只提供拉取，不进行实际开发；Release分支用于产品版本测试，每个版本一个Release分支；Feature分支则是需求开发的功能分支，功能开发完成后合并到Develop分支。此外，还列举了工程分支概况，包括各个工程的主干分支、需求分支和版本分支。例如，Feature-ASP-13555代表爱数的需求编号，Hotfix-ASP-13913代表爱数的bug编号，Release-MISSION-Console-7.0.1中的MISSION-Console是版本发布常量值，7.0.1为版本号。总结：该页面为版本管理提供了清晰的分支管理策略，有助于提高代码质量和团队协作效率。

http://192.168.1.14:5000/d/f/xLh9EziibFRt83ZLYItamxFLR0tZOqXq



## 爱数workflow开发流程

该项目涉及相关环境地址、版本分支管理参考和开发部署流程。相关环境地址包括anyshare桌面云、anyshare文档云、anyshare管理控制台和anyshare客户端，提供了相应的链接和用户名密码。版本分支管理参考为workflow版本分支管理。

http://192.168.1.14:5000/d/f/xLh98SNWpyMZOFc3CvOPhIhKIMwqiQ2E



## 公司虚拟机环境



http://192.168.1.14:5000/d/f/xLh999Nl2pm6LaBrLruuVOcOTCQkq4BB



## 2021年4月CRM项目质量审计报告

POM项目在设计和上线阶段存在严重问题，包括缺少设计文档和上线方案评审报告。建议先编写详细设计文档再进行评审，上线方案需进行评审并提交评审报告。需改进以确保项目质量。

http://192.168.1.14:5000/d/f/xLh8wxCMUmicKRZIEIa0ytEAVqhzBkC6



## 2021年3月CRM项目质量审计报告

设计阶段存在文档不规范问题，编码阶段有大量BUG和安全漏洞，上线阶段变更缺乏方案。需采取相应措施整改，确保项目质量。

http://192.168.1.14:5000/d/f/xLh8u554N4FwGtN3gBZkfKsoNIms5STd



## crm系统代码重构方案

此方案旨在全面优化CRM系统的代码结构，提高系统的性能、可维护性和可扩展性。通过现状分析，识别现有代码中的问题，如代码冗余、逻辑混乱等。然后，采用分层架构、模块化设计等方法，对系统进行重构。在重构过程中，注重代码优化和性能提升，确保重构后的系统更加高效。同时，制定详细的重构计划和风险评估措施，确保项目的顺利进行。最终，通过质量保证和持续维护，确保系统的稳定运行和持续改进。

http://192.168.1.14:5000/d/f/xLh8uovHsasFwGeU927xcAvQtsP9dAwb



## CRM代码审查记录

1. **类名定义不规范**
2. **文件存放位置不一致**
3. **Spring管理的Bean使用不恰当**
4. **相同物理表对应的实体类重复定义**
5. **SQL语句分散在Java代码和XML文件中**

http://192.168.1.14:5000/d/f/xLh8xry8WEJKY5vm2Goqb3Y6WSMH4sG7



## 客户项目管理

客户项目管理页面针对南京诺唯赞集团行业行销部的办事处技术支持、产品支持和产品中心主管三个角色。各角色拥有不同的功能和数据权限，以区分不同产品线的业务需求。业务模型对不常修改的查询字段进行冗余存储，接口默认传递header参数，并返回与CRM一致的参数结构。此方案旨在满足不同角色在业务操作和数据权限上的需求，提高业务处理效率和数据安全性。

http://192.168.1.14:5000/d/f/xLh8sWHr0sqpiIReeLZJ1gPx5hQ2g5O9



## CRM系统详细设计说明书-订单2.0

本文描述了一个复杂的订单处理流程，涵盖了从订单提交到出库的多个环节。流程中涉及到多种条件判断、数据验证和操作，包括选择客户类型、判断预付款、使用优惠券、低价审批、缺货通知、合规验证等。在订单提交和出库环节，系统需要验证销售员在职状态、库存情况，并处理特殊情况如预付款订单、禁销产品等。此外，流程还涉及出库单的创建、更新、删除等操作，确保出库数量与应发数量匹配，并进行相应的状态更新和编号设置。该流程旨在确保订单处理的准确性和效率，满足客户需求，同时维护企业利益。

http://192.168.1.14:5000/d/f/xLh8rV86ZPn0t9BB73THLLukRX2Ssvcw



## 业务模块-活动服务

该模块包括多个业务模块，如活动服务。在Controller层，存在多个接口类，如ActivityclientController、ActivityClientscopController等，用于处理不同的功能。然而，一些类如ActivityContractController、ActivityController等的功能说明尚未补充。在service层，核心业务流程图和数据库主要表截图待后续补充。总体而言，该CRM模块的分析报告尚不完整，需要进一步补充和细化。报告主要关注了模块的拆解分析，但缺乏对各部分具体实现和功能的深入探讨。为了更好地理解和评估该模块，需要进一步完善报告内容，包括补充功能说明、业务流程图以及数据库表结构等。

http://192.168.1.14:5000/d/f/xLh93WWkAqbMyDERerGdnscrnT37USuT



## 产品模块拆解分析

通过对产品模块的拆解分析，发现主要分为四个部分：Controller、Service、核心业务流程以及定时任务接口。其中，Controller主要负责处理外部请求和提供接口，包括根据产品编码或id查询产品信息、发送产品到货和缺货消息等任务。Service层则主要负责业务逻辑处理和数据操作，例如获取订单未出库数据、循环查出来的订单数据、判断是否已有库存等。核心业务流程则是整个产品的核心逻辑，包括定时任务接口的实现，例如每天下午5点自动查询定制产品的发货提醒功能。整个产品模块的代码运行成功，功能齐全，能够满足用户的需求。此外，该模块还具有良好的可扩展性和可维护性，方便后续的开发和维护。综上所述，该产品模块的拆解分析具有较高的价值和意义，为后续的开发和维护提供了良好的基础和保障。

http://192.168.1.14:5000/d/f/xLh8yd5Y73aDMHCotS4rx9hXsWJAZiFP



## 合同服务拆解分析

本次合同服务拆解分析主要围绕合同的生命周期管理、合同内容、与订单服务的关联、合同管理工具与系统以及优化建议等方面进行了详细的探讨。通过对合同服务的全面分析，我们发现合同管理在企业的运营中扮演着至关重要的角色，它不仅关系到企业的经济利益，还涉及到企业的法律风险。

在合同生命周期管理方面，我们梳理了合同的起草、审批、执行、变更、终止以及归档等关键环节，强调了每个环节的重要性和注意事项。在合同内容方面，我们深入分析了合同的基本信息、附件与补充协议、价格清单与支付方式、双方责任与义务等核心要素，以确保合同内容的完整性和准确性。

此外，我们还探讨了合同服务与订单服务之间的关联，明确了合同与订单的关系以及合同履行过程中的注意事项。同时，我们还对合同管理工具与系统进行了评估，提出了改进建议，以提升合同管理的效率和准确性。

最后，我们针对合同管理流程、合同内容、合同管理系统以及风险管理等方面提出了具体的优化建议和改进方向，以期为企业提供更好的合同服务支持，降低风险，提高运营效率。

http://192.168.1.14:5000/d/f/xLh92JAF8XSTr0Jerc59DJ2RdYJTNJvk



## 客户服务拆解分析

根据所提供的页面内容，韩健对CRM模块进行了拆解分析，包括功能描述、代码运行截图、核心逻辑、数据库设计和接口说明。从表格中可以看到，涉及到的类地址、类名、类说明、序号、请求方式和相关方法等信息都进行了详细的列示。这些信息涵盖了从单个客户对象的新增到批量确认集团客户等不同功能的实现。
总结来说，该页面内容主要围绕CRM模块的拆解分析展开，涉及到了模块的各个方面，从功能描述到接口说明都有所涵盖。通过这些信息，可以更全面地了解CRM模块的设计和实现细节，为后续的开发和维护提供有价值的参考。同时，也展示了韩健在拆解分析方面的专业能力和经验，为相关人员提供了一个良好的学习范例。

需要注意的是，由于表格中存在一些空缺的信息，如部分方法地址和方法说明缺失，可能会对全面理解整个CRM模块的功能和实现造成一定的影响。因此，在实际应用中，还需要进一步完善和补充相关信息，以便更好地支持业务需求和系统稳定性。



http://192.168.1.14:5000/d/f/xLh94wnzd6OdRUGo1DHjvln6hkD4rjPk



## 接口服务拆解分析

本文档旨在对“接口服务拆解分析 - 项目管理库 - 知识库管理平台”进行详细的描述和分析。通过对各个接口的详细拆解，让读者能够更深入地理解该平台的架构和功能，并为后续的开发和维护提供参考。

该平台提供了一系列RESTful风格的API接口，用于实现项目管理库和知识库管理平台之间的数据交互。接口主要包括用户管理、项目管理、文档管理、版本控制等功能。

http://192.168.1.14:5000/d/f/xLh92r5JBLoUGsIotdARWfBKBfbAibdM



## 日志模块拆解分析

日志模块拆解分析功能描述：支持大数据量，支持mysql、elasticsearch。接口日志、操作日志、浏览日志和业务日志，使用springboot 2.6.9和sharding-jdbc 5.1.0技术栈。

http://192.168.1.14:5000/d/f/xLh90hOEuPvC8ImjrJT1Au8Sf7MEDQii



## 消息服务拆解分析

该CRM模块的拆解分析详细描述了消息服务的核心逻辑和数据库设计。它通过按月分表持久化到MySQL，利用状态区分实现快速发送。第三方接口调用后，数据存储至消息记录表，并轮询查询未推送数据进行推送，采用线程池异步处理。整个设计考虑了租户和应用的维度，支持短信、邮件和企业微信等多种消息发送方式。

http://192.168.1.14:5000/d/f/xLh94G5MYJuX7tt47sGSpmlKshyKt30Y



## 知识库模块拆解分析

该文档主要对CRM模块进行了拆解分析，涵盖了功能描述、代码运行截图、数据库设计和核心接口说明。其中，功能描述部分详述了如何通过思维导图模式具象化输出复杂的业务逻辑场景，并支持知识树的导入/导出功能。核心接口说明则列举了与知识地图节点和知识树操作相关的API类及其对应的API接口、URL地址和功能说明。这些接口类包括KFieldsController、KMapController等，提供了如根据节点编号查询表单集合、根据节点id查询节点及扩展信息、获取和保存全部知识树和约束表单、导入/导出excel和xmind文件等功能。
总之，该CRM模块的设计旨在提供一个功能强大的知识管理平台，帮助用户更方便地管理复杂业务逻辑场景的知识，并通过思维导图和导入/导出的功能提供高效的知识整理和使用体验。

http://192.168.1.14:5000/d/f/xLh96EZHBJ5cG5aREILYGyD0V2IqAHOq



## 第三方对接模块拆解分析

该文档对CRM模块的第三方对接进行了拆解分析，包括功能描述、代码运行截图、接口说明、核心业务流程图和数据库等方面。其中，功能描述部分提到了管理与第三方对接、公开CRM内部接口给有赞商城调用，以及封装调用WMS、SAP、CMS接口的功能。接口说明部分则详细列举了CMS接口、SAP接口和WMS接口的具体类地址、类名、类说明、请求方式、方法地址、方法名及方法说明等信息。此外，文档还提到了代码运行截图、核心业务流程图和数据库等方面的内容。

http://192.168.1.14:5000/d/f/xLh8z7B1tyTwMgR07LZaLm16O06vOZt9



## 统计服务拆解分析

该CRM模块具备全面的数据统计功能，覆盖客户、单据、部门和销售等多个维度。其包含的多个控制器类具备各种功能，如客户开拓进展、客户标签和贡献排名等。这些控制器类提供了一系列操作，如删除、批量保存、查询和导出等。此外，该模块还提供了订单看板和商品出库记录等实用功能。同时，它也处理逾期账款的相关操作，如导出、删除、查询和提醒等。

http://192.168.1.14:5000/d/f/xMaK5nnEdF7eT6rOg63P4abot10Hkefl



## 2021年4月POM项目质量审计报告

POM项目质量审计报告显示，运行阶段存在环境参数配置混乱问题，需求阶段缺乏详细的需求文档指导设计开发。建议严格区分不同环境配置，并补充需求文档，包括用例图、业务流程图等。

http://192.168.1.14:5000/d/f/xLh6LGwBaqoyNGO32eLiDJ8lRvC6r8tc



## 2021年3月POM项目质量审计报告

POM项目质量审计报告显示，设计、编码和上线阶段存在不同程度的问题。数据库设计文档未及时更新，功能详细设计文档不规范，代码存在大量BUG和安全漏洞，系统变更申请未放在指定目录且无评审记录。需采取相应措施，确保文档同步、格式规范、代码质量提高及评审记录完备。



http://192.168.1.14:5000/d/f/xLh6M0UnyJSGWjAgoFsUmfw1H4xewYX6



## 2021年3月质量整改计划

彭超负责质量整改计划，涉及数据库设计、功能详细设计、代码质量及系统变更管理。数据库设计文档需更新同步，功能详细设计需规范。代码存在BUG和安全漏洞，需审查工具整理问题清单并统一宣贯。系统变更申请需存放在指定目录并增加评审记录。负责人包括彭超、陈琳、朱君正。其中编号4已完成。

http://192.168.1.14:5000/d/f/xLh6NJg5AtePDhtLiZfzYRAiku5qqOV0



## 中烟零星需求项目

http://192.168.1.14:5000/d/f/xLh8mxyQDWY5wrTs2oNowEgwNiKAplwH



## 省委党校项目

http://192.168.1.14:5000/d/f/xLh9SYUZuut777stkTzHr2xetT2DGwKz



## 圣维尔LIMS实验室信息系统实施项目-设计文档

圣维尔LIMS实验室信息系统实施项目的设计文档详细地描述了该系统的数据库结构。从表格中可以看出，该系统包含了许多字段，如姓名、性别、出生日期、家庭住址、身份证号码等基本信息，同时也包含了检测结果、创建和更新时间、电子邮箱、手机号码等其他信息。
该系统还包含了一些特殊的字段，如采集点、采集模式、任务来源、区域和检测项目等，这些字段对于实验室的信息管理具有重要的意义。根据字段的类型，系统可以有效地存储和管理大量的信息，同时也能够保证数据的完整性和准确性。
通过使用该系统，实验室可以更加高效地处理和查询数据，提高工作效率。同时，该系统还具有高度的可扩展性和灵活性，可以根据实验室的需求进行定制和扩展。

http://192.168.1.14:5000/d/f/xLh6HON8qONBc0XasARTUVs55UeZ0ZwL



## 项目部署

http://192.168.1.14:5000/d/f/xLh6Gq1g6TEddmDtfdOGjQC01ggQJa8K



## 司法协助流程交互设计

司法协助流程交互设计页面提供了发起、查询、查看详情和流程监控功能。该设计包括司法协助流程列表的查询条件筛选、列表数据搜索和重置，以及流程详情展示。此外，还提供了发起司法协助流程的表单要素，包括调查单位、调查人员、协助事项、司法文书摘要、法律与改革部审查意见和备注等。提交表单后，系统会进行校验并弹出流程选人弹框，可选下一环节审核人员，点击确定后流程提交。该设计考虑了业务场景和逻辑，提高了用户体验和工作效率。

http://192.168.1.14:5000/d/f/xLh5rmdqi7smovdtppCOQszquNKWUDck



## 合同实例管理交互设计

合同实例管理交互设计是为了满足在项目管理库中对合同实例进行高效、便捷管理的需求。通过此设计，用户可以轻松创建、查看、编辑和管理合同实例，同时实现与知识库管理平台的无缝对接，提高合同管理的效率和准确性。

http://192.168.1.14:5000/d/f/xLh5uTXzCIipoPlKRrFErqmeEdyYxPNF



## 合同审核职能匹配交互设计

合同审核职能匹配交互设计旨在提高合同审批效率和完成形式审查到实质审查的转变。该设计能根据合同条款绑定的关联组织，智能筛选与匹配当前组织或岗位职责的合同条款内容。在交互设计中，智能匹配当前审核部门，进行高亮显示。对于指定了审核部门和职责的合同条款，此设计能显著提高审核效率和准确性。

http://192.168.1.14:5000/d/f/xLh5xPM41JKK9Zopqweg84rS6WsiVkr5



## 合同条款库管理交互设计

合同条款库管理交互设计需满足查询、新增、修改、删除操作功能。条款分为静态、动态和表单类型，合同管理员可对条款进行操作，不影响模板和实例条款。交互设计方面，合同条款列表支持多种筛选条件，如标题、内容、类型等，按更新时间降序排列，并分页加载数据。新增条款需填写标题、类型、业务类型和是否为通用条款，可选填内容、审核部门和职能说明。此外，还有编辑和删除条款功能。设计旨在提高合同条款管理效率和用户体验。

http://192.168.1.14:5000/d/f/xLh5yHQeJ3LvA8psm6WdhUazBxNa0e2Z



## 合同样式管理交互设计

合同样式管理交互设计是本次设计的核心部分，旨在提供便捷的管理功能，包括新增、修改、删除和下载合同样式。交互设计注重用户体验，界面简洁明了，便于操作。在合同样式列表中，若列表为空，则提示用户暂无数据；若列表不为空，则显示所有样式类型，分页显示每页10条记录，可切换分页。列表字段包括样式标题、样式类型、样式说明、样式文件、创建时间等，支持按样式类型筛选和搜索。筛选结果按创建时间降序排列，若无筛选结果则提示暂无数据。同时，提供样式标题的编辑和删除功能，编辑时需记录变更日志，便于追溯。在新增样式时，需填写样式类型、标题和说明，上传样式附件。编辑样式时，可修改样式信息。删除样式时，若该样式已关联合同模板则无法删除，否则提示确认删除。此外，交互设计还考虑了权限管理，合同管理员拥有合同样式管理的所有操作权限。若样式被合同模板引用则无法删除，需先解除绑定关系。编辑样式时需记录变更日志，便于追踪。同时，在合同模板名称过长或合同模板过多时，提供相应的显示和处理机制，确保用户体验的流畅性。综上所述，该交互设计为用户提供了全面、便捷的合同样式管理功能，注重用户体验和权限管理，确保数据的安全性和完整性。

http://192.168.1.14:5000/d/f/xLh608xOFTt9uZQamJaYMpncZVSxhdRu



## 合同模板版本管理交互设计

合同模板版本管理交互设计主要包括两个核心功能：查看合同模板的所有历史版本和查看各版本关联的合同实例。设计基于合同示范文本，将数据结构化存储，形成模板。当合同管理员修订模板时，会生成新版本并标记为待审核，审核完成后，系统将该模板标记为最新版本。管理员可以在历史版本列表中查看各个版本的关联合同实例。此外，还设计了合同已关联合同实例列表，支持按合同类型筛选，并可实时刷新筛选结果。列表还支持按合同名称和编号进行关键字搜索，提供【搜索】和【重置】功能。在交互设计上，对于模板标题和说明等信息，采用“...”显示方式，悬停时显示全部内容。历史版本列表分页显示，每页加载10条记录，可切换分页。列表默认按“创建时间”降序排列，并支持模板标题和创建时间搜索。对于已关联合同实例弹框，标题展现内容为当前查看的模板的标题。

http://192.168.1.14:5000/d/f/xLh5v2kFKNJn7hW3UVrxeYM5gYeU7FXL



## 合同模板管理交互设计

本交互设计文档涵盖了合同模板管理的功能简介、基本概念、业务场景、业务逻辑和交互设计。主要功能包括查询、新增、修改、删除和查看历史版本操作。合同模板是基于合同示范文本的结构化存储，合同实例是基于模板生成的合同对象。业务逻辑明确了管理员、起草人和审核流程的权限和操作规则。交互设计部分详细描述了合同模板列表的查询、筛选和显示方式，以及新增和修改模板的操作界面设计。整体设计考虑了用户操作便捷性和系统逻辑的合理性，旨在提高合同模板管理效率和用户体验。

http://192.168.1.14:5000/d/f/xLh5rFrBBa6kax60d2fFKoLTBIi8n3W0



## 法人授权审批流程交互设计

该流程支持列表筛选和查询，提供发起、查询、查看详情和流程监控功能。列表默认展示10条数据，可筛选代理人、申请人、申请部门和流程状态，并支持搜索和重置操作。流程监控信息可在新标签页中查看，详情展示各环节审批信息。发起流程需填写申请部门、日期、理由等，校验表单后提交。综合来看，该设计对业务流程进行了详细规划和描述，便于用户理解和操作，为提升用户体验和工作效率提供了基础。

http://192.168.1.14:5000/d/f/xLh5widQwWD1xtNrnZyrDB5UiXXB2IKD



## 法务信息发布管理交互设计

法务信息发布管理交互设计主要涉及平台首页设计、内容列表页、内容详细页、后台管理权限管理、管理员管理、角色管理、栏目管理、文章管理、静态化等内容。首页设计包括头部、正文部分和底部，展示站点logo、名称、导航栏目等信息。内容列表页和详细页分别展示内容标题、发布时间等信息和内容基本信息。后台管理权限包括管理员管理、角色管理等，管理员可新增、编辑或删除，角色可查询操作。栏目管理提供新增、删除等功能，文章管理可查询、新增、编辑或删除。静态化分为生成主页、生成文章和生成栏目三部分，根据模板生成html。交互设计使前台用户可查看已发布内容和栏目，提升用户体验。

http://192.168.1.14:5000/d/f/xLh60yTaMGrzAUTk3BMNET6h6Y32aYwx



## 法律咨询服务流程交互设计

该页面提供了法律咨询服务流程的交互设计信息。设计由王孝鹏创建，最后修改于2021年11月5日。交互设计包括流程列表的筛选、查询和操作功能，以及发起流程的表单要素和提交过程。列表支持材料名称和流程状态筛选，并可查询数据。点击流程监控按钮可查看详情，展示每一环节的审核人、审批意见和审批时间。发起流程时需填写材料名称、提请时间、申请部门和上传附件，并选择下一环节审核人员后提交。表单校验通过后弹出选人弹框，点击确定完成流程提交。

http://192.168.1.14:5000/d/f/xLh5szrYBIjuga0laFG4uKPF1Ti7gCX8



## 诉讼、仲裁案件审批流程交互设计

诉讼、仲裁案件审批流程交互设计旨在提供一个高效、便捷的流程管理工具，用于处理诉讼、仲裁案件的审批过程。该系统支持流程发起、查询、查看详情以及流程监控等功能，以满足不同业务场景的需求。

http://192.168.1.14:5000/d/f/xLh5vfdI9fqKq1kzmA5QCckQlkaVJj2A



## 重大决策事项风险评估简易程序流程交互设计

该文是一份交互设计文档，主要描述了重大决策事项风险评估简易程序流程的交互设计。该流程提供了发起流程、查询流程、查看详情和流程监控功能。交互设计详细描述了列表筛选条件、搜索操作、流程监控和流程详情展示等功能。发起流程表单中包括经办人、日期、决策事项基本信息等要素，表单提交时需校验表单并弹出流程选人弹框。总体来说，该交互设计文档为重大决策事项风险评估简易程序流程提供了清晰、详细的交互设计指导。

http://192.168.1.14:5000/d/f/xLh5ysc6LaPgcxFUZbdd3mICJfUrM4tF



## 重大决策事项风险评估论证报告审核流程交互设计

该报告主要介绍了重大决策事项风险评估论证报告审核流程的交互设计，包括功能简介、基本概念、业务场景、业务逻辑和具体的交互设计。交互设计部分详细描述了流程列表的查询条件和操作，如筛选事项名称、承办部门、支持流程状态等，并说明了发起流程的表单要素，如承办部门、负责人、讨论组成员等。此外，报告还提到了流程审批详情的展示内容，如审核人、审批意见和审批时间等。该设计旨在提供发起、查询、查看详情和流程监控功能，方便用户对重大决策事项风险评估论证报告审核流程的管理和监控。

http://192.168.1.14:5000/d/f/xLh5tdkBxRlf8OPoSbgHN99zlTGojEYn



## 222

页面描述了一个数据库表的设计，包括id、rev、category和name四个字段。其中id为主键，rev为版本号，category和name为流程命名空间和流程名称。

http://192.168.1.14:5000/d/f/xLh6A3vLZq6iqufuygiD07mooeTttVxp



## 合同实例管理实现设计

合同实例管理系统的设计稿详细介绍了方案的背景和实现过程。首先，设计稿明确了方案的背景，包括逻辑设计和交互设计。接着，它详细阐述了实现设计的过程，包括流程设计和数据库设计。最后，它讨论了变更可能产生的影响，并明确了影响范围。

http://192.168.1.14:5000/d/f/xLh6C8E2NZzeJ1ROJ4z0rPHp4gPrjmeG



## 合同样式管理实现设计

本文档主要介绍了合同样式管理的实现设计，包括方案背景、实现设计以及数据库设计。在方案背景部分，对合同样式管理的逻辑设计和交互设计进行了简要说明。在实现设计部分，详细描述了RESTful API的设计，包括新增、修改、删除和下载模板样式的接口描述、资源及方法以及面向的用户类型。此外，还提供了API文档和RESTful API的依赖信息。在数据库设计部分，新增了模板样式表HTJGH_TEMPLATE_STYLE，并详细列出了表中的字段、数据类型、空值情况、索引以及备注信息。同时，还新增了模板样式变更日志表HTJGH_TEMPLATE_STYLE_LOG，用于记录模板样式的变更历史。

http://192.168.1.14:5000/d/f/xLh6E9XwJItPqOblRY0rowYqZ2rAkyBI



## 合同模板管理实现设计

合同模板管理系统的设计实现涉及多个方面，包括方案背景、逻辑设计、交互设计、流程设计、数据库设计等。其中，流程设计包括新增、修改、删除、获取模板详情和分页获取模板列表等动作的接口设计。数据库设计部分暂未给出具体内容。此外，变更影响涉及影响范围的分析。该系统的设计旨在提高合同模板管理的效率和规范性，为管理员和普通用户提供便利的操作界面和接口。通过合理地规划和管理合同模板，有助于提高企业或组织的合同管理水平和降低潜在的法律风险。

http://192.168.1.14:5000/d/f/xLh69Q2hnhWLlHlqeEX1UogkXpUAge5S



## 合同正文转换管理实现设计

该文稿主要描述了合同正文转换管理的实现设计，包括方案背景、流程设计、数据库设计、变更影响等部分。其中，流程设计部分介绍了RESTful API的设计，包括动作、接口描述、资源及方法、面向对象等。数据库设计部分未提及。变更影响部分仅关注逻辑影响，除接口变更外，无其他影响。此部分仅关注逻辑影响。

http://192.168.1.14:5000/d/f/xLh6BeQ9ii8Jb7tEGD1i4Xg3gnhyTGDW



## 条款库管理实现设计

该文档描述了条款库管理逻辑设计和交互设计，包括流程设计和数据库设计。流程设计详细介绍了新增、获取、修改和删除条款的API接口，包括接口描述、资源及方法、说明和面向对象。数据库设计新增了条款库表HTJGHCLAUSE，包括字段CLAUSEID、CLAUSENAME和CLAUSETYPE等。该设计实现了合同模板引用的RESTful API设计，方便管理员和普通用户进行内部和外部操作。此外，该文档还提到了变更影响范围，但未具体说明。总体来说，该文档为条款库管理系统的实现提供了详细的逻辑设计和交互设计，有助于系统开发人员快速实现系统功能。

http://192.168.1.14:5000/d/f/xLh6DItLgF9F7hoV2y5TqCerI1DINOA1



## 法务信息发布管理实现设计

该文稿主要介绍了法务信息发布管理的设计和实现。首先，阐述了方案背景，包括逻辑设计和交互设计。然后，详述了实现设计，包括流程设计和数据库设计。流程设计部分，定义了查询、获取、新增、更新和删除等动作的接口描述、资源及方法和面向对象。数据库设计部分，新增了app应用表，并列出了字段变更，包括字段、数据类型、空、索引和备注等信息。总的来说，该文稿全面介绍了法务信息发布管理的设计和实现细节，为管理员和普通用户提供了清晰的接口和操作流程。

http://192.168.1.14:5000/d/f/xLh6GJNo8wkQYJ82isCvrNUbwQegdB3y



## 系统边界

系统边界合同结构化系统与中烟各系统关系明确，遵循不访问业务系统表和界面元素的规则，避免过度依赖。法务管理子系统独立，主要用于法务内容展现和发布、审批。合同结构化和法务子系统依赖于流程平台，用户中心与流程平台组织用户表集成。应用网关用于应用注册及访问、单点登录。容器云部署中烟环境，需提前申请。

http://192.168.1.14:5000/d/f/xLh6CjGgr4jExoeE5Quez97c0XLwx8xx



## 合同全生命周期数据流转的一致性管理逻辑设计

逻辑设计文稿关注合同全生命周期数据流转的一致性管理，旨在防范合同风险。该设计通过结构化数据流转，自动匹配前端与后端信息，确保数据一致性。

http://192.168.1.14:5000/d/f/xLh67kZussysVC0mAbJZEczJEbq9w0ma



## 合同实例管理逻辑设计

合同实例管理逻辑设计旨在实现规范合同过程精细化管理，为评估合同履约质量提供客观、准确、真实的依据。其主要功能包括：结构化实例模板关联管理，支持合同实例基本信息在线编辑；结构化实例条款排序管理，可对条款进行拖拽式排序；结构化实例供需方信息管理，自动带入相关信息；合同正文结构化实例在线编辑及审批管理，支持添加、删除及修改操作，并可锁定不允许修改的条款。通过这些功能，合同实例管理逻辑设计可提高合同处理的效率和准确性，满足不同业务场景的需求，降低合同风险。

http://192.168.1.14:5000/d/f/xLh61nZNlzFY00YVCRHOxItrhZSxhBUr



## 合同审核职能匹配管理逻辑设计

本文档主要介绍了合同审核职能匹配管理的逻辑设计，旨在实现合同审核流程的自动化和智能化。通过系统自动化匹配合同审核职能，确保合同审核的准确性和高效性，降低合同风险。设计逻辑涵盖了合同信息录入、审核职能匹配、审核任务分配、审核过程管理以及审核结果输出等关键步骤。同时，文档还涉及了技术实现和实施运维方面的考虑，包括数据库设计、系统开发、接口开发以及实施计划和运维管理等内容。通过实施这一逻辑设计，企业可以大大提高合同管理水平，优化审核流程，提升审核效率和准确性，为企业的稳健运营提供有力保障。未来，可以进一步优化系统的智能化程度，整合更多业务逻辑，实现更全面的合同管理功能。

http://192.168.1.14:5000/d/f/xLh63CQdZwKuZcZfUUDGadYCVFfwoZJd



## 合同条款库管理逻辑设计

合同条款库管理逻辑设计旨在提供合同文本条款的在线编辑、修订、参数配置、组织关联、分类与版本管理等功能。其中，静态条款管理包括数据展现及维护、合同关联管理和修改痕迹及日志管理。动态条款支持参数配置管理。在逻辑设计上，需先定义合同条款，并确保条款名称、类型和业务表单为必填项。动态条款支持参数配置管理，参数分为固定变量和扩展变量。删除合同条款对已实例化的合同条款不产生影响。此设计旨在提高合同管理的效率和规范性，为合同经办人和审核人提供便捷的操作体验和充足的业务信息提示。

http://192.168.1.14:5000/d/f/xLh66VnQCG6pVrvtKA1yy2coSvzBigco



## 合同样式管理逻辑设计

合同样式管理逻辑设计文档概述了需求分析和逻辑设计两个部分。需求分析部分主要介绍了合同样式模板分类管理、合同文本正文样式导出管理的功能需求。逻辑设计部分则从总则、模块关系、功能框架等方面进行了详细说明。其中，总则部分明确了合同样式管理的查询、新增、修改、删除、下载等功能，以及权限和编辑日志的记录要求。模块关系图说明了一个合同样式可以和多个合同模板进行绑定，但一个合同模板只能绑定一个合同样式的对应关系。功能框架图则对样式列表、新增样式、编辑样式、删除样式、下载样式和变更历史等功能进行了详细描述。其中，对于已绑定了合同模板的合同样式，无法直接删除，需在合同模板管理取消样式绑定后才可进行样式删除。此外，编辑样式修改附件后，会存在业务ID关联的多个样式文件，并可查看该行样式变更的历史样式附件信息。总之，该文档为合同样式管理系统的设计和开发提供了详细的逻辑设计指导。

http://192.168.1.14:5000/d/f/xLh67Afevd8UWezlvI96uURK4BEkkp2M



## 合同模板日志管理逻辑设计

合同模板日志管理逻辑设计旨在记录合同模板变更日志和痕迹化日志监控。合同经办人或管理员修改合同模板条款时，系统自动生成模板变更日志，记录变更时间、内容、操作人员和变更说明等信息。此外，在合同审核页面，针对有变更记录的合同条款会显示变更痕迹，默认展示最新变更。审核人员可通过查看痕迹了解合同正文变更内容。该设计提供了一个全面的合同模板管理解决方案，有助于提高合同管理效率和准确性。

http://192.168.1.14:5000/d/f/xLh62VZCw73vsFoBsE3xakKxi7kO9eM3



## 合同模板版本管理逻辑设计

合同模板版本管理逻辑设计文稿旨在统一管理合同模板，让管理员了解模板变化历程和内容。合同模板是基于示范文本的结构化存储，生成对应业务场景的合同结构化模板。合同实例则是基于模板生成的实际合同对象。业务逻辑说明中，管理员在修订模板时，修改并提交流程生成新版本，审核完成后标记为最新模板。管理员可查看历史版本及关联的合同实例。功能框架图显示了模板版本列表和已关联合同实例列表，查询条件多样，默认按时间或关键字等排序。此设计文稿为合同模板版本管理提供了全面的逻辑设计，包括需求分析、逻辑设计术语、业务逻辑说明、模块关系说明和功能框架图等部分，有助于实现高效、规范的合同模板管理。

http://192.168.1.14:5000/d/f/xLh68s7dkq8zea1xSgn5GelNgUAZ9m3i



## 合同模板管理逻辑设计

需求分析主要涵盖结构化模板的在线维护、分类管理、关联配置等。逻辑设计重点在于权限管理、模板保存与审核流程、数据删除、通用条款修改限制以及模板分类维护等。通过系统化管理，实现合同模板的规范化、高效化操作，提升合同生成效率与准确性。

http://192.168.1.14:5000/d/f/xLh659m9h07d8Hvfw70yL0Pg5sH4GJSI



## 合同正文转换管理逻辑设计

本文档详细描述了合同正文转换管理的逻辑设计过程，从需求分析到系统设计、实现和测试。该逻辑设计旨在实现结构化合同实例与非结构化合同文本之间的转换，以提高合同管理的效率和安全性。设计过程中，考虑了合同模板管理、合同实例生成、合同正文转换和合同加密解密等关键需求，并采用了分层架构和模块化设计。通过数据库设计、系统架构和模块设计等方面的细致规划，实现了合同正文的自动化转换和加密处理，确保了合同内容的安全性和可读性。在系统实现和测试阶段，对各个模块进行了单独的测试和集成测试，以确保整个系统的稳定性和可靠性。该逻辑设计为提高合同管理的效率和规范性提供了有力的支持。

http://192.168.1.14:5000/d/f/xLh63kdIkna7gQqdwWwzi9ZhQPTUC9Bs



## 法务信息发布管理逻辑设计

法务信息发布管理平台主要实现尊法、学法、守法、用法、制度保障、法治文化等板块的内容存储和发布功能，提升公司合同法务管理效率。平台支持在线发布文字、文档、视频等内容，并具备权限控制功能。业务流程图表明，该平台主要包括内容管理和权限管理，由管理员或具备对应权限的用户录入和发布内容，前台用户则可查看已发布的栏目和内容。

http://192.168.1.14:5000/d/f/xLh65lfbYhB32qoD19MGyyVKqvWcJPPz



## 系统管理-角色管理逻辑设计

该文档描述了一个系统的角色管理和权限控制逻辑设计。系统管理员可以在角色管理页面进行角色的新增、编辑、删除、导出，并与权限绑定进行业务控制。此外，系统还提供菜单权限和数据权限，可与角色绑定进行业务控制。该设计旨在为用户提供全面的权限管理功能，确保系统中的数据安全和访问控制。

http://192.168.1.14:5000/d/f/xLh68JmB0xTjGs1WmcxJVsdes5ToyPA7



## 综合统计分析管理管理逻辑设计

该文稿对综合统计分析管理的需求和逻辑设计进行了概述，主要目标是实现合同的实时有效监管，规范业务运作并防范合同风险。业务逻辑包括根据合同类型统计总金额、年度总预算、应付款余额等，并统计年度合同收票付款情况和大区收票付款情况。

http://192.168.1.14:5000/d/f/xLh64JyMRuFpFnKm6mNbI1OLhOdXATvf



## 逻辑设计

逻辑设计包括总体逻辑图、产品测试工作流程和下位机状态数据同步。下位机状态数据同步要求每分钟同步一次心跳状态和设备测试状态，上传数据需在服务端保存。

http://192.168.1.14:5000/d/f/xLh9NPaFGBH15fECSSn08zn2AsALoPHx



## 实现设计

本设计方案充分考虑了用户需求和技术实现，通过合理的架构设计和关键对象设计，构建了一个功能强大、易于维护的知识库管理平台。同时，通过高效的数据库设计和部署架构，确保了系统的稳定性和可扩展性。

http://192.168.1.14:5000/d/f/xLh9OEORXoAlWkfD8Zo9lcBuYCMCUYac



## 车间数据监控大屏

本文介绍了车间数据监控大屏的业务流程和数据库设计。首先，业务流程部分描述了数据监控网络状态和公示信息的管理方式。对于数据监控网络状态，系统会根据在线和离线状态进行判断，并采取相应的处理措施。对于公示信息，系统会选择车间新增公示信息，并在大屏上按创建时间正序轮播有效的公示信息。
接下来，数据库设计部分详细介绍了车间监控表和车间公告表的结构。车间监控表包含了多个字段，如id、name、pressure_key、pressure_value等，用于存储车间的各种监控数据。车间公告表则用于存储车间的公告信息，如id、monitor_id、valid、content等字段。
此外，文中还对各个表字段的字段类型、默认值、最大长度、是否可空、是否主键和描述进行了详细说明。这些字段共同构成了整个数据监控系统的核心数据结构，为系统的正常运行提供了基础保障。

http://192.168.1.14:5000/d/f/xLh6KftX7HVFbLgABjt6QOo102a8cEm7



## 内部用户登录流程

用户登录流程包括判断cookies中是否存在特定的cookie项，然后重定向到登录地址。登录成功后，后端服务将token信息放入cookie中，并跳转到相应页面。整个流程涉及路由守卫拦截、获取用户登录入口地址、重定向和后端服务获取token信息等步骤。

http://192.168.1.14:5000/d/f/xLh9PUsX1QOmQqNPKn0vngGtqltmzsS0



## rocketMq定义

该页面主要介绍了各个中心的定义设计信息，包括主题（TOPIC）定义、字段说明等。其中，RMQCOREMESSAGE主题含义为发送消息通知，订阅者为消息服务，备注说明中提到了电子烟产品备案申请流程出口、电子烟技术审评申请流程境内销售、企业信息变更申请流程等需要发送短信通知申请人的场景。RMQCORECUSTOMER主题含义为客户中心通知，订阅者同样为消息服务，备注说明中提供了企业相关信息，如地区、地址、代码等。此外，页面还提到了RMQCORECOMMODITY主题，但未给出具体定义和说明。这些主题定义的目的是为了提供更加灵活和高效的消息传递和通知服务，满足不同业务场景的需求。通过合理配置和使用这些主题，可以提高系统的可扩展性和可用性，为业务发展提供有力支持。

http://192.168.1.14:5000/d/f/xLh9RJqsnIbHd1dwCjAb7as3LOMnzleG



## 时序图

各中心定义设计，包括客户中心、消息中心等

http://192.168.1.14:5000/d/f/xLh9RtKk3RCxrWcATqrBNZpiRl22QDDt



## 实施部署手册

该文档是一份实施部署手册，涉及数据库配置和应用部署说明。在数据库配置部分，需要获取数据库脚本并执行数据脚本，同时添加白名单以保障数据库的安全访问。在应用部署部分，需要配置镜像仓库信息、RDS信息和云效部署应用，以及域名映射、服务和路由的配置。整个过程需要综合考虑安全、性能和可用性等因素，以确保系统的稳定性和可靠性。在部署过程中，需要注意镜像仓库、RDS和云效部署的细节，以及域名映射、服务和路由的配置参数。这些步骤都是为了确保系统的顺利部署和正常运行。通过合理的配置和部署，可以提高系统的可用性和可靠性，降低故障风险和维护成本。在整个过程中，需要遵循规范和标准，确保系统的安全性和稳定性。

http://192.168.1.14:5000/d/f/xLh9QASlZxYt4LYuqQ4CPlIQK7sRtGxc



## 公司文件数据权限详细设计

在体系文件管理系统中，数据权限需求根据角色不同而有所差异。部门文件管理员和其他角色可查看本部门编制的文件等，而公司文件管理员可查看全部数据。功能点如文件新增、修订、作废、增发、借阅、复审和其他可能引起数据权限变化。该系统需确保符合数据权限及数据有效性条件的数据能显示详情和在线预览按钮。

http://192.168.1.14:5000/d/f/xLh9ctQpeUsvd5vcbDARKwAAMXngWP59



## 历史文件初始化详细设计

这是一个关于文件管理的数据库设计文档。设计主要包含两个表：`docstandard`和`basicfile`。`docstandard`表记录了文件的基本信息，如编号、类型、名称、状态等。`basicfile`表则记录了文件的具体内容，如内容概述、备注等。此外，该设计还考虑了文件的有效期、版本、编制部门和编制人等信息。设计中的字段都详细定义了数据类型、长度、是否可为空以及是否为主键等属性。整个设计过程从需求分析开始，经过逻辑设计和数据库设计，最终提供了标准的文件表结构和字段描述。该设计为后续的文件管理提供了清晰的数据结构基础，有助于提高文件管理的效率和准确性。

http://192.168.1.14:5000/d/f/xLh9YYlV1XDhWtBoYiJXuW84uCsUiETZ



## 多租户设计

该文档介绍了多租户设计在知识库管理平台中的应用，旨在满足企业对高效、安全的项目管理库的需求。文档概述了多租户设计的基本概念，并详细描述了如何在知识库管理平台中实现多租户设计，包括流程设计和数据库设计。该设计方案具有灵活性、安全性和易用性等特点，能够支持动态添加、删除租户，确保租户数据的安全和隔离，并提供简洁明了的用户界面和友好的交互体验。通过引入多租户设计，知识库管理平台将为企业提供更高效、更安全的项目管理库服务，满足企业不断变化的需求，为企业创造更大的价值。

http://192.168.1.14:5000/d/f/xLh9TxdQqusZv4QFN7lwc19kU76z02Wu



## 天融信加解密设计

天融信加解密设计完善。

http://192.168.1.14:5000/d/f/xLh9Vbp1gsLsGFiW6O3kZGQ2VXtzRk56



## 数据权限具体实现

页面介绍了创建数据权限实现目标，包括数据库表设计、字段说明和类型。系统支持在角色管理设置需要数据权限的角色，并添加DataScope注解来实现数据权限控制。通过这种方式，可以实现不同角色的数据权限管理，提高系统的安全性和灵活性。

http://192.168.1.14:5000/d/f/xLh9ez0iXDDF67vDvhoiuBZVQ1X4juln



## 数据权限交互设计

数据权限交互设计文档，目前处于草稿状态，文档所有者为该用户。该设计提供了五种数据权限设置方式，包括全部、自定义、部门、部门及以下和仅本人数据权限，以满足不同角色的查询需求。

http://192.168.1.14:5000/d/f/xLh9fvU5Ka6WZLVBbmNVdRJOzJARrKy7



## 数据权限逻辑设计

该文档主要涉及数据权限逻辑设计，旨在通过配置方式实现自定义数据权限过滤，调整现有功能并优化用户体验。系统管理员、公司领导、生产质量负责人、公司文件管理员、部门领导和普通用户等不同角色应具有相应的数据权限。通过切面的方式在SQL语句末尾加入权限范围认证，实现数据过滤。此外，还需调整一级、二级和三级导航菜单，确保不同角色能够快速访问所需功能。系统应提供快捷操作、操作指引、最近查看、文件变更统计、生效文件统计和文件建议统计等功能，以便用户高效处理工作。数据表设计方面，应包括sysroledept部门角色表、sysmenu系统角色表、部门表sysdept和sysrolemenu角色与菜单关系表等，以确保数据结构合理、易于维护和扩展。通过合理规划数据权限逻辑设计，可以提高系统的安全性、可靠性和易用性，为不同用户提供更好的服务体验。

http://192.168.1.14:5000/d/f/xLh9eBTiKsdlbh0X7I3MkPMZpjOuDcR9



## 文件关联记录详细设计

该需求分析记录详细阐述了文件关联记录的设计需求。文件关联记录伴随主文件的新增、修订和作废而变化，遵循一定规则。当主文件作废时，其关联记录作废；主文件新增时，关联记录只能新增；主文件修订时，关联记录可以新增、修订和作废。归档环节根据主文件的修订情况对关联记录进行相应处理，如生成编号、合稿、签章等。文件类型支持WORD、EXCEL、图片和PDF，大小限制为100M。
数据库设计方面，doclinklog表为主键关联记录表，包含id、standardid、docid等字段。filename、fileid、versionvalue等字段描述关联文件的相关信息。linktype、versionid、tenantid、docclass等字段用于描述关联类型、版本、租户和文件类型。createtime和updatetime记录创建和更新时间，status字段标识记录的有效状态（1：有效；2：失效）。
此外，docversionlink表用于版本关联，包含id、linkid、versionid等字段。docmodifyapplylink表用于文件变更操作申请引用，包含applyid、createtime、docid等字段。
该设计旨在规范文件的管理和操作流程，提高文件处理的效率和准确性。通过合理规划文件关联记录的设计和数据库结构，可以实现文件的便捷管理，满足实际业务需求。

http://192.168.1.14:5000/d/f/xLh9ZLRhpg2oEmIfA2ktJmf5nx7eH3XI



## 文件变更操作详细设计

本文档详细设计了文件变更操作的流程和规范，包括变更申请、审批、操作、审核和完成等环节。通过遵循这些流程和规范，可以确保项目管理库中文件变更操作的高效运行和数据的准确性。同时，也有助于提高项目管理的效率和质量，为企业的稳定发展提供有力支持。

http://192.168.1.14:5000/d/f/xLh9anqwlQkFfUVENQVLiI5JOp0RCIO5



## 文件复审详细设计

本文主要描述了文件复审的详细设计需求，包括企业在使用或遵循文件时需要定期对文件进行再次审核的要求。业务流程中需要设计数据库表来存储复审申请信息，包括申请标题、文件编号、复审标准、申请部门和申请人等字段。其中，复审文件清单表格中包含了主键字段id和外键字段apply_id。同时，本文还介绍了文件复审申请表和接口清单的相关信息。文件复审申请表包含doc_name、doc_id、doc_class、version_id、字段名称、version_value、tenant_id等字段，接口清单包含/process/workflowApplyLog/selectDetail、/process/distributeLog/listNoProcess、/process/reviewApply等接口，分别用于获取文件复审详情、选择文件和新增或修改复审。这些表格和接口的字段信息有助于更好地了解和管理相关业务数据，提高企业的文件管理和业务流程效率。

http://192.168.1.14:5000/d/f/xLh9T2RG8pvWiiRDCBVqCI7JwJd1lPAo



## 文件签收详细设计

文件签收、打印、回收和签章是文件管理流程的重要环节。文件生效分发后，文件管理员需进行签收操作，以确保所有相关人员能获取文件及查看权限。签收人完成签收后，可进行相应份数的文件打印。若出现问题，可联系管理员协助重新打印。文件失效时，需进行回收操作，以避免无效文件继续使用。文件签章环节需对接第三方电子签章，第一次签章无弹框选择，完成签署后有标志；第二次点击则弹框选择查看上一次签章或重新签章。系统设计需确保收发平衡，并预览和保存签章详情。在数据库设计中，需充分考虑这些功能的实现细节和数据结构。此流程旨在确保文件管理的规范性和高效性，提升企业业务运作的效率和可靠性。

http://192.168.1.14:5000/d/f/xLh9dZ9rm3SuM7iD7coX9BzW26DRWpvv



## 爱数全文检索设计

本文主要介绍了体系文件管理系统的设计与实现，其中包括方案背景、实现设计、数据库设计等部分。首先，介绍了方案背景，说明了体系文件需要集成爱数全文检索功能，用于用户在搜索栏可以随时搜索文件或者搜索文件内容。接着，重点介绍了实现设计，包括流程设计和数据库设计。在流程设计中，详细描述了体系文件实现借阅分发等功能时，需要将文件上传到爱数平台，并存储用户信息到爱数中间数据库中。同时，通过请求爱数接口获取文件的用户权限和借阅人/分发人爱数用户信息，并重新更新该文件用户权限。最后，在数据库设计中，新增了basic_file表字段，包括external_file_id、external_file_path和external_rev等字段，用于存储文件外部储存信息和创建时间等。
总之，本文详细介绍了体系文件管理系统的设计与实现过程，包括方案背景、实现设计和数据库设计等部分。通过将文件上传到爱数平台并存储用户信息到爱数中间数据库中，实现了借阅分发等功能。同时，通过请求爱数接口获取文件的用户权限和借阅人/分发人爱数用户信息，并重新更新该文件用户权限。此外，数据库设计新增了相关字段以适应系统需求。该系统的实现将有助于提高体系文件的管理效率和用户体验。

http://192.168.1.14:5000/d/f/xLh9ZyTYDd7JKhohTsjVoerN4dw6jH4E



## 第三方应用集成规范

第三方应用集成规范文稿主要介绍了单点登录集成的接口描述、参数和生成签名的方法。接口描述说明了无需输入用户名/口令，直接登录到体系文件管理系统，请求地址和方式也进行了说明。接口参数包括应用id、需要登录的账号、签名和登录后跳转的链接，其中应用id和签名生成是关键。生成签名的方法是将appId、userName和appSecret进行md5加密生成。appId和appSecret由体系文件管理系统提供，需要保密。通过以上各个片段内容的综合，该文稿为第三方应用提供了集成规范的参考，有助于实现应用的快速集成和单点登录功能。

http://192.168.1.14:5000/d/f/xLh9V52MALwIhqTSbUiggfLZ6T27sEOW



## UDI通用客户端V0.1详细设计

UDI通用客户端V0.1详细设计概述：本版本只考虑实现与第三方平台诺唯赞多工厂UDI系统集成的全检业务场景相关功能，满足诺唯赞多工厂架构下对于全检的需求。功能清单包括登录、首页、任务详情、全检监控、任务数据同步和UDI编码检测状态同步。部署架构中，通用客户端与UDI前置机服务共用前置机数据库mysql，通用客户端部署在与全检机集成的一体机电脑上。全检业务流程中，本版本暂不实现部分环节。数据库设计包括用户表sysuser、任务表uditask、UDI编码数据udicode和全检记录udichecklog。其中，用户表sysuser基于tpomstaff表创建视图，任务表uditask用于存储任务数据，UDI编码数据udicode用于存储UDI编码数据，全检记录udichecklog用于记录全检过程。总体来说，该设计为UDI通用客户端V0.1提供了详细的实现方案。

http://192.168.1.14:5000/d/f/xLh7KyQBhAV0yz4GzvE8ihMXjm7cv1sp



## SaaS-M2 .NET 客户端 设计

该文主要介绍了WebSocket服务端、UDI任务接收与消息发布、UDI任务数据下载、打印服务、扫码检测和数据上传服务的流程和数据结构。此外，还提到了界面和固定编码的相关内容。总体上，该文较为全面地概述了各个功能模块的细节。

http://192.168.1.14:5000/d/f/xLh7HWgEkHjm9CepxLhv9f9NOuKdjYIj



## UDI .NET 打印 客户端 设计

UDI .NET 打印客户端设计，采用WebSocket实现与浏览器间的通讯。客户端作为WebSocket服务端，接收PC端浏览器发送的打印任务，并以JSON格式缓存到本地。任务数据包括任务ID、打印数量、UDI主键列表、打印类型、模板附件ID和接口token。此外，还涉及任务数据下载、模板下载、UDI数据下载和UDI打印等功能。整体架构清晰，功能完善，适用于多种打印场景，提高了打印效率和便捷性。

http://192.168.1.14:5000/d/f/xLh7D8K7RC5p3qTxaG5J1ngLHh4871BB



## SaaS版打印、全检流程设计

该文档描述了一个客户端打印和全检场景的流程。主要内容包括客户端基础框架、架构、打印场景、全检场景和全局变量等部分。在打印场景中，重点涉及了打印模板的获取、数据流的返回、打印客户端与SAAS服务端的交互等环节。在全检场景中，介绍了全检功能的开启、全检界面以及全检机的通讯流程等。此外，还涉及全局变量和服务线程的交互流程。整个流程图清晰地展示了各个关键点和异常场景，有助于理解和优化整个打印和全检过程。

http://192.168.1.14:5000/d/f/xLh7Oa66CLCPShf1c2AIvKoJNLay7opu



## 打印、全检常见问题&解决方案

PDA1机器打印PDI码后，质检、包装、留样服务无法扫码。解决方法：在PDA扫描设置中去掉“键盘方式输出”选项。

http://192.168.1.14:5000/d/f/xLh7FADDctrmtVXvs7CpqGqtabylKYtM



## SaaS版打印、全检客户端设计V1.0

该文描述了一个客户端打印和全检系统的多个方面，包括客户端基础框架、架构、打印流程、全检场景等。该系统涵盖了从客户端交互到打印机拉取数据、打印模板生成、打印过程更新状态、全检功能等多个环节。全检场景涉及多个流程图和功能按钮，以实现全检启动、暂停和打印机控制等操作。同时，该文还提到了全局变量和服务线程等概念，以支持全局交互流程。总体而言，该系统提供了一个完整且详细的打印和全检解决方案，为相关领域的开发和应用提供了有益的参考和指导。

http://192.168.1.14:5000/d/f/xLh7KyQBhAV0yz4GzvE8ihMXjm7cv1sp



## 全检客户端-单机版 全检功能 设计文档

本文详细描述了全检监控界面的设计与工作流程，涉及基础框架、版本信息、打开流程、切换步骤、成套码检模式开启、全检检测流程等。首先，系统基于.NET框架和EF ORM框架，使用SQLite数据库。在打开全检监控界面时，需要加载数据库数据、启动全检机，并处理错误退出流程。此外，还补充了SAAS版本与单机版本之间的切换流程。全检监控界面提供了手动和自动检测模式，自动模式下需先暂停再切换，手动模式可随时切换。成套码检模式默认不勾选，需在全检暂停状态下设置重复检测数量，并可选择自动或手动模式。全检检测流程中，NG信号会强提示，需用户确认后消失。手动检测需切换模式、放置标签并点击检测按钮，而自动检测则直接点击启动按钮。最后，文中还提到了UDI任务详情表的数据结构。

http://192.168.1.14:5000/d/f/xLh7JgNJ0lVoJvzHXgsJUntRFw36J02U



## 打印标签质量检测-详细设计

打印的UDI标签经常出现不清晰、污迹、划痕、错位等问题，这些问题人工很难检测，导致产品不合格。传统标签检测只解决了二维码评级问题，没有对标签质量进行检测，因此需要在原有的全检机基础上进行升级。基于海康VisionMaster平台解决图像质量检测难点，采用tcp/ip协议将检测结果实时反馈给客户端完成后续的逻辑控制。实现支持二维码等级评测和不同规格的标签质量缺陷检测的目标。

http://192.168.1.14:5000/d/f/xLh7BtgQJcZT7roHWauEll1BcXS00LWy



## 南京浦光生物科技有限公司客户客户端功能设计

南京浦光生物科技有限公司客户客户端功能设计需满足用户信息获取、检测等级信息显示控制、SAAS端全检任务和TOKEN处理、用户权限获取及客户端显示部分控制等需求。流程图缺失。

http://192.168.1.14:5000/d/f/xLh7M0Hvxlh4EXL3fpUDgercNrJLpY0B



## Saas版 - DI分段编码配置设计

该文档描述了一种企业产品DI码的管理方案，从总体流程、功能设计、表结构设计到接口设计进行了全面规划。首先，总体流程强调了根据产品分类分段生成DI码，便于识别和管理。功能设计部分详述了DI分段编码配置的查看和编辑功能，包括权限控制、排序、搜索、提示内容等细节。表结构设计则定义了DI分段配置表及其字段，包括主键、名称、起始值和结束值等。接口设计部分则提供了分页获取列表、获取详情列表、获取厂商识别代码和保存DI分段配置等接口。整个方案旨在为企业提供一个高效、便捷的产品DI码管理工具，提升管理效率和准确性。通过合理的权限控制和数据完整性校验，确保数据的安全性和可靠性。同时，提供丰富的接口功能，方便与其他系统集成，实现数据的共享和交换。

http://192.168.1.14:5000/d/f/xLh6OoDJa78zwN8PDVxSGVcVJn4gGLsJ



## Saas版 - DI申报/DI管理功能优化设计

1. 批量一键申报：用户可选择多条待申报记录，点击“一键申报”后，系统自动完成多条记录的申报。此操作涉及多次调用药监局接口，需确保某条记录操作异常不影响其他记录申报，并考虑使用多线程提升处理效率。方法执行完毕后，需告知客户端成功与异常提交的记录数。申报后，DI状态先调整为“申报中”，再根据药监局反馈更新状态。
2. 申报异步处理：为提升用户体验，将“提交申报”的后台处理方式由同步改为异步。后端接收到请求后，先将DI状态调整为“申报中”，再异步提交至药监局。
   此外，还规划了EXCEL批量编辑DI、报废校验、下载GS1通报表格和Excel批量变更DI等功能。

http://192.168.1.14:5000/d/f/xLh6eddPqxzZXRf2QA9CEiPV0O8ZUFnJ



## SaaS版 - UDI防伪模块设计

UDI防伪模块设计用于记录追溯记录，包含表设计、逻辑图和页面接口设计。表名是udi_anti_fake_history，记录不同手机扫码次数。逻辑图要求，不同手机号扫同一udi码超过3次则显示，少于3次不显示；同一手机号扫超过3次也不显示，只根据不同手机号判断。页面接口设计包括小程序扫码检测和保存记录、显示产品信息和追溯信息、显示产品详细信息、显示扫码明细信息和判断是否本人扫码。综合以上设计，UDI防伪模块实现了追溯记录的完整流程，提高了产品的防伪能力。

http://192.168.1.14:5000/d/f/xLh71NFPpYuol8JNm3pwtqvMmOlQ8mO5



## SaaS版 - UDI管理模块设计

UDI一站式服务平台提供了UDI管理模块设计表和产品信息表。UDI管理模块设计表包括DI码、类型、包装规格、包装级别和包装内含小一级包装规格等信息。产品信息表包括产品标识编码体系名称、产品名称通用名称、规格型号、DI码申报状态、标识载体和产品标识发布日期等信息。平台还提供了奇数位求和功能。通过该平台，用户可以方便地管理UDI相关信息，提高管理效率和准确性。

http://192.168.1.14:5000/d/f/xLh7VTIOxwzV8VdNBP2dqas9UuUUdwYw



## Saas版-留样管理模块设计M3

SaaS版UDI管理模块设计，包括留样管理模块M3，包含表结构和基本流程。业务规则要求留样只针对最小销售单元，PDA根据留样数量更新UDI码的留样状态。

http://192.168.1.14:5000/d/f/xLh7XOVvbFJvXPsqgXYXAdusegPHkMiC



## Saas版 - 打印模板设计

本文详细介绍了打印模板设计的流程和功能设计，包括新增免费模板、复用免费模板、新增自定义模板和模板设计等环节。平台管理员可维护免费模板供租户复用，租户也可自行创建自定义模板。在线web模板设计器提供所见即所得的设计方式，用户可直接拖拽控件完成模板设计，并支持模板预览。此外，还涉及生成模板文件、关联产品和模板转换等功能。表结构和接口设计部分未在文中详细描述。本文为系统开发提供了完整的打印模板设计解决方案，有助于提高打印效率和管理水平。

http://192.168.1.14:5000/d/f/xLh7Sl74OYsDSCOysFhHwy51zZ3nGdfO



## Saas版 - 测试打印设计

为了实现打印模板的“所见即所得”设计，开发了测试打印功能。用户在设计模板时，可实时预览打印效果。流程涉及web端、服务端、客户端和打印机。前端调用模板接口完成数据入库和文件上传，再调用仿真数据查询接口获取数据，结合打印机信息下发给客户端。服务端需新增仿真数据查询接口，从模板数据中提取占位符和样例数值，返回给前端。客户端从webSocket接收指令，拉取模板，填充样例数据并打印。数据库结构不变。服务端需提供仿真数据查询接口。此功能简化了打印模板设计流程，提高了用户效率和满意度。

http://192.168.1.14:5000/d/f/xLh7Qb8P01KqsOnYEUsDhMu1qDePr9xm



## SaaS版 - 模板关联设计

SaaS版模板关联设计

http://192.168.1.14:5000/d/f/xLh6U5vDGc6Q1juuW5J6Qf6osyZSbU0d



## SaaS版 - 认证授权设计

该文主要介绍了认证授权设计和多租户模式在SaaS版中的应用。首先，认证授权是确认用户身份和授予系统访问权限的过程，常用框架为Spring Security和Shiro。考虑到项目基础，Spring Security更为合适。认证总体架构中，复杂业务会拆分为多个微服务，需建立统一认证中心，如单点登录效果。认证体系设计则基于Spring Security的UsernamePasswordAuthenticationToken进行认证。对于多租户模式，介绍了基本概念、流程设计和表结构设计，并强调了数据隔离的重要性。

http://192.168.1.14:5000/d/f/xLh6OC2GaMlfzpiAvC2j99f6pGxyG4mY



## SaaS版 - 设备管理设计

设备管理设计在SaaS版中，需根据当前需求，在已存在的设备表（t_udi_device）中新增字段以展示设备及其关联关系。表设计包括设备主键（device_id）、设备类型名称（device_type_name）、设备类型编号（device_type_code）、设备名称（device_name）等字段。新添加的字段包括设备ip地址（device_ip）、设备厂家名称（device_vendor）、创建时间（create_time）、租户id（tenant_id）等，同时根据不同的设备类型展示不同页面字段。使用状态（using_status）、最近使用时间（last_use_time）、串口号（com）和关联设备id（association_device_id）等字段也需一并考虑。推送接口地址（interface_url）等其他相关字段也需在设计中予以考虑。通过这样的设计，可以更好地满足设备管理需求，提高设备管理的效率和便利性。

http://192.168.1.14:5000/d/f/xLh82vgxbXR3U9hkfJyasTrOvJFD5iuY



## 安装包管理

安装包管理使用OSS服务，下载管理简单增删改查。相关接口为http://192.168.1.169:9000/project/11/interface/api/cat_276

http://192.168.1.14:5000/d/f/xLh83iNAPg6aKQq7gH6uEl7RZ9GT4ky9



## Saas版-生产任务模块设计

该平台包含生产任务模块设计，其中涉及DI管理模块。功能架构与流程方面，最小销售单元可自定义添加、删除规则及编辑部分字段，修改后其他包装层级同步修改；其他包装层级仅能修改序列号长度，其他规则与最小销售单元相同。产码逻辑采用生产者与消费者模式，多线程生成码，单线程插入码，异常处理时改变状态标记字段。表关系设计包括tasksubid、taskid、tasksubtype等字段，子任务状态、完成时间、完成人等信息也涵盖在内。该平台通过综合考虑功能架构、流程、产码逻辑和表关系设计，提供了一站式服务解决方案，有助于提高生产效率和管理水平。

http://192.168.1.14:5000/d/f/xLh85lFrZ1bm6B3wk6VHapIDw1CVWw6y



## Saas版-UDI生产任务操作日志设置

Saas版-生产任务模块设计，包括UDI生产任务操作日志设置。记录UDI生产的操作，以创建时间排序，操作内容以json类型存储。

http://192.168.1.14:5000/d/f/xLh84pm5isweW8Z4h3EG0qa84bOsQZct



## UDI码溯源

UDI码溯源系统需要对UDI生命周期的每个环节进行记录，以便在需要时进行查询。根据现有实现，产码、作废、打印、重新打印、全检、首检、尾检、抽检等环节已有相应的记录机制。包装关联逻辑也已完善，无需改动。留样和出库、重新入库功能暂未实现，需要进一步完善。udi_code表需增加创建人、作废人、作废时间字段，并修改其他字段类型和长度。相关接口为http://192.168.1.169:9000/project/11/interface/api/cat_285。通过这一系统，企业可以更好地追踪UDI的整个生命周期，确保产品的可追溯性和质量安全。未来需要进一步完善留样、出库和重新入库等功能的实现，以提供更全面的追溯服务。

http://192.168.1.14:5000/d/f/xLh87LKH0OWIAYegOGPAvKKjgoz3WuWd



## SaaS版 - 与药监局对接详细设计

该文主要介绍了与药监局对接时，如何根据不同数据组织结构对包装数据进行重排序和赋值的问题。针对药监局和本系统包装标识组织结构的差异，通过深度有限遍历算法重新构建包装规格层级树。排序算法先根据DI找到第一层包装，然后依次给包装规格赋值，再取其中一个包装找到第二层包装并赋值，以此类推处理多层包装，最终得到包装层级树。

http://192.168.1.14:5000/d/f/xLh73r60Kd3Ct7PFD8Jjet2mazvFL0oB



## Saas版-质量管理-全检记录等级报告预览与下载_模块设计M3

该平台提供SaaS版质量管理、全检记录等级报告预览与下载功能。表结构udi_check_log详述了模块设计M3。无业务设计流程模版默认存放位置标签。

http://192.168.1.14:5000/d/f/xLh6c6o2TzgjSYkVjk0ilsce0XXcvX7X



## Saas版 - 注册证管理设计

平台主要关注注册证管理设计，特别是注册备案证号与产品名称的自动匹配功能。平台具备查看、导入和导出注册证信息的功能，并对此进行了详细的权限控制和数据校验设计。在表结构上，它构建了一个udiregistercertificate注册证表，包含多种字段如证书编号、产品名称、医疗器械管理类别等。此外，还涉及分页获取注册证、excel导入、获取详情和删除等接口设计。该平台旨在为用户提供便捷、高效和安全的注册证管理服务，以支持医疗器械行业的合规性和数据准确性。

http://192.168.1.14:5000/d/f/xLh6oG9RiopPu4xSsrvbdq2HYbPodlgG



## SaaS版 - 租户管理设计

租户管理业务流程图分析，主要包括前端生成邀请链接、调用后端接口检查密钥、秘钥缓存管理以及租户与潜在客户的关系。秘钥有效期内无需登录即可访问注册页面，后端接口无需权限校验。租户表与潜在客户表通过id和source_id字段关联，并调整了部分字段长度。相关接口地址为http://192.168.1.169:9000/project/11/interface/api/cat_267。

http://192.168.1.14:5000/d/f/xLh6YJuyL2OHKtfUcTE6lB0nfFhRaSXy



## 药监局常见问题及解决方案

药监局常见问题包括未授权、业务执行失败和参数格式不正确。针对这些问题，解决方案分别为引导客户授权、检查代码中是否缺少字段以及将错误回显给用户修改内容后重新提交。同时，测试环境会有一定的延迟。

http://192.168.1.14:5000/d/f/xLh6h35DqFkfJLGmYonpC50baoZKOkor



## 诺唯赞UDI系统-首页与报表统计设计

本文介绍了诺唯赞UDI系统的首页与报表统计设计。需求主要包括DI统计、产码统计等，要求按天、按小时更新展示统计结果，查询响应速度需达到秒级。设计思路为通过空间换时间，建立统计结果表，定时更新数据，以加快前端查询速度。详细设计方案中，采用XXL-JOB作为定时工具，报表与模块表用于存储数据，并定义了各字段的数据类型、长度、小数位数等。整体方案旨在提高系统性能和用户体验。文章还描述了数据库表结构的设计，包括字段名、数据类型、字符长度、数字长度、小数位数、是否允许非空和默认值等。同时提到待讨论的点，包括是否新增报表工程和统计SQL的存储方式。这些讨论点对于数据库设计和应用开发非常重要，需要仔细考虑和权衡。最终，需要根据实际需求和业务场景来做出最佳的选择。

http://192.168.1.14:5000/d/f/xLh7nsx497vI2LBdfJsGxoke8BuCJvbd



## 诺唯赞UDI系统-设备管理设计

本文主要介绍了诺唯赞UDI系统中的设备管理设计部分。首先对需求进行了简要分析，指出现有的前置服务已维护了设备表，但需新增字段以实现设备所属工厂及车间的标识，以及不同设备类型对应展示页面的字段。接着详细展示了设备表的结构和字段信息，包括设备主键、设备类型名称和编号、设备名称、内容、厂家名称、创建时间、租户ID、使用状态、最近使用时间、工厂和车间ID等。
此外，设计过程中充分考虑了字段的可空性和主键设置，确保数据的完整性和唯一性。通过详细展示设备表的结构和字段信息，使读者能够清晰了解设备管理设计中的数据结构和关系。最后，文章未提供任何标签信息。
总体而言，本文对诺唯赞UDI系统中的设备管理设计进行了全面、细致的描述，为读者提供了完整的数据结构和关系视图。这种设计方式有助于提高系统的可维护性和扩展性，为设备的统一管理和操作提供了基础。

http://192.168.1.14:5000/d/f/xLh7luT9VzrlkBYGxMwpJYuZKnVTMklw



## 诺唯赞UDI系统-三层架构设计方案（开发指导）

诺唯赞多工厂的UDI系统设计方案旨在满足高性能要求，支撑日产600万码和1亿热数据量，并支持打印、喷码、装箱、出库等核心业务。方案将业务场景拆分为基础业务和核心业务，基础业务部署在私有云以保证数据安全性，核心业务部署在阿里云以利用云计算资源。三层业务设计包括服务端、前置机和客户端，各自承担产码、装箱、出库等核心业务、打印数据处理和状态数据回传等职能。服务端与前置机产码数据流转由生产人员新建产码任务并指定工厂，前置机保存热数据量不超过100万。服务端与前置机UDI打印数据流转中，前置机只保存少量热数据，传输完状态数据后即删除。前置机、服务端和喷码服务的数据流转由前置机发起喷码请求，服务端生成码文件并返回给前置机，喷码服务解析并保存码文件，完成后返回喷码结果数据给服务端。接口清单包括增量传输UDI基础数据、产码接口、打印码拉取和打印状态数据回传等。整个设计方案旨在提高系统性能和数据安全性，满足诺唯赞多工厂协同生产的需求。

http://192.168.1.14:5000/d/f/xLh7qAJIvV555MybG1ON4GnmBcpOA2FJ



## 诺唯赞UDI系统-前置机部署方案

诺唯赞多工厂的前置机部署方案详解，包括前置机基础环境、组件安装规划和安装步骤。该方案要求使用CentOS Linux 7.9 64位内核版本5.10及以上，禁用selinux和firewalld，确保前置机与网络打印机、喷码设备之间的网络可达。部署的组件包括mysql、redis、xxl-job-admin、udi-prepose-front和udi-prepose-service，均采用Docker容器方式安装。安装步骤包括准备、安装和测试验证，确保容器实例状态为Up。通过此方案，可以实现诺唯赞UDI系统的前置机部署，提高生产效率和管理水平。

http://192.168.1.14:5000/d/f/xLh7pW941I9XFHa0srx8kgDbUlrBl8Vn



## 诺唯赞UDI系统-喷码记录设计

诺唯赞UDI系统-喷码记录设计是为了跟踪每次喷码任务的结果，包括分配的喷码数量、成功数和失败数。
该设计为诺唯赞UDI系统提供了全面的喷码记录功能，帮助用户跟踪和管理喷码任务的结果，确保每个任务都能准确、及时地完成。

http://192.168.1.14:5000/d/f/xLh7nDVd9b3ClNt5JrnoPYw9d0E6FpXH



## 诺唯赞UDI系统-基础数据与产码服务数据同步设计

诺唯赞UDI系统，重点在于基础数据与产码服务的同步设计。基础数据主要涉及员工、角色、权限等，会从外部系统主动推送至SaaS平台，再流转至工厂前置机服务器。SaaS平台需提供基础数据同步接口服务，通过通用接口和场景值区分不同数据对象，减少开发和维护成本。产码数据涉及UDI码生成与状态更新，前置机服务器需主动从SaaS平台获取码并回传状态。SaaS平台需提供生成和更新状态的接口。此外，还需关注接口认证、事务一致性和加密设计等技术要点，确保数据同步的准确性和安全性。

http://192.168.1.14:5000/d/f/xLh7irHVJZGuZjVCKoSAVEGBp1gCJlBT



## 诺唯赞UDI系统-工厂管理设计

该文章主要介绍了诺唯赞多工厂的UDI系统中的工厂管理设计。服务端需要维护所有工厂的信息，前置机需同步自己工厂的工厂信息。服务端和前置机都维护一张相同的工厂表，定时获取自己工厂的工厂信息，但定时多久获取需进一步讨论。表设计包括工厂的id、parent_id、名称、名称拼音简写、排序值、状态、创建时间、创建人、修改时间、修改人、级别等字段。通过这些字段，可以全面地记录和管理工厂的各种信息，为工厂的管理和决策提供有力支持。该设计考虑了工厂的层级关系和信息完整性，具有较好的扩展性和灵活性，能够满足不同场景下的需求。通过使用该UDI系统，可以有效地提高工厂的管理效率和信息准确性，降低管理成本，提升企业的竞争力。

http://192.168.1.14:5000/d/f/xLh7ZhiYiuOMkZyEnTsrwlBZm4tsQmxo



## 诺唯赞UDI系统-产码、拉码、数据回写设计

诺唯赞UDI系统需要解决快速、不冲突、不重复的产码问题，并保证数据一致性，以支撑多工厂日产650W码的需求。方案采用服务端产码，通过生产者与消费者的方式，多线程生产码并存入阻塞队列，再由单线程定时循环从队列中取出一定数量码插入数据库。此外，采用定时拉取方式，从服务端拉取本工厂数据，进行打印、全检、喷码等业务，然后定时回写状态数据给服务端。为保证数据唯一性，只能有一台中控服务器。UDI产码服务端与工厂前置机端涉及多张表，其中UDI码主表和从表通过taskid进行hash水平分表，分表算法为taskid+shardingnum。UDI码插入方式为从阻塞队列拉取一定数量后，由JDBC硬编码方式批量插入数据库。该方案可满足诺唯赞多工厂日产650W码的需求，并保证数据一致性。

http://192.168.1.14:5000/d/f/xLh7giipZGBuYvEn3HE3ZdUHzzN77zQO



## UDI服务性能优化设计

当前架构分析包括总体、部署、数据库和表设计。针对数据库开发，提出了显式指明字段名称、使用limit的限制、使用合适的计数方法、控制INSERT提交数量、避免null值和参考阿里手册等规范。优化目标旨在提升性能。部署设计需综合考量整体架构和规范，确保系统稳定、高效运行。

http://192.168.1.14:5000/d/f/xLh7eTdNpRzMDg8Lvqpvxb7CC2XD7Oj1



## 诺唯赞 - PDA 设计

诺唯赞多工厂系统包括登录认证、验证与关联任务列表、生产抽查、质量检测任务列表、产品留样等模块。系统根据角色控制菜单权限，如装箱专员、IPQC和物流专员。此外，系统还提供生产抽查、质量检测和产品留样等功能，并支持扫码验货和自动更新。整个系统设计精良，功能全面，方便实用，提高了工厂的生产和管理效率。

http://192.168.1.14:5000/d/f/xLh7uMkGmKfPG3svBvQf9vGz9A0z3PJ0



## 诺唯赞UDI系统-xxl-job任务调度策略设计

诺唯赞UDI平台通过xxl-job执行调度的任务包括六大类，包括产码任务、产码基础数据任务、基础数据任务等。每个任务都有具体的调度策略，如CRON执行周期可以通过管理页面进行调整。部分任务的核心目标是将数据从服务端同步至前置机，其中部分数据同步类型需要后续版本进行同步策略优化。

http://192.168.1.14:5000/d/f/xLh7sLHZHYUcEqZrTiUvYU22S9E8M7Dw



## 诺唯赞UDI系统-阿里云环境发布流程

发布流程包括开发自测、填写更新记录、功能测试、发布到生产环境和冒烟测试。发布步骤包括进入公司Paa平台和阿里云Jenkins系统构建应用。总体来说，这个发布流程和步骤比较详细，确保了应用的安全性和稳定性。

http://192.168.1.14:5000/d/f/xLh7hILUORwotwEsAASRtP0hKnXIkB6O



## 诺唯赞UDI系统-兼容组合产品设计

该需求涉及多个模块的改动，包括DI管理、PI管理、生产任务管理、码同步、打印模板、同步销售出库单等。主要改动包括新增区分组合产品和常规产品的字段、更新标识符库、修改拉码查询条件、新增组合产品模板等。此外，还涉及UDI架构改动、UDI详情打印功能、PDA装箱验证功能等。最终目标是提升系统的灵活性和可维护性，满足不断变化的市场需求。

http://192.168.1.14:5000/d/f/xLh7jVRkDmZ9MIBcpUlAjO4yee1kCk6P



## 诺唯赞UDI系统-生产任务设计

诺唯赞多工厂UDI系统中的生产任务设计，主要涉及原型、接口传参设计和后端实现逻辑。对于组合产品，设计新增实现类并复制原有逻辑进行修改，动态加载对应的PI规则，并默认添加3个PI规则记录。前端需调用bom组合产品查找接口获取物流树形结构信息。非组合产品的传参方式保持不变。后端主要实现逻辑根据产品是否为组合产品采用不同产码方式。组合产品的UDI码包含特定格式和参数。此外，还提供更详细的需求文档描述。

http://192.168.1.14:5000/d/f/xLh7qwHVuh0uLb57mUMspR2KE86a4eWM



## 诺唯赞UDI系统-并行出库设计

UDI系统需要支持大订单急出场景下的并行出库，避免扫码验货速度成为瓶颈。通过Redis存储锁标识，每次扫码验货数都需经过验证，确保不超验或少验，并及时更新已验货数量。此方案可解决并发问题导致的多出或少出问题，以及数据库脏读问题。

http://192.168.1.14:5000/d/f/xLh7tkHceV1iirn2AvLqoH78qvsgJFNA



## 诺唯赞UDI系统-仪器UDI版本设计

该文主要描述了多个功能和管理的调整，包括模板自定义、BOM调整、DI和PI管理、模板绑定、标签字段管理、UDI生产任务管理和已产码数据管理等。具体改动包括新增用途类型字段、DI和PI标识符类型、模板对象类型字段、PI与模板管理表、标签字段、UDI生产任务按钮、产品产码信息、新建配件码表和仪器激活子任等。这些调整旨在提高系统的灵活性和功能性，满足不同业务需求。

http://192.168.1.14:5000/d/f/xLh7lDtK0EDX5Bl1tJGd2rOfSsW7t8IE



## 诺唯赞UDI系统-标签自定义JSON转ZPL命令打印

诺唯赞多工厂的UDI系统-标签自定义JSON转ZPL命令打印源文件详述了从前置机打印UDI标签的整体流程。系统区分历史模板打印和自定义模板打印，历史模板走历史通道打印机，自定义模板则获取最新自定义JSON转换成ZPL命令进行打印。此外，还涉及术语缩略语解释、功能设计和表结构设计等内容。其中，功能设计部分重点说明了UDI打印、历史模板隔离和自定义JSON转ZPL打印命令等功能的实现方式。表结构设计部分则提到了UDI打印模板配置表和PI规则配置表的添加字段。总之，该文件为诺唯赞多工厂的UDI系统提供了详尽的指导和参考，有助于提高打印效率和准确性。

http://192.168.1.14:5000/d/f/xLh7uuwvxC3ZKl66RtofC27r1jY6MmCK



## 诺唯赞UDI系统-标签模板定义服务-模块整体功能设计

诺唯赞UDI系统-标签模板定义服务旨在提供独立的标签模板设计工具，解决用户在设计标签模板时遇到的痛点。该服务支持图形化标签配置方式，使得普通用户经过短期培训即可完成设计工作，提升设计效率。该服务将应用于诺唯赞IVD仪器生产中心UDI平台，并独立于其他系统进行设计与维护，通过接口与外部平台交互数据。服务特征包括独立运行、支持图形化标签设计、用户无需了解模型等。总体设计包括架构、流程、数据结构、功能模块、代码框架和接口等方面。其中，功能模块包括模板管理、数据组件管理、标签在线设计和模板预览打印等。该服务将促进标签模板定义工具在业务场景的快速落地，为诺唯赞IVD仪器生产中心UDI平台提供快速获取标签模板设计能力。

http://192.168.1.14:5000/d/f/xLh7c9iksXiZz1QTkrYkQWDnNyI0QUUt



## 诺唯赞UDI系统-WMS对接接口梳理与设计

本文详细描述了诺唯赞UDI系统与WMS系统的对接需求和场景梳理。业务背景显示，因业务变化，UDI系统需与WMS系统对接，实现UDI码的生命周期数据链条的完整性，符合药监局等管理部门对UDI的规范管理要求。场景梳理部分列举了各种对接场景，包括生产入库、出库、退检、报废等，并对各个场景的操作流程和码状态变化进行了说明。总体而言，对接需求涉及多个方面，包括码信息查询、码状态更新、校验等，以确保UDI码的准确性和完整性。通过合理的接口设计和流程优化，可以实现两个系统的顺利对接，提高仓储、物流和UDI管理的效率。

http://192.168.1.14:5000/d/f/xLh7kbQfsPyToiG3whVNyNOQzR1T9EV2



## 诺唯赞UDI系统-仪器UDI打印、质检、激活、出库设计

诺唯赞多工厂推出了UDI系统，针对仪器生产的需求进行定制化设计。该系统解决了仪器本体与外箱、配件与配件外箱码值一致导致无法区分的问题。功能改动清单中详细列出了产码模块、任务详情、前置机同步数据等功能的变动。其中，新增的t_normal_code表用于存储常规码数据。该UDI系统通过不同的UDI别名来区分本体、外箱和配件的操作情况，如打印、质检、激活等，使得操作更加便捷和准确。此外，UDI溯源信息只展示本体码，方便区分本体和外箱的操作。整体而言，该UDI系统为诺唯赞多工厂的仪器生产提供了更加高效和精准的管理方式。

http://192.168.1.14:5000/d/f/xLh7oWyVUJUTQAZbP566y4awmpTIp30Q



## 诺唯赞UDI系统-WMS对接设计(开发指导)

诺唯赞UDI系统-WMS对接设计开发指导，旨在实现多个关键功能，包括接口认证、UDI码信息查询、码状态变更、整单提交及定时任务。架构设计部分未详细阐述。在详细设计方案中，重点关注了AOP对外接口认证，以及涉及UDI码状态变更的相关接口实现逻辑。此外，还包括了定时任务的设计，用于处理超过一个月的UDI变更记录。在数据库设计部分，创建了多个表来支持上述功能，包括租户信息、租户接口权限、UDI变动记录和历史记录，以及第三方调用日志。该方案通过细致的逻辑设计和合理的数据库结构，为诺唯赞UDI系统与WMS的对接提供了坚实的支撑。

http://192.168.1.14:5000/d/f/xLh7t6OysMs8RMp8T3AvrY9jt6drUeS5



## UDI系统与第三方ERP、WMS的对接架构

强调UDI系统对接第三方ERP、WMS，确保码的产生、赋码和状态保持。避免UDI被边缘化。

http://192.168.1.14:5000/d/f/xLh6VKhhxFLS0RmurcQlfOCwngBfWEBL



## Saas版 - DI自动编码/产品分类模块设计

UDI一站式服务平台需解决DI自动编码问题，包括关联DI分段和自动生成替代手工触发编码。业务需求涉及前端和后端设计，前端需去掉自动编码功能按钮，并调整展示逻辑，后端需调整数据提交后的自动编码逻辑。产品分类DI分段和接口设计也需考虑。该需求旨在提高DI生成效率和准确性，减少人工操作，提升系统自动化水平。

http://192.168.1.14:5000/d/f/xLh6ScnyVjWdGi2lAGVEADr7q5wZL2Mg



## Saas版 - 生成UDI序列号的规则设计

提供了序列号类型两种：随机序列号和自定义序列号。随机序列号长度根据包装级别生产量确定，后端使用Redis缓存确保唯一性。自定义序列号可通过表设计实现，并提供了增补UDI实现逻辑和自定义序号顺序生成逻辑图样例。前端根据PI规则动态加载UDI生成，控制隐藏或显示输入框。整体设计考虑了高并发场景，确保序列号的唯一性和准确性。

http://192.168.1.14:5000/d/f/xLh6dOZK2HNExFaWJeBBMaCZ6Uxve39B



## Saas版 - PAD授权设计

基于SAAS服务端权限框架，扩展PDA模块的权限功能。租户管理员和普通用户分别根据租户购买的服务和关联的角色集合，确定有权访问的菜单集合。

http://192.168.1.14:5000/d/f/xLh6QOQWb2iUuQyo01vIVbEIkoSn5KBL



## Saas版 - M4.2.3功能优化需求设计

该文主要介绍了M4.2.3版本的SaaS系统在功能优化上的需求设计，包括DI删除、账号优化、DI导入功能优化和性能优化等方面的改动。其中，DI删除功能对不同模块的DI列表中的按钮名称进行了调整，并明确了支持删除的状态；账号优化则调整了个人中心模块的文本显示和用户管理模块的列隐藏；DI导入功能优化则针对非自动编码场景进行了校验规则的设定。此外，文章还提及了新增表和更新表的数据库设计以及相关页面的调整。整个设计过程注重用户操作体验和数据准确性的平衡，以提升系统的整体性能。通过这一系列的优化措施，有助于提高系统的稳定性和用户体验，为企业的数字化转型提供有力支持。

http://192.168.1.14:5000/d/f/xLh6WyBIxv2mljo9Ive2pSKr8FwQu4i5



## Saas版 - 模版自定义图库设计

SaaS版模版自定义图库系统，允许用户在系统中选择标准图片或上传自定义图片。每个租户限100张图片，且图片名称不能重复。文件大小限制为100K，仅支持bmp、jpeg、jpg、png格式。原表udi_template_image被复用的udi_attachment表替代，通过busi_type区分。图片存储在工程路径下的'resources/static/trmplateImg'目录。历史数据处理需编写脚本或后端代码。

http://192.168.1.14:5000/d/f/xLh78GaWA2XRKbkhWZdOeeZ5h5BCuQGQ



## Saas版 - M4.2.4功能需求设计

描述了一个系统的需求、逻辑设计、详细需求说明、设计说明、接口设计和详细需求说明与设计。需求包括增加同步GS1数据和判断DI编码的准确性。逻辑设计涉及一个关联表。设计说明涵盖了查询现有数据、处理流程和过滤数据的方法。接口设计提到了查询列表。最后，详细需求说明与设计涉及到自动编码、去重处理和错误提示。

http://192.168.1.14:5000/d/f/xLh6xbv8uMyFgH2OdujOKB1KMMVzA7z2



## Saas版 - M4.2.4功能需求设计-(1)

该需求文档主要描述了M4.2.4版本的功能需求设计，包括一维码和二维码的制作、打印和全检，以及接口的权限控制、DI数据导入优化、打印模板优化和数据库设计等内容。其中，一维码和二维码的制作、打印和全检功能需要支持多种编码方式，并在前端和后端进行相应的数据结构调整和接口处理。接口做权限控制功能需要对UDI-SAAS服务端全部功能页面执行全部功能按钮级别的权限控制，需要在portal端配置按钮级菜单。DI数据导入优化和打印模板优化也是该版本的重要功能，需要进一步优化和完善。最后，该文档还涉及了数据库设计和接口设计等方面的内容。总体来说，该需求文档详细描述了M4.2.4版本的功能需求和相关设计，为开发人员提供了明确的指导和参考。

http://192.168.1.14:5000/d/f/xLh6sbWmAQfJJuH05Xv4nGzGWFbs3s15



## SaaS版 - 商机清洗及管理设计

UDI一站式服务平台是一个项目管理库，专注于商机清洗及管理设计业务流程。该平台提供了系统清洗、管理、整理等功能，帮助用户高效地处理和组织商机数据。其中，系统清洗分为两个维度进行确认，公司维度和商机维度，确认后的数据可在管理界面查看。管理功能包括编辑和分配，编辑维护的是公司表的数据，分配则是将公司分配到销售后，销售才能看到数据。整理功能包括跟进和编辑，跟进是将销售拨打电话收集的信息进行存储，编辑则是根据收集的信息维护公司表。数据库设计方面，该平台包括一个商机公司表，包含了多个字段，如id、companyname、companyarea等。这些字段的类型、长度、是否可空、是否主键等属性都进行了详细的规定。该平台旨在帮助用户更好地管理和利用商机数据，提高业务效率和准确性。

http://192.168.1.14:5000/d/f/xLh6dx3aLCaAntf9FjF8drRnm72JUzWj



## SaaS版-关联关系管理设计

本文主要描述了关联关系管理的设计，包括需求概述、原型设计与规则说明、接口设计以及涉及的影响功能。首先，该功能主要涉及服务端和PDA端，通过一个接口兼容两个端。规则说明中，默认操作包括搜索UDI码、展开并选中UDI码、解除关联、替换UDI码等。查询逻辑则涉及到递归查询和直接查询。在解除关联和替换UDI码的流程中，服务端和PDA端有所不同，前者在查询时直接修改相关字段，后者则增加了一个效验逻辑。此外，PDA端还有验证关联关系的流程。接口设计方面，使用Yapi进行管理。最后，该设计还涉及到UDI溯源无标签的影响功能。
综上所述，本文详细阐述了关联关系管理的设计过程，从需求概述、原型设计与规则说明、接口设计到涉及的影响功能，为相关人员提供了有价值的参考信息。通过统一接口兼容服务端和PDA端，实现了一系列操作如搜索、展开、解除关联、替换等。同时，根据不同端的特点，服务端和PDA端在流程上有所区别，PDA端还增加了验证关联关系的流程。整个设计过程考虑了查询逻辑、解除关联和替换UDI码的流程以及涉及的影响功能，使得关联关系管理更加高效和准确。

http://192.168.1.14:5000/d/f/xLh6aSKqWDzQp5TGEkEgInHHreivHTDX



## 出入库总体架构设计方案

出入库系统是医疗器械监管中的关键环节，在国家“十四五”规划的背景下，需要建立全生命周期的UDI溯源。系统设计目标是支持主流ERP接口、UDI系统、快递接口，实现大数据量存储和快速响应，同时保证对外接口的独立与标准化。技术难点主要在对三个系统的对接上，需要降低新系统对接成本。主业务流程图未提供，架构设计采用前后端分离，前端、后端、PDA端分别只有一个工程，数据库不拆分。数据流转图和对外接口列表也未提供。表关系与表设计需要进一步明确。总之，此系统开发涉及工作量，没有较大难度，可以复用已有对接经验。

http://192.168.1.14:5000/d/f/xLh81bNHsY7BslFJcEXRavdFRKItYzHb



## Saas版-fastReport文件上传

UDI一站式服务平台新增了fastReport文件上传功能，允许管理员上传.frx格式的模板文件，并支持普通用户应用和编辑这些模板文件。该功能设计独立入口，各租户可维护自己的模板文件。上传时需校验文件后缀，表单数据默认写入uditemplate表，其中templatetype默认写入”ATTACHMENT“。后端接口将文件写入服务器指定目录。此外，该功能调整在已有的“打印模板管理”模块基础上进行，该模块将受到潜在影响。除模板文件上传外，还需考虑模板文件更新、删除、应用和查询等功能，并进行数据库和接口设计。

http://192.168.1.14:5000/d/f/xLh6kEmpwj7DfVAz3UqTi1UbHlfRUmRw



## SaaS版-包装层级关联设计

需求背景描述了UDI码关联和装箱任务的流程，包括内层和外层扫描的判断与提示，以及UDI码状态和比例关系的规则。PDA扫描涉及内包和外包两个接口调用，任务完成后不能再次进行。表设计涉及到UDI码码表的相关内容。

http://192.168.1.14:5000/d/f/xLh6jbBnIVTDhY39ErnRb4fXlQHfAAwb



## SaaS版 - 南京浦光生物科技有限公司-SAAS端需求

南京浦光生物科技有限公司-SAAS端需求

一、需求背景本次需求主要涉及打印/全检客户端的权限控制，以确保不同服务之间互斥，避免逻辑混乱。

二、功能设计

1. 租户管理平台需进行服务管理模块和菜单管理模块的变更，具体包括：更新全检服务-需评等级、新增全检服务-无需评等级和全检服务-打印质量OCV服务；在自动检测记录模块中新增“检测等级”按钮权限，并将其与全检服务-需评等级服务关联。
2. 一站式服务平台需对质量管理目录下的“自动检测记录”模块中的“检测等级”列进行权限控制，控制策略为：租户平台定义好“检测等级”按钮菜单，并将该按钮菜单的权限字符在前端页面写死。用户登录系统后，访问该页面时，前端页面将用户有权限访问的全部按钮菜单对应的权限字符集合，与该页面“检测等级”列对应的权限字符名称进行对比，如后者在前者集合中存在，则显示该字段内容，否则不显示。

三、数据库设计该功能不涉及saas数据库变更。

四、接口设计需变更接口以返回当前登录用户的服务集合数据。

http://192.168.1.14:5000/d/f/xLh6z23anTLigOIRTqLpMPuwRb0RUHI1



## 一、2022.8.22优化需求开发

该文涉及四个需求点。首先，将SaaS前端调用的portal端接口进行剥离，以实现更好的解耦。其次，自定义上传的图片需按租户维度存储，并兼容新老路径。第三，优化任务名称生成方式，避免批号缺失时的任务名称重复问题。最后，为最小销售单元设置单位，满足包装标签显示需求。详细设计部分涉及前端接口剥离、模块功能以及路径兼容性处理。该优化旨在提高系统的灵活性和用户体验。

http://192.168.1.14:5000/d/f/xLh7BHDmBlqvXnb4LBzGgK1oRQA7hK8y



## SaaS版-首张打印+PDA质检业务详细设计

本次功能开发旨在优化SaaS端首张打印及PDA质检检测模块的操作流程，提升模块质量及稳定性。涉及功能包括UDI生产、打印全检、层级选择、打印首张打印模块、UDI生产任务完工模块和PDA质检检测模块。同时，需调整全检子任务逻辑，完善“完成”状态判定规则，并优化页面显示和开放平台功能。服务端模块功能设计包括新增全检子任务逻辑、调整完工检测接口业务逻辑和优化子任务完成状态判定规则。PDA SAAS模块服务设计需完善质检状态管理，开放平台中全检相关功能需单独存储全检状态，并更新质检字段内容。数据库设计需考虑表结构和字段关系，接口设计需遵循RESTful规范，定义请求方法、URL和参数等。通过这些措施，可以提高系统的操作效率和用户体验，为企业的生产管理提供有力支持。

http://192.168.1.14:5000/d/f/xLh6uSluyh10onD3GX8v2rOXi4o5ixGx



## WMS与UDI平台对接架构

UDI一站式服务平台上创建了WMS与UDI平台的对接架构，需参照肖斌写的接口设计文档执行中间交互过程。

http://192.168.1.14:5000/d/f/xLh6bPwbq6Kq87rSrjuqXZXRDj33jLBw



## SaaS版-私有化部署功能设计

广东健奥项目需要基于UDI-SAAS平台进行私有化部署，旨在将UDI-SAAS的应用、组件和数据库统一部署至健奥内部服务器环境。私有化部署不能影响UDI-SAAS已有功能模块，确保对其他租户无异常影响。设计目标包括完善UDI-SAAS的私有化部署，使其支持用户指定的服务器部署，并保持与UDI-SAAS的代码一致性。业务和功能架构与UDI-SAAS保持一致，但在权限管理部分存在差异。私有化部署平台包括多套环境，可扩展至其他用户。流程设计保持与UDI-SAAS一致，差异通过配置处理。租户管理表需扩充，增加业务配置字段。数据结构设计完整，满足项目需求。功能模块设计、打印、接口设计等细节将在后续部分详细描述。

http://192.168.1.14:5000/d/f/xLh6inNBy2DuJjYy2j0nf2AL0DoMxMSR



## SaaS版-PDA独立质量检测

总体设计主要描述了创建任务、UDI码扫描、质检记录查看和完成质检任务等流程，并强调了PDA独立质检功能。代码设计部分提到了需要新增一个接口用于解析UDI码，并判断其是否符合规范。数据结构设计包括uditasksub子任务表和udichecklog质检记录表.

http://192.168.1.14:5000/d/f/xLh6S0CWosEPx9ZrTtsJNHetKrOPqqHl



## Saas版 - 药监局数据同步兼容私有化环境功能设计

UDI一站式服务平台由高佳创建，具备药监局数据同步功能，适用于私有化和SaaS环境。背景说明中，打通了与药监局数据同步的6个接口，但需在药监局备案服务器IP。在私有化部署中，数据库和服务器由租户提供，可能导致访问未授权错误。影响范围包括对私有化和SaaS环境下的药监局DI数据同步或查询的全流程影响。总体设计包括当前与药监局数据同步流程、私有化场景下DI数据同步流程。功能模块包括租户平台、SaaS-UDI服务端和私有化UDI服务端。接口设计包括在SaaS和私有化平台新增的接口。此方案旨在解决在私有化部署中，由于服务器IP不固定导致的药监局接口访问问题，实现UDI数据的顺利同步。

http://192.168.1.14:5000/d/f/xLh6UifSWWgsntzRzvnpce210TmhqUX1



## Saas版 - 产品序列版本管理功能设计

SAAS-UDI平台在版本管理层面存在诸多问题，如版本标识不一致、版本逻辑对应关系缺失、私有化部署场景缺乏版本管理功能等。这导致无法追溯历史关联关系数据，且私有化平台进行版本升级困难。为解决这些问题，需要开发统一的SAAS平台产品序列版本管理功能。该功能将帮助管理员清晰了解并管理SAAS或私有化平台产品序列对应的版本信息，并便于后续版本升级。具体设计包括版本管理功能模块、版本更新业务流程、版本管理格式统一规范、功能兼容性等。数据结构将用于存储版本信息，功能模块将包括租户平台等。接口设计将包括版本管理、历史版本管理和版本基线管理。该方案将解决现有问题，提高SAAS-UDI平台的版本管理能力，为私有化部署场景提供更好的支持。

http://192.168.1.14:5000/d/f/xLh6RJlUs9z6nGVokGmgAcsALUU3UXpm



## Saas版-独立标签模板设计功能设计

此项目主要设计一个独立的标签模板定义服务，以满足多个项目需求。服务将独立于第三方系统运行，支持图形化标签模板设计，用户无需了解打印语言即可完成设计。服务还支持预览和打印功能，并提供数据接口以与其他平台集成。业务架构中，服务以iframe形式嵌入其他平台，提供两种鉴权模式。功能架构包括标签模板管理操作。数据结构、功能模块、代码框架和接口设计将根据实际需求进一步细化。此服务旨在提高标签模板设计的灵活性和可复用性，满足不同项目的需求，提高工作效率。

http://192.168.1.14:5000/d/f/xLh6l5rpGsYMWPXjvSo4wcgKgyUbfHmO



## Saas版-版本发布流程

UDI-SAAS平台和WMS出入库平台，包括多个项目。发布流程遵循以下步骤：

1. 在SVN目录编写新版本上线方案。
2. 基于主分支新建release分支，并保护分支。
3. 在PAAS平台构建分支，环境选择开发环境。
4. 在jenkins管理控制台进行部署。
5. 如果涉及PDA或客户端发布，还需在udi_sys_config表中更新版本号。
   发布时需注意：
6. 通常基于主分支（develop分支）发布。
7. 修复线上缺陷需拉代码修复分支，测试通过后构建新发布分支，再合并至主分支。
8. 发布后在相关工作群公告。
   版本管理要求：
   每次版本更新后，在租户平台完成平台产品序列版本更新操作，核心是手工更新当前版本和版本基线信息。

http://192.168.1.14:5000/d/f/xLh764L3iz8VEuib49343OnQHLdHhITJ



## SaaS版 - 多租户-服务-权限管理设计方案

本文描述了一个SaaS版的跨多租户、多系统的权限管理设计方案。该方案旨在统一管理UDI和WMS系统及其服务，并解决权限管理问题。方案目标包括实现租户管理平台对各系统的统一管理、系统间切换、WMS系统服务支撑以及服务过期管理等功能。同时，也明确了各个系统的影响范围，如UDI平台需新增服务过期校验，WMS平台涉及用户管理等。此外，还详细介绍了租户体系架构，包括总体系统架构、权限模型、逻辑模型等。最后，提到了各系统的改造要求，如UDI系统需实现服务过期后的限权功能。整个方案全面而细致，为多租户、多系统的权限管理提供了有效的解决方案。

http://192.168.1.14:5000/d/f/xLh6gQcZiQOJW0mMc14kyDkTMMvB83vQ



## 2023-01-16版本

UDI版本发布记录，包含前端和后端以及标签模板的前后端，于2023年1月16日上线。本次更新主要内容包括：

1. 标签模版设计测距的单位进行换算，提高了测距的准确性和用户体验。
2. 在线模版设计增加自动保存功能，降低了因意外退出造成的数据丢失风险。
3. 基础组件-图片增加搜索和常用图片，方便用户查找和使用常用图片。
4. Saas服务端列表字段优化，提高了列表的显示效果和用户体验。
5. 模板文字组件优化，增强了文字的可读性和展示效果。
6. 模版列表增加预览功能，方便用户在选择模板时预览模板效果。
   同时，BUG与优化内容也进行了处理，包括DI导入模板增加校验、编辑模板第二次报错修复等。此外，数据库表结构也进行了调整和优化，增加了常用图片库表和模板字典表等。这些更新和改进将有助于提高产品的稳定性和用户体验。
   总体来说，本次UDI版本发布是一次重要的更新，涵盖了多个方面的改进和优化，为用户提供了更好的使用体验和功能支持。

http://192.168.1.14:5000/d/f/xLh82QbsrMKjg7hm62sIiatQSPGbY5Cd



## SaaS版 - 租户平台-UDI平台-WMS系统权限整合改造方案

本文提出了对租户平台、UDI平台、WMS系统进行权限整合改造的方案。首先，将原有共用一个数据库的三个系统拆分为三个独立的库，并使用跨库视图、触发器和接口实现交集数据的处理。然后，针对租户平台、UDI平台和WMS系统分别进行改造，包括新增功能、权限统一控制和实现服务过期后的限权功能等。此外，还涉及到打单台和PDA的改造，增加登录权限验证和权限过期校验等功能。整个方案旨在提高系统的可扩展性和安全性，同时满足用户对不同租户和服务的权限控制需求。

http://192.168.1.14:5000/d/f/xLh6i9LkcrzPWcaW9dCODxwFFgpZiWLZ



## 1、支持多个厂商识别码设计

本文详细介绍了支持多个厂商识别码的设计过程，以满足企业在不影响原有操作的前提下，实现多个厂商识别码的编码和分段配置的需求。主要涉及修改思路、原型设计、业务规则、代码编写设计、数据结构设计和接口设计等方面。设计过程中遵循了数据验证、操作便捷和数据安全的原则。通过新增表、后端做效验逻辑、传参为list先根据当前租户为条件全部删除后重新新增等步骤，实现了支持多个厂商识别码的目标。同时，对DI分段编码进行了设计，实现了根据选择的厂商识别码查看到对应的分段信息和同步Gs1数据的功能。最终，通过数据结构设计中的新增表和接口设计，确保了整个系统的稳定性和可扩展性。本文为相关领域的开发人员提供了重要的参考和指导，有助于推动企业信息化建设的发展。

http://192.168.1.14:5000/d/f/xLh80S7yE904Sla1ORhHoP6dK5r2u94B



## 2、版本更新内容提醒设计

该文档主要描述了UDI零星需求的SaaS版更新内容。首先强调了更新内容需要及时通知客户的重要性。在影响范围中，明确了新功能与表格设计不会对现有功能产生影响，只在用户登录后对UDI一站式服务平台弹窗提示，PDA/客户端则不提示。总体设计部分，详细说明了原型设计、菜单和tab页切换、以及使用redis缓存的核心代码。此外，新增了版本更新表，用于记录版本号、端口、更新时间等内容。接口设计部分，提供了四个前后端接口，用于新增、删除、编辑和查询版本更新信息。总之，该文档为UDI零星需求的SaaS版更新提供了全面的设计和实现方案，旨在提供更优质的服务和用户体验。

http://192.168.1.14:5000/d/f/xLh7zo6WsyyLkPKVGKLjxgAtzkoDZAIa



## 3、V1.2.0_租户改造需求

本文详细介绍了SaaS版UDI零星需求的详细设计，包括整体业务流程图、目录、商机清洗、商机管理等功能。其中，商机清洗功能增加了官网客户录入的数据验证，清洗规则判断重复性和不合格数据。此外，还增加了导入商机、新增商机、编辑商机、导入记录等功能，并对原有功能进行了修改和优化。这些功能更好地满足了用户需求，提高了业务处理效率和数据质量。新增功能包括人员名单重复数量、重复企业数量、新增企业数量、记录数据每次的导入时间和人工处理后的更新时间，以及根据移动操作调整重复企业和新增企业的数量。通过实时更新相关字段，可实现数据的实时追踪和更新。

http://192.168.1.14:5000/d/f/xLh7zETs3nf3GE2QNKZV6NqbpcUb0c7b



## 4、V1.3.0_SaaS功能需求设计

本文描述了UDI零星需求在SaaS版本中的设计和实现细节。该需求包括自定义标签模板、UDI生产、全局设置、在线模板设计、数据源管理、许可证和地址管理、国际DI预分配、bug修复、操作手册更新、DI自动编码、增补UDI逻辑优化、并行打印以及批量提交申报等方面的内容。
需求主要影响标签模板打印、设计、并行打印，UDI生产任务和增补，以及DI自动编码和批量申报等部分。
设计方面，对自定义标签模版进行优化，改进数据配置方式，增加打印组件排序功能；UDI生产支持批量打印，并可根据udi_seq字段排序；国际DI预分配调整表结构，区分国际和国内DI，并支持预分配和已上市状态。
此外，还涉及数据结构设计和接口设计等方面的内容。最后强调该需求将增强SaaS版本的打印功能，提升用户体验和效率。

http://192.168.1.14:5000/d/f/xLh7yhynfKFp4DfmKnmBtlKIQpwCINCs



## 5、V1.3.0_租户功能需求

该需求文档主要描述了UDI Saas版在2023年的零星需求，涵盖了商机清洗、商机管理、客户管理等方面的功能优化和改进。具体来说，需求包括bug修复、数据统计页面优化、商机管理活动名称修改、筛选条件增加企业类型、客户查询状态和地区显示、客户主数据维护、开通服务区分预分配和正式开通、服务订购时长区分购买和赠送、批量续费、服务订购后时长修改以及增加企业续费周期表等。同时，也明确了数据结构设计中涉及的表结构，包括udi_tenant、udi_subscription、udi_serving和udi_service_record等。
这些改进旨在提升用户体验、优化数据管理和提高业务处理效率。通过修复bug、优化数据统计和查询功能，可以提升系统的稳定性和易用性；而增加筛选条件和主数据维护等功能，则有助于提高数据质量和准确性；此外，服务订购时长和续费功能的改进，将有助于满足用户的不同需求，提高客户满意度。
总体来说，该需求文档详细描述了UDI Saas版在2023年的零星需求，并明确了相关功能改进和数据结构设计，为开发人员提供了清晰的指引，有助于推动项目的顺利实施。

总之，这些改动和修复是为了提高UDI管理的准确性和用户体验，确保系统的稳定性和可靠性。

http://192.168.1.14:5000/d/f/xLh7xIpwj80kG4Ke1uNM5hOuhUL9VfdI



## 6、爱博诺德BUG修复版本

本文主要介绍了SaaS版-2023年UDI零星需求的修改内容和爱博诺德BUG修复版本。首先介绍了UDI管理DI编码配置的改动点及问题描述，包括默认厂商代码的设置、分段编码配置和产品分类选择等，并给出了影响范围和问题描述。接着介绍了UDI管理导入的改动点及问题描述，包括药监局注册证导入系统时的长度限制和UDI管理新增、编辑的字段长度等。最后介绍了客户端下载和自动更新的改动点，包括下载打印客户端地址和自动更新方式等。
针对这些问题，提出了相应的解决方案和实现方式。首先需要优化DI编码配置的默认厂商代码设置和分段编码配置，确保产品分类选择的正常显示。其次需要按照药监局的长度或规则来设置DI申报等相关导入的excel，以避免导入失败。最后需要优化客户端下载和自动更新的地址和方式，以满足用户的下载和使用需求。

http://192.168.1.14:5000/d/f/xLh7y17N1VEruOervvILs18WtuPwgL4z



## 7、Saas版-V2.0.0的不能层级设置不同PI规则，分别产码

UDI零星需求Saas版，版本V2.0.0无法设置不同PI规则的层级，需要添加生产对象表主键id。前端传生产对象list时，需额外传递序号list。其他部分保持不变。

http://192.168.1.14:5000/d/f/xLh814Romwp6fdYGA5MLelWNR54tmQU9



## SaaS版 - 产码与增补优化方案设计

UDI码根据PI规则分为唯一码和批次码。唯一码有随机序列号和自定义序列号两种形式，批次码则一批一码。产码时，非序列号遵循PI规则，序列号可选随机号和自定义。增补码需保持与初始产码格式一致，随机号增补时需判断总数不超过序列号位数的最高容纳数，避免死循环。

http://192.168.1.14:5000/d/f/xLh6ljSruxZjU7B4ov2fTQ93iq2jI4K2



## 二开改造功能点设计

该方案涵盖了多个功能点，包括分段编码配置、国内DI分配、国内DI申报和管理变更等。首先，分段编码配置涉及表设计、字段添加和核心计算方法。国内DI分配涉及表设计、原型和批量完善申报信息。国内DI申报的规格型号与DI分配一致，并设计存草稿和提交功能。国内DI管理变更则包括变更记录。此外，还涉及到GS1数据管理。总体而言，这是一个系统性的规划和设计方案，旨在实现编码管理的全面优化和规范化。通过这一方案，可以实现编码的精细化管理，提高编码的可用性和准确性，从而为企业的运营和管理提供有力支持。同时，该方案还考虑到了实际操作中的各种需求和限制，如规格型号的递增修改、批量操作等，具有很高的实用性和可操作性。

http://192.168.1.14:5000/d/f/xLh7wFYCoBzJNi3XdHiWlt0rCZn6IDhz



## 支持同用户多企业功能设计

支持同手机号用户在多个企业间切换。用户登录时，系统会缓存token值，切换租户时，后端切换用户信息，前端重新获取用户信息与权限。若手机号已存在其他租户，本租户只能关联该用户，前端提醒是否关联。接口设计包括关联租户用户、租户列表和租户切换，以实现系统的需求。

http://192.168.1.14:5000/d/f/xLh7vYgmAM0ZDqQSH6NiOeKTJOrPMROJ

 

## SaaS版 - DI导入相关场景的梳理与优化

对DI导入相关场景进行了梳理与优化。包括四个导入场景：Gs1数据管理、国内DI预分配、国内DI申报、国际DI预分配。针对每个场景的DI导入模板差异，支持不同模板导入；快速校验和大批量快速导入需求；并发导入场景的考虑。优化设计方案遵循前端初步校验和后端通用校验原则，批量导入数据循环前进行校验，关键查询添加索引，做批量插入，并使用合适容器和算法提高效率。根据数据量大小，设计同步或异步处理策略。

http://192.168.1.14:5000/d/f/xLh6VyaLjO7SqxMEx1Pd9ZO0kbod5tfQ



## 迈思私有化

迈思私有化项目涉及多个方面，包括需求范围、部署架构、数据处理流程、业务流程和相关功能修改设计。在物料绑定DI方面，需要添加diid字段，并规定绑定、解除绑定和搜索等规则。UDI生产订单表结构也需要修改，并需考虑同步生产订单的规则。部署架构、数据处理流程和业务流程等其他方面的具体内容未提及。此方案有助于规范物料绑定DI和UDI生产订单的管理，提高工作效率和数据准确性。

http://192.168.1.14:5000/d/f/xLh7Af2jByvJhw6RiUfaY17ipjA9g1FC



## 迈思私有化-接口平台设计说明书

该文档主要描述了迈思私有化-接口平台的设计说明书，包括目标和范围、主要功能、数据设计等方面的内容。该接口平台旨在统一管理UDI与所有外部系统的对接和公开暴露内部系统接口，支持对接不同的外部系统及不同版本，为内部系统转换第三方系统数据格式。主要功能包括接口参数管理配置、第三方系统管理、接口管理与字段管理、认证和日志等。此外，还介绍了第三方数据对接的方式，包括同步数据、获取数据和推送数据等。数据设计部分则对数据格式转换进行了说明。该平台通过统一接口平台管理内部系统公开接口与鉴权，实现不同系统的数据转换和集成。

http://192.168.1.14:5000/d/f/xLh6fDG4g8M49z1c8L1a2CQD4OHrGTOn



## 租户管理平台

该平台涉及多个表，包括商机表、商机公司表、跟进记录表、导入商机记录表和商机标签表等。当前

http://192.168.1.14:5000/d/f/xLh6mHfX5oxcvjCNe3xj8FljRKI3gLB0



## 交接资料

该平台提供交接资料和文档，包括UDI平台.pos和UDI平台.xmind，同时也提供了电子表格。平台可通过链接访问。

http://192.168.1.14:5000/d/f/xLh6TAj2YWOpfwk6USooeCQh6UL7gIxQ



## WMS改造工作量评估

WMS改造工作量评估背景复杂，丹大版本与UDI和CRM系统数据库表交杂。若成都稳健版本复制丹大部署，将导致体系更加混乱。改造后用户数据、菜单、服务数据可统一管理，UDI 系统、WMS系统的业务数据交互可通过统一接口平台进行对接，包括第三方ERP系统等。

http://192.168.1.14:5000/d/f/xLh6fo9vabmSO7LFwVGQ6f0a0JsSovSw



## 珠海尼诺私有化设计

私有化设计项目包括四个部分：Saas端改造、WMS端改造、客户端改造和部署方案。其中，重点在于新增数据分弹窗、打印数据接口加锁和增补打印外箱接口。部署方案中，考虑到数据量巨大，Saas端需独立部署并新开数据库分库，而WMS端则在Saas服务器上单独部署。

http://192.168.1.14:5000/d/f/xLh6Pbt7LveS75akEkAvGZumNVgpd0WP



## 鱼跃UDI与睿展模板设计平台集成方案

鱼跃UDI与睿展模板设计平台集成方案主要包括部署与集成方式、系统之间的交互关系和平台间数据对接详情。建议以鱼跃UDI平台前端为主体，集成模板设计平台的前端，采用单点登录做系统之间的认证，并将两者部署到同一服务器。数据内容方面，包括用户数据、模板数据、模板动态组件数据、模板组件翻译数据、UDI码数据、赋码指令和赋码结果等。需要评估和调整标签定义工具的关联产品和动态数据源组件的管理方式。综合以上内容，需要进一步明确和解决相关问题，以确保两个平台的顺利集成。

http://192.168.1.14:5000/d/f/xLh6cgHtk8HLPEj4mfipfzGrxskJq5lq



## SaaS-防伪溯源小程序设计

该SaaS防伪溯源小程序设计主要涉及消费者、监管员和后台三个部分。消费者可以扫码获取产品信息，监管员则可进行产品监管和信息上报。后台采用多租户模式，独立对接UDI和物码平台，并支持小程序配置。部署架构中，三个服务可部署在同一或不同服务器上，小程序需能对外网暴露。业务流程中，小程序只负责数据展示与获取，WMS负责存储和提供出库信息，UDI负责窜货信息展示。接口清单包括监管员分页查询、新建与编辑、状态修改、删除窜货信息查询、处理等接口。此外，还涉及用户手机号鉴权、注册和码信息查询等接口。表结构设计未具体提及，但需综合考虑以上需求和业务流程。该设计对现有业务无风险，主要涉及SaaS防伪溯源模块和WMS系统的改动。

http://192.168.1.14:5000/d/f/xLh6nN5GUDcCace7p1xXAYuagEgfNVOm



## cms管理后台 - 产品管理/资讯管理功能设计

本文是对CMS管理后台中资讯中心和产品中心模块的功能设计。主要涉及资讯和产品的增删改查处理，以及所属分类管理。在基本功能层面，两个模块业务流程类似，以文章管理和分类管理为例，支持新增、编辑、删除、预览、排序和分页查询等操作。文章管理支持以表单形式新增文章数据，包括标题、分类、摘要、图片、内容等元素；支持对新增文章执行编辑、删除、预览及排序操作；以分页列表形式查询已有文章数据。分类管理支持新增、编辑、下架及排序操作；支持以树形结构查询文章分类信息。此外，还设计了文章回收站功能，支持永久删除已删除文章。
在抽象设计上，资讯和产品共享一张数据表，后续其它场景下的业务数据维护也可与资讯、产品继续公用一张表，以增加扩展性。主体属性以json数据格式进行管理和存储，其他字段根据查询场景确定是否独立保存。
数据库设计方面，资讯管理和产品管理共用一张数据库表。接口设计包括新增、更新、删除资讯/产品接口，以及分页查询和详情查询接口。
综上，本文提供了资讯中心和产品中心模块的功能设计细节，包括基本功能、抽象结构、数据库设计和接口设计，为CMS管理后台的开发提供了全面的指导。

http://192.168.1.14:5000/d/f/xLh87xVK0E3SIyKu3Ea0x4528rMZNCgM



## cms-管理后台-文章违禁词管理

该文章主要介绍了违禁词管理的需求背景、涉及功能、功能设计和实现设计。在功能设计上，支持新增/编辑违禁词、列表查询违禁词和删除违禁词。在实现设计上，新增/编辑违禁词需判断站点已存在，查询标题、描述、内容、关键词中是否存在此违禁词；咨询中心、产品中心、栏目分类需判断标题、摘要、内容、关键字是否包含此站点下存在的违禁词；模板上传需判定压缩包内文件是否存在此站点下存在的违禁词。通过查询违禁词集合和使用stream().filter筛选，提示用户并记录相关url或文件路径。文章提供了详细的功能和实现设计，有助于实现高效的违禁词管理。

http://192.168.1.14:5000/d/f/xLh89IFOQGHKrkYS95VF5ZoTJrKMXnUK



## cms-管理后台-用户跟踪

本文主要介绍了CMS管理后台中用户跟踪模块的设计与开发。用户跟踪用于记录用户的每一次操作记录，包括IP、地区、终端、访问时间、访问页面URL、停留时长和询盘信息。该模块不会对其他模块产生影响。总体流程包括数据获取、解析、对比和呈现。功能设计包括下级页面、文章和产品的展示规则，以及定时同步和手动同步的逻辑。页面设计包括弹窗草图和询盘图弹窗页面。数据库设计包括三张表：51La访问明细接口记录表、用户主体记录表和访问记录共享表。接口设计包括新增或更新访客、访客记录新增或更新和用户跟踪统计接口等。

http://192.168.1.14:5000/d/f/xLh8Dlr5eGFw7S2v9kS0GAhiTAEq6Xfk



## cms管理后台-轮播图管理/技术资源管理

该文章描述了CMS管理后台中的轮播图管理和技术资源管理的需求背景、涉及功能、功能设计和数据库设计。其中，轮播图管理支持新增、下架、上架、设置新URL和记录点击量，技术资源管理支持新增、审核、批量删除、记录点击量和文件管理。数据库设计方面，资源文件与轮播图共用一张数据表，回收站也共用。

http://192.168.1.14:5000/d/f/xLh8Bf00gMXpEkkC7LFegUj2kXTtQ9YH



## cms-管理后台-运营罗盘

本文详细介绍了CMS管理后台的关键词分析、产品分析和文章分析功能的设计和开发。其中，关键词分析涉及站内关键词的搜索次数、统计和占比情况，产品分析和文章分析则基于51La接口获取数据。为确保数据准确性和完整性，采用定时和手动同步方式从51La接口获取数据，并进行对比更新。数据库设计方面，产品、文章共用一张数据库表，关键词单独用一张表。此外，还提供了接口列表以便调用。本文详尽地阐述了相关功能的背景、影响、设计及实现方式，为CMS管理后台的优化和完善提供了有力支持。

http://192.168.1.14:5000/d/f/xLh8EfdGi1pXG1PwJwcuUEmd4MKS7p0C



## Nuxt.js静态化打包指南

Nuxt.js是一个基于Vue.js的开发框架，用于实现服务端渲染和静态网站生成。静态化打包是Nuxt.js的一个优势，可以提高SEO效果、首屏加载性能和服务器性能。Nuxt.js项目的核心配置文件是nuxt.config.js，可以通过配置选项和路由配置进行静态化打包。Nuxt.js的目录结构包括pages、layouts和assets目录。静态化打包与传统渲染不同，它是在构建时生成所有页面的静态HTML文件，直接提供静态资源，减少服务器端渲染和客户端渲染的过程。数据获取、动态路由和参数化、静态资源与优化等都是静态化打包中需要考虑的问题。部署和上线时，需要构建静态页面并进行托管。使用Nuxt.js静态化打包可以提供更好的用户体验和网站性能，是构建复杂Vue.js应用的一个强大工具。

http://192.168.1.14:5000/d/f/xLh88a6lh6xK3QRXpKXdDz45RGMZOBIb



## 亚马逊服务器配置

亚马逊服务器配置步骤包括VPC、EC2、Redis、RDS、ALB和目标组，遵循特定的顺序进行。

http://192.168.1.14:5000/d/f/xLh8jiiozLCZs0YhVFJJvd4m1B2N0NSd



## ALB创建

描述了如何通过ALB创建负载均衡，需选择VPC、安全组、侦听器和路由，并创建负载均衡器。完成后，可跳转到详情找到DNS作为访问地址。

http://192.168.1.14:5000/d/f/xLh8hnMUmdTHCLXOfN2yrZOtkTCdgSid



## EC2实例创建

亚马逊服务器配置，包括登陆控制台、选择EC2实例、启动新实例、选择实例类型和网络设置等步骤。注意vpc、子网和安全组的选择和配置。

http://192.168.1.14:5000/d/f/xLh8leeLRqtRZN7nRAbvROPsGYdTLsh2



## RDS数据库创建

如何创建RDS数据库。选择mysql 8.0.32引擎，测试环境模板，设置数据库名称、账户和密码。选择db.m6g.large配置，默认存储和连接配置，注意安全组设置和身份证验证。监控配置可自行选择。

http://192.168.1.14:5000/d/f/xLh8gG84dt3vgRYyhTIOyKJ8Jsyn82BS



## Redis创建

创建Redis集群：在ElastiCache中搜索Redis，禁用集群配置，选择cache.t4g.medium节点类型和2副本，连接新子网和VPC。设置安全组，并完成创建。

http://192.168.1.14:5000/d/f/xLh8mB0cHH9UfHQZHiGLaroSzpbuJK6C



## VPC创建

详情见图

http://192.168.1.14:5000/d/f/xLh8kMkGKWF0HBqGERP3kXnKwwfqhwFI



## Waf设置

在创建WAF时，需注意填写名称，并可选择添加AWS资源。安全规则中，添加相关安全规则，并设置默认允许未匹配任何规则的请求。拦截日志可选择开启。

http://192.168.1.14:5000/d/f/xLh8l0cu6fqlF694yXJLy7BF1J0ejt09



## 安全组创建

亚马逊服务器配置安全组，需在EC2中寻找网络与安全，选择vpc并命名，点击创建安全组完成配置。

http://192.168.1.14:5000/d/f/xLh8j6OyQYOL2D7HuulyhUQLBbLkrDlz



## 目标创建

按照搜索EC2、找到目标群组、配置目标群组、注册目标的步骤完成操作，最终创建了一个目标群组。

http://192.168.1.14:5000/d/f/xLh8fgDogeUiWCvOLcgWRxK9AOczSczv



## 分支结构

分支版本管理规范，明确了不同分支类型的命名、来源和合并目标。Master分支为纯主线代码，不进行开发；Feature分支用于需求功能开发，完成后合并到Master；Release分支用于产品版本发布测试，每个版本一个；Hotfix分支为bug修复分支，修复后合并到Master或Release。分支命名遵循站点-feature-版本-需求号的规则。此规范有助于统一管理分支，提高开发效率。

http://192.168.1.14:5000/d/f/xLh8InoFc2PKyE7C8vDd49Mur6auyWPa



## 网关应用IP限制

这是一个关于项目管理和CMS官网平台的概述，详细描述了网关接口的配置和IP限制的必要性。由于生产环境的Nginx未做IP限制，存在安全风险，所有需经过网关的接口需要在Nginx中做IP限制，只允许网关IP访问。文中列举了多个接口名称、认证方式、对外访问路径和后端地址，包括cms-us-web、vazyme-shop-manage、xxl-job-admin等。这些接口涉及前端认证和后端认证等多种认证方式，对外访问路径和后端地址也各不相同。
为了确保系统的安全性，限制IP访问是非常必要的。通过在Nginx中设置IP限制，可以防止未经授权的用户访问这些接口，从而保护系统的数据安全。此外，文中还提到了部分接口不走网关的情况，这些接口可能存在其他的安全措施或者特定的业务需求。
综上所述，对于生产环境的Nginx，限制IP访问是非常重要的安全措施。通过合理配置网关接口和实施IP限制，可以大大提高系统的安全性，防止潜在的安全威胁。在实际操作中，还需要根据具体业务需求和安全策略进行细致的规划和配置，以确保系统的安全稳定运行。同时，对于不走网关的接口，也应采取相应的安全措施，确保整个系统的安全性。

http://192.168.1.14:5000/d/f/xLh8AUKhNGR5Lrgxw6svqC4dAVOASBvQ



## 美国官网时区相关配置

该总结描述了对代码和配置的调整，包括查询JsonFormat注解、重写SQL脚本中的NOW函数、获取美国时间并调整时间戳获取方式等。同时，也提到了调整过程中遇到的问题和解决方案，并针对后续前端问题3进行了补充总结。

http://192.168.1.14:5000/d/f/xLh8FaP2j171LdFKmTDLQ5Q6ty60oVyi



## 花旗银行对接

本文介绍了花旗银行与CMS官网平台的集成方式，其中重点介绍了基于Hosted Checkout的集成方式。用户下单后，通过调用花旗银行相关接口发起支付请求，跳转到花旗银行支付页面，用户选择付款方式、输入卡号密码、确定支付，花旗银行返回交易信息给购物网站，购物网站展示交易的订单信息给用户。调用花旗银行API需要商户账户，并获取相关的商家id和api密码。后台通过post请求Api接口进行交互，具体参数说明参见请求接口参数说明。
用户可以通过调用花旗银行支付页面进行支付，支付成功后，系统会通过回调操作返回订单信息和支付结果。用户可以在商户订单和交易详细信息页查看交易和订单信息。如果需要退款，可以通过退款接口进行操作。回调操作的URL需要拼接订单信息，并判断返回的resultIndicator是否一致。退款接口需要传入正确的参数，包括操作类型、金额和货币类型等。
在使用这些接口时，用户需要注意参数的正确性和安全性，以确保交易和退款操作的成功。花旗银行支付页面提供了一个安全、便捷的支付方式，可以满足用户的支付需求。同时，CMS官网平台也提供了一个易于使用的后台管理系统，方便用户进行订单管理和商品推广。通过花旗银行与CMS官网平台的集成，可以提升用户的购物体验和支付体验，促进电商业务的发展。

http://192.168.1.14:5000/d/f/xLh8drofApsp2nMWCoup1F8U1aV7ENMs



## Direct Payment集成

流程图描述了付款人通过应用程序或网站提供卡信息，交易请求通过API发送到Spring by Citi Payment Gateway，再传送到收单行处理。收单行返回交易响应，指示交易是否成功。同时，订阅通知可以给客户发送邮件通知，但待验证。总结为：付款人通过应用或网站提供卡信息，交易请求通过API发送到Spring by Citi Payment Gateway，收单行返回交易响应，同时可订阅通知但待验证。

http://192.168.1.14:5000/d/f/xLh8f0vBG9l744kK0bWPvqdR3XOsbGW4



## Hosted Checkout集成

主要介绍了Hosted Checkout集成的四种方式。其中，基于Hosted Checkout的集成方式是重点。这种集成方式流程包括用户下单、调用花旗银行相关接口发起支付请求、跳转到花旗银行支付页面、用户选择付款方式、输入卡号密码、确定支付、花旗银行返回交易信息给购物网站等步骤。在调用花旗银行API时，需要商户账户和相关的商家id、api密码。后台通过post请求API接口，并配置相关参数。此外，还提到了收据和退款等后续操作。整个流程清晰明了，为商户和用户提供了便捷的支付体验。同时，也需要注意遵循花旗银行的规定和要求，确保交易的安全和顺利完成。

http://192.168.1.14:5000/d/f/xLh8dCW1kMKfZfVsOZhwMOWxMXYN6MN5



## 测试流程

花旗银行对接流程包括Initiate Checkoutpost请求获取sessionId，调用花旗银行支付页面，输入测试卡号，并点击支付。成功后获取订单信息。请求方式为get，请求地址为https://test.gateway.spring.citi.com/api/rest/version/67/merchant/TESTVAZYME000001/order/202302130926020102。

http://192.168.1.14:5000/d/f/xLh8eRIWQyBw9lBgXUuB5zl3ZpYSUHIQ



## PO订单设计

这段内容描述了一个将CRM中的PO订单信息更新至官网的轮询过程，涉及规则、数据更新、状态转换等多个方面。处理运输状态不一致和时区问题需特殊考虑，以确保数据同步的准确性和完整性。

http://192.168.1.14:5000/d/f/xLh8cDUGm2NmO29i0LfZeHKxef3GM1DH



## 产品中心设计

该设计包括产品详情内容的自由标签，支持多个详情内容编辑与展示。新增/更新逻辑为先删除再新增，记录操作日志。查询接口增加产品类型明细。前端采用element-ui的标签页组件展示。

http://192.168.1.14:5000/d/f/xLh8Zs0qbicwh36FJvPmPcMntxrDWbxA



## 包邮管理设计

该设计描述了包邮活动的规则设定、数据库设计以及业务场景。它涵盖了新增/更新包邮规则、删除包邮规则、分页列表展示和查询订单是否包邮等场景。其中，包邮规则可以同时设置满额和满件，包邮区域提供多选，记录操作日志。查询订单是否包邮接口根据商品信息、州和时间判断是否满足包邮规则。在结算页，会调用该接口校验包邮状态和活动变更。

http://192.168.1.14:5000/d/f/xLh8bIQtczy9Uqm7MQggMZCCmk94IkmP



## 合作管理设计

合作管理功能需求详细描述了合作商管理系统的各项业务场景，包括新增/更新、删除、上移/下移合作商等操作，以及分页列表和查询合作商的Tag功能。在新增/更新合作商时，需要校验公司名称的唯一性并提示用户，同时要求填写必填字段。在删除合作商时，需要更新状态字段并记录操作日志。上移/下移合作商时，需要查询所有启用状态的合作商，并根据排序号进行增减操作，同时记录操作日志。分页列表合作商时，需要展示类型、公司名称、国家、电话、邮箱、上架状态、排序、创建时间等字段，并提供编辑、删除、下移、上移等操作。查询合作商的Tag时，需要在mdiy_tag表中创建tag模板，并使用SELECT语句查询符合条件的合作商信息。此外，无标签表示该功能需求已通过评审。综合来看，该需求设计对合作商管理系统进行了全面而细致的规划，为后续的开发工作提供了明确的指导。

http://192.168.1.14:5000/d/f/xLh8YKdctsWcstXNFMnDOX6NAf0KsRQA



## 标签管理设计

该需求设计主要围绕客户标签管理展开，以满足特定规则的客户自动添加标签的需求。设计内容包括需求描述、原型设计、数据库字段修改以及接口服务。需求描述中明确了自动打标条件、历史累计消费次数、历史消费金额、客单价和客户类型等要求。原型设计中明确了最近消费时间的动态获取、自定义时间设置、交易时间定义、自动打标条件的默认勾选及提示等细节。数据库方面，需要新增或修改字段以支持新功能。接口服务则需考虑场景、标签条件、新增逻辑、手动删除逻辑及接口服务等。最终目标是满足所有条件其中一个条件的客户，判断逻辑需要综合考虑以上各个方面。整个设计过程需要细致考虑每个环节，确保最终实现的功能能够满足客户需求，提高客户满意度。

http://192.168.1.14:5000/d/f/xLh8Z72EZxEnUqEU7huVIzMgTHIe0o0u



## 渠道管理设计

商城系统的渠道管理设计是关键环节，涉及新增渠道、查看和编辑操作等功能。交互设计中的搜索和筛选功能，以及PV、UV和注册数量等统计数据，为运营人员提供决策支持。数据库设计新增了渠道表，包括channel_id、channel_name和delivery_channel等字段。用户注册渠道信息流程图和渠道数据统计时序图，也展现了设计的完整性。
此外，数据库的字段变更进一步增强了商城系统的灵活性和可扩展性。在“渠道访问记录表”中，log_id、channel_id、ip、access_time等新字段的加入，以及字段数据类型和索引的修改，适应了业务需求的变化。在“用户表”中，新增的channel_id字段记录了用户的注册渠道ID，提供了更多维度的数据支持。
总之，商城系统的渠道管理设计经过深思熟虑，既满足了运营人员的日常操作需求，也适应了业务的发展变化。数据库的字段变更增强了系统的灵活性和扩展性，为商城的长远发展奠定了坚实基础。这一系列设计有助于提升商城的运营效率和用户体验，为商城的持续发展提供了有力保障。

http://192.168.1.14:5000/d/f/xLh8agFqdEtHEH5veMlbsx4kQ8y8IJpx



## 【2.4.0】CMS资源静态化

这是一个关于CMS（内容管理系统）资源静态化的技术文档，涵盖了功能描述、模块清单、数据库设计修改、业务场景等多个方面。作者邓敏杰详细介绍了根据国家字段和业务数据生成静态页面资源的功能，并提供了相关的模块清单和数据库设计变更信息。在业务场景部分，作者列举了分类创建更新上架和文章创建更新上架所涉及的模块清单，并详细描述了各个方法的作用和参数。此外，作者还提到了对net.mingsoft.cms.util.generateList中页面路径生成和页面生成的优化，可以根据国家编码集合循环插入国家参数，生成对应国家的静态页面。

http://192.168.1.14:5000/d/f/xLh8NnD1OwfoxRtz1yYcwjaxxKHZFFJC



## 【2.4.0】产品中心设计

该文档是一份关于国际化商城的产品中心设计的详细说明。它主要包含功能简介、业务场景、业务逻辑、交互设计等方面的内容。
该国际化商城旨在提供个性化的购物体验，通过识别用户所在国家，智能展示相关商品和本地货币信息。管理员能够精准发布和分类商品，并根据用户所在地调整价格。
在业务逻辑部分，文档详细说明了产品分类管理和商城端展示的流程。分类管理端增加了选择发布国家的选项，根据地区字典树形结构进行选择。商城端则根据用户IP所在国家展示相应内容，包括产品分类、币种和推荐产品等。
交互设计部分对新增编辑产品分类、产品管理列表页等界面进行了详细说明，包括字段添加、筛选项设置等。
总的来说，这份文档为国际化商城的产品中心设计提供了全面而详细的指导，有助于实现高度个性化的购物体验和精准的商品管理。

http://192.168.1.14:5000/d/f/xLh8WyTYpYcxcPr9WUYqFRxa99JpkECp



## 【2.4.0】包邮活动国际化

包邮活动国际化的功能允许商家针对不同国家创建包邮活动，用户只能参与所在国家的活动。在数据库中，包邮表和包邮规则表的相关字段进行了修改，新增了国家集合和币种字段。业务场景中，详细描述了新增、更新和包邮活动计算的需求。在代码层面，需要在ExemptPostageItem中增加区域集合和币别字段，并对ExemptPostageService中的保存更新方法进行改造，包括对区域数据的先删后增操作，以及将区域名称数据冗余到包邮表中的操作。该功能旨在提升用户体验和商家营销效果，通过更精细化的地域和货币适配，提高用户参与度和购买意愿。

http://192.168.1.14:5000/d/f/xLh8M5TRRgE7BA73WVD6a4cNhn46qdG2



## 【2.4.0】区域划分

该总结主要介绍了区域划分数据库设计、枚举值level的区域级别、区域选择组件和CMS工程如何调用CMS前端对接商城后端获取数据。首先，区域划分数据库设计包括大洲、国家、州和城市四个层级，每个层级都有对应的API接口。枚举值level的区域级别包括CONTINENT、NATION、STATE和COUNTY，用于标识不同区域级别。区域选择组件基于el-cascader，可根据tier属性加载指定层级的数据。此外，CMS工程调用CMS前端对接商城后端获取数据的方法是将数据表映射为CMS库的视图，再将代码拷贝到CMS。需要注意的是，不推荐直接拷贝代码，因为这可能导致数据安全问题。在事件处理方面，该系统监听区域变更和删除事件，通过事件类名和事件说明来判断需要处理的事件类型，并传递相应的事件属性。
综上所述，该总结介绍了区域划分数据库设计、枚举值level的区域级别、区域选择组件和CMS工程如何调用CMS前端对接商城后端获取数据等方面的内容，为相关人员提供了有关区域划分的数据库设计、事件处理等方面的参考信息。

http://192.168.1.14:5000/d/f/xLh8R31owDdpZXKPOJN5jmUnRMGkarP1



## 【2.4.0】商城用户“是否管理员”维护

商城用户“是否管理员”维护1.1功能描述：前端未登录及普通用户根据亚马逊IP解析国家访问，管理员可切换更换国家。数据库设计需在用户表tz_user中添加is_admin字段。

http://192.168.1.14:5000/d/f/xLh8MfEtpxZXM8urSeYzBgqjxBAdjug6



## 【2.4.0】币种管理

2.4.0版本的币种管理数据库设计包含对币种变更、删除、解绑事件的监听。这些事件包括CurrencyRemovingEvent、CurrencyUpdatedEvent和RegionCurrencyRemovingEvent。当监听到这些事件时，系统会根据事件描述和属性进行相应的处理，如抛出异常或更新业务数据。同时，提供相关SQL展开源码以供参考。

http://192.168.1.14:5000/d/f/xLh8W9NlPrRbxVpV3MqLeAwcx77MBH4X



## 【2.4.0】标签管理设计

2.4.0需求设计主要是标签管理的改进，以满足全球化用户的需求。交互上，新增标签功能，用户点击后弹出框增加国家字段，并支持币种搜索条件。同时，前端校验要求币种必填。在历史消费金额和客单价中，新增币种选项，后台逻辑相应修改。数据库方面，修改了tz_user_tag表，添加了两个币种字段。

http://192.168.1.14:5000/d/f/xLh8QNjBVkh3G2j0qhtBvBm58YQLI3w0



## 【2.4.0】根据用户IP访问定位国家



http://192.168.1.14:5000/d/f/xLh8UAl3DVs3Y9UJhwfBwhYhuyBBm4GJ



## 【2.4.0】税率管理国际化

税率管理国际化的功能描述是：根据用户下单地址，针对国家维度创建并计算税率。在数据库中，税率表vztaxrate新增了名为“nation”的国家字段。业务场景主要涉及新增和更新操作，并特别提到了国家州有值和null两种时间区间内的数据唯一性校验。代码调整中，com.vazyme.shop.service.impl.check类中增加了国家参数的校验，并调整了相应的SQL查询语句。此外，还涉及税率导入和导出的业务场景。

http://192.168.1.14:5000/d/f/xLh8LQJbaFjfF2fTvqn2bd2dDNNFHlXB



## 【2.4.0】网站管理

网站管理功能主要涉及国家维度的结算方式和销售组织的维护。数据库设计增加了网站管理表和业务关联国家表。业务场景中，前端根据IP和结算方式展示不同内容，如询价时禁止订单提交并显示相应按钮。后端新增页需要选择网站类型、结算方式、PO模版、发布国家和销售组织。列表页仅需常规CRUD操作，且发布国家需唯一。此外，后端“询盘中心”来源为“询盘询价”时需增加相关展示，并对历史询价数据进行初始化处理。整体而言，该网站管理功能相对完善，考虑了多个维度和场景。

http://192.168.1.14:5000/d/f/xLh8UxISSc3wlizVttunED4Ci5XYF8pC



## 【2.4.0】营销管理设计

该文档详细介绍了国际化商城的营销管理设计，包括功能简介、业务场景、业务逻辑、交互设计、实现流程设计和数据库设计等部分。商城旨在提供个性化的购物体验，根据用户所在国家展示相关活动/优惠券，管理员可精准发布不同国家的活动/优惠券，并根据用户所在地调整价格。交互设计部分涉及活动/优惠券管理列表、新增/编辑页、优惠券中心、我的优惠券等界面的设计，展示当前IP国的优惠券，并根据IP国家展示商品、活动、优惠券、价格、币种等信息。实现流程设计部分则提供了设计时序图。此外，数据库设计部分对活动优惠项表和优惠券表进行了修改，增加了币别字段。整个营销管理设计旨在提高用户体验和购物便捷性，同时满足管理员的精准发布需求。

http://192.168.1.14:5000/d/f/xLh8TSu1cR8lniqvLwbDjKWDUhR8G2uv



## 【2.4.0】询盘中心增加IP所属国家字段

对询盘中心进行了更新，增加了IP所属国家字段。数据库中的CMS分类表（cms_inquiry）也相应进行了字段变更，新增了“nation”字段，用于存储国家信息。业务场景中涉及的接口用于获取国家代码，并在显示时查询对应的中文名称。

http://192.168.1.14:5000/d/f/xLh8PYLmwqO8yIsEMFZqLNZA2viawRTz



## 【2.4.0】资讯中心-文章管理设计

该需求设计主要围绕资讯中心的文章管理展开，包括全球使用支持、业务场景、交互设计与实现、相关改动、数据库表设计和初始化数据。交互部分要求推荐国家和发布国家联动，首页推荐时推荐国家为必填，每个国家文章推荐数量限制为4，超过则提示。文章列表新增发布国家字段和查询，超过5个用数字代替。导出、上下架和编辑修改等操作也需调用静态化服务。CMS模板静态渲染涉及mdiy_tag表相关SQL。数据库表设计见轮播图管理设计的第5点。初始化数据包括插入cms_biz_country表的语句。此方案旨在优化资讯中心文章管理流程，提高用户体验和数据管理效率。

http://192.168.1.14:5000/d/f/xLh8XcV0AjP3nUnA1ijuDsBvGvCllXeG



## 【2.4.0】轮播图管理设计

该需求设计主要围绕轮播图管理的功能展开，包括全球使用支持、原型设计、交互设计与实现、相关改动、数据库创建和初始化数据等部分。
首先，需求规定轮播图支持全球使用，且多个国家可以共用同一套轮播图。原型设计方面，每个国家的首页展示位置已经明确。交互设计与实现部分，新增轮播图功能需进行前后台校验，每个国家图片数量最多5张。新增接口地址为ms/cms/resource/addCarouselList，入参为CmsResourceBo对象和新增的countryId属性。回收站轮播图上架逻辑与新增逻辑保持一致。列表新增国家查询使用蒋定轩的国家组件查询。
此外，相关改动中提到cms模板静态渲染需要用到mdiy_tag表相关sql。数据库方面，需要创建表cms_biz_country，包含id、biz_id、type、country_id、country_code和recommend_status等字段。初始化数据时需加上国家过滤条件。
综上所述，该需求设计为轮播图管理提供了全面的解决方案，从交互设计到数据库创建和初始化数据等方面都有明确的规划和实现方式。该方案考虑到了全球使用和多国家共享轮播图的需求，并提供了详细的前后台校验、图片数量限制等细节。相关改动部分也针对现有系统做出了一些调整，使得整体方案更加完善和符合实际需求。

http://192.168.1.14:5000/d/f/xLh8SW0G7y0Qx3lzysb1NecoQ0OFV5WR



## 【2.4.0】隐私合规



http://192.168.1.14:5000/d/f/xLh8OjFzVDgqABJ6BfQnIakZDxrNOPAC



## 官网总体设计

该文档是关于诺唯赞官网电商项目的详细设计说明书。说明书旨在为开发人员提供精确的系统需求理解和程序设计蓝图，以便完成相应功能的代码。面向的读者包括管理人员、系统设计人员、代码编制人员和系统实施人员。该电商项目旨在设计一款功能齐全、易于使用的电商系统，满足用户在电商平台上进行购物、交易等需求。系统将包括用户中心、产品中心、订单中心、消息中心等多个功能模块，并提供安全、稳定、高效的运行环境。该文档对系统进行了综合描述，并详细设计了各个模块的功能，如用户中心、产品中心、订单中心等。此外，还提到了其他相关内容，如调整点、用户等。整个文档结构清晰，内容详细，为项目的开发提供了重要的参考和指导。

http://192.168.1.14:5000/d/f/xLh8Kf3OQOPeU7cWZAej8g1VAt6g1Prb



## 邓白氏

美国邓白氏公司 (纽约证券交易所代码: DNB) 于1841年成立， 是世界著名的**商业信息服务机构**。 总部设在 新泽西州 的Short Hills 。 在其170多年的发展历程中，邓白氏公司通过技术创新，不断开拓信用评估市场。

http://192.168.1.14:5000/d/f/xLh8HKpoPt2ZOoIBGCAGGKJAMhXvq3mO



## 查询公司信息（Typeahead ）

通过查询参数如名称、地址、邮编等，帮助用户了解公司是否有信用风险。查询参数中，radiusDistance和radiusUnit定义了查询的半径范围，candidateMaximumQuantity则限制了返回结果的数量。在返回的Response中，transactionDetail包含了业务id、时间、语言和服务版本等信息，而searchCandidates则提供了组织的详细信息，包括组织名称、DUNS码、财务状况和行业代码等。此外，还提供了基于组织关系的详细信息。通过这些信息，用户可以全面了解公司的信用风险情况。
综上所述，Typeahead公司通过提供全面的公司信息查询服务，帮助用户降低与潜在交易对象的信用风险。这些服务不仅覆盖了公司基本信息，还包括地理位置、财务状况和行业代码等详细信息。通过这些信息，用户可以更好地评估潜在交易对象的信用风险，从而做出更明智的决策。

http://192.168.1.14:5000/d/f/xLh8GFYsaWVnksDWDA5FEq6Awib8f2pj



## 集成 kkfile 生成 pdf 文件

创建了一个解决方案，用于生成固定格式的PDF文件。该方案首先制作规定格式的Word模板，然后使用poi-tl解析参数生成Word文件。接着，通过kkfile将Word文件转换为PDF，最后将文件流返回给调用方。kkfile仅提供Word转PDF功能，因此进行了二次开发，增加了poi-tl生成Word的功能，提供了对应的HTTP接口。制作Dockerfile应用采用分层构建的镜像，已上传到公司的镜像仓库进行构建与部署。

http://192.168.1.14:5000/d/f/xLh89uqq77LFhiV8Wbss3MIU2tdDC56N



## 项目了解

该项目管理库主要涉及CMS官网平台的搭建和配置。项目地址为http://www.rzdata.net:82/vzportal1.1。项目分为公司环境、31环境和生产环境，每个环境都有对应的后台和官网地址。配置包括IP地址和域名。美国官网一期原型和需求地址也已提供。后台地址在多个地方有提及，包括Modao和Figma。开发计划则在QQ文档中。此外，还有二期需求地址和相关配置的说明。项目涉及后台页面、官网页面和相关配置。流程和项目结构部分缺失。该项目的目的是搭建和配置CMS官网平台，为公司的运营和推广提供支持。通过不同环境下的配置，可以满足不同需求，并保证系统的稳定性和安全性。

http://192.168.1.14:5000/d/f/xLh8D9xdmZdVKd3FmBE91SbFa7g1apue



## 老版本-用户中心对外接口梳理

用户中心对外接口梳理文档主要涉及用户、员工和组织信息的查询服务。其中，获取用户信息接口通过传入用户ID查询用户信息，同时考虑用户权限和微信openId的限制。获取员工信息服务则根据员工ID查询员工信息，并提供员工列表查询和组织下所有员工信息查询功能。获取组织信息服务可根据组织ID查询组织信息，并支持组织列表查询和树型列表查询。此外，文档还涉及相关表结构说明。这些接口旨在提供全面、灵活的用户、员工和组织信息查询服务，以满足后台管理和查询需求。同时，为了保证安全性，这些接口仅支持后台调用，并参考服务网关JWT调用方式进行认证。通过这些接口的梳理，可以提高后台管理效率和数据准确性，为相关业务提供有力支持。

http://192.168.1.14:5000/d/f/xLh9OxWfEjMQsFyn1zRgaJT3Jrn48mmt



## 出国境



http://192.168.1.14:5000/d/f/xLh96qkKB6TdrKSWJ1227kCfsLTvPYqP



## 使用场景

在CPS沟通工具中，各种使用场景和角色之间的流程和权限关系得以清晰呈现。从采购问题咨询到跨部门领料咨询，每个场景都有相应的级别、发起角色、对接角色和分配规则。例如，物资计划员可以发起采购问题咨询，并与采购员进行沟通；生产工艺工程师可以向项目经理咨询转产SOP相关问题。在配制原料仓库管理员与不同角色的交互中，也明确了领料咨询、生产向研发领料、研发向生产领料等场景的分配规则。此外，不同角色拥有不同的权限，如项目经理拥有明示权限，而物资计划员、生产工艺工程师等则拥有暗示权限。这些角色权限的设置有助于确保流程的顺畅进行和信息的准确传递。通过这种详细的流程和权限设置，CPS沟通工具能够更好地支持跨部门、跨角色的协同工作，提高工作效率和信息传递的准确性。同时，这种工具也有助于减少沟通障碍和误解，增强团队协作能力。因此，对于需要高效、准确地进行信息传递和协同工作的团队来说，CPS沟通工具是一种非常实用的工具，能够大大提升团队的工作效率和协作能力。

http://192.168.1.14:5000/d/f/xLh8p6FUppqCt94xmDBe6onDVagsCmvU



## 系分文档

该文档描述了一个CPS沟通工具的创建背景、功能模块、项目架构等信息。该工具旨在解决明码和暗码人员之间的沟通问题，通过转码物料编码和名称，使双方能够理解。参与人员包括项目负责人、产品经理、工程师等。功能模块包括登录页面、工单列表、WebSocket连接等。项目架构涉及认证接口、登录接口、获取用户信息接口、角色接口、场景接口、工单接口、已读回执消息接口等。通过明暗码转换和消息分发等功能，实现用户之间的有效沟通。该工具对于提高CPS中的人员沟通效率和信息准确性具有重要意义。

http://192.168.1.14:5000/d/f/xLh8q3rG9SNFcGWK4BWwYhAsoVmkd7dT



## 详细设计

创建了CPS沟通工具的详细设计文档。该工具涉及前端调用后端，后端将请求转发到cps-admin。登录成功后，cps-admin返回token，再请求获取用户信息接口，将用户信息存入IM后端的会话，并将token返回给前端。工单分配根据是否配置规则进行操作，未配置规则则按角色分配，配置规则则按人员分配。发送消息时，前端存储占位符，后端进行明暗码转换并加密存储到message表，再通过WebSocket通知另一方前端刷新消息列表。数据库设计包括第三方接口、物料明转暗、物料暗转明等。该工具涉及登录、获取用户信息、工单分配和消息发送等功能，提供了一种有效的沟通方式。

http://192.168.1.14:5000/d/f/xLh8nfgeFblrlVZQ0d8C021JGN8ASzI1



## 工作量审核

创建了CPS沟通工具的详细设计文档。该工具涉及前端调用后端，后端将请求转发到cps-admin。登录成功后，cps-admin返回token，再请求获取用户信息接口，将用户信息存入IM后端的会话，并将token返回给前端。工单分配根据是否配置规则进行操作，未配置规则则按角色分配，配置规则则按人员分配。发送消息时，前端存储占位符，后端进行明暗码转换并加密存储到message表，再通过WebSocket通知另一方前端刷新消息列表。数据库设计包括第三方接口、物料明转暗、物料暗转明等。该工具涉及登录、获取用户信息、工单分配和消息发送等功能，提供了一种有效的沟通方式。

http://192.168.1.14:5000/d/f/xLh6Iu2lmCNGaXnaf5NtXLqbdhGQXecV



## 项目经理角色数据过滤

项目经理角色数据过滤，只可查看自己的项目管理。有A、B、C三个项目，甲有A、B权限，需屏蔽C项目信息。涉及工作日报、年报、月投入、工时统计、投入费用等页面，需过滤查询结果。改动点涉及下拉选择和查询接口过滤。

http://192.168.1.14:5000/d/f/xLh6IAlkWVl1DqTfnjsbp76dyReEtION



## 1、Bom

Bom编码管理，涉及物料编码、Bom数据库字段设计、留样管理数据库字段设计等，产码赋码无标签。

http://192.168.1.14:5000/d/f/xLh5jyflv3xoiNkgBLIZhzruhDGUWAss



## Bom管理

本文主要探讨了Bom管理的多个方面，包括概念、需求分析、流程设计、功能设计和数据库设计。Bom管理旨在解决多组合产品的标签打印需求，通过描述组合产品与子料的关联关系，实现高效管理。在流程设计方面，新增、编辑和审核功能确保了数据的准确性和完整性。功能设计则涵盖了Bom展示列表、新增、编辑和审核等部分，为用户提供便捷的操作体验。数据库设计方面，文章提到了数据库表pro_bom的设计，包括字段名称、字段属性和长度等信息。此外，文章还深入探讨了数据库表结构和相关API接口的设计，提供了两张表的字段信息以及五个API接口的详细信息。这些接口旨在提供更加灵活和高效的数据管理方式，满足不同场景下的需求。通过这些接口，用户可以方便地获取、添加、修改和删除Bom信息，同时也可以对Bom进行审核管理。这些设计对于提高数据处理效率和保证数据一致性具有重要意义。总之，本文对Bom管理的全面探讨为相关领域提供了有益的参考和指导，有助于推动Bom管理的进一步发展和应用。

http://192.168.1.14:5000/d/f/xLh5pBYUO9sg35uAMUJrRsECh7cJmwzu



## 业务日志管理

根据所提供的业务日志管理数据库设计表格，可以总结如下：该数据库表包含业务日志的详细信息，包括业务ID、业务类型、操作类型、操作详细信息、创建时间、创建用户ID和名称、租户ID等字段。其中，主键为ID字段，用于唯一标识每条记录。此外，该表还包含了一些数据类型和长度信息，以便进行数据存储和管理。整体而言，该表为业务日志管理提供了基础数据结构，为后续的数据处理和分析提供了基础。

http://192.168.1.14:5000/d/f/xLh5lH93IWMoKq8NT2LQlhYjr4jtX4tc



## 产码赋码

产码赋码系统，通过LinkedBlockingQueue队列进行数据组装，实现单线程生成码和单线程插入码的逻辑。该系统包括最小销售单元和其他包装层级的规则配置，其中最小销售单元可自定义添加/删除规则及编辑部分字段，修改后其他包装层级同步修改；其他包装层级仅能修改序列号的长度。系统的核心思路是通过队列实现数据的组装和生成码的逻辑，以满足实际业务需求。此外，系统还提供了详细的产码逻辑设计，包括PI规则配置页面和生成码的逻辑。整个系统设计合理、高效，能够满足大规模数据处理和生成码的需求，为实际业务提供稳定、可靠的支撑。

http://192.168.1.14:5000/d/f/xLh5kXs238bIruUR3oTOgX29Ef6QN1JA



## 包装层级关联（PDA）

包装层级关联（PDA）系统，旨在解决产品编码任务完成后不同层级之间码未关联的问题。该系统通过PDA扫码进行关联，实现产品关联查询、包装查询、出库控制和统计等功能。设计规则包括完成包装关联任务、组合产品子料关联、记录最小关联并激活产品、设置成品展示等。流程从PDA开始至完成关联任务。业务场景涉及包装任务列表展示、物码信息查询和建立子项物料码关系。接口设计包括包装列表展示、任务详情展示、单一物码查询、建立子项物料关系、完成包装任务、统计已装箱数量等。此系统简化了产品编码与关联流程，提高了管理效率和准确性。

http://192.168.1.14:5000/d/f/xLh5lpUW2PjygXgMOK7xUx5NB8Fl0JZb



## 标签管理

本文主要介绍了标签管理的需求分析、流程设计、数据库设计等方面。首先对标签信息进行管理，包括标签信息的补全、发布、绑定等操作，难点在于信息整合的复杂性。系统主要对Bom信息进行管理，支持产品的自由组合和配置。流程设计包括标签展示列表和新建标签字段等步骤。最后，给出了数据库设计的字段名称、字段类型、长度和备注等信息。通过对标签信息的全面管理，可以提高生产效率和产品质量，同时方便用户在web端直观地查看和维护标签信息。整个系统流程清晰，操作简便，具有很高的实用性和可扩展性。

http://192.168.1.14:5000/d/f/xLh5nLaXexKtyzgAMutyOVszfG1iYoIm



## 溯源管理

溯源管理功能主要包括两个接口：新增溯源操作日志接口和溯源操作物码查询接口。每个业务环节需要添加溯源日志，以物码为单位查询物码相关的溯源操作日志。数据库设计包含多个字段，如life_id、code_id、complete_code、task_id、product_task_id、material_code等。接口设计包括添加溯源日志接口和查询溯源日志接口，可用于在特定项目中追溯和查询溯源信息。综合以上信息，该溯源管理功能旨在提供完整的追溯链条，方便对产品进行全程追溯和管理，提高产品质量和可靠性。

http://192.168.1.14:5000/d/f/xLh5qOuzQMeYC7NqZABj0ejI1MCHQLFa



## 留样管理

本文探讨了留样管理的需求分析、流程设计、功能设计和数据库设计。留样管理旨在将部分产品作为样品留在公司，不对外销售，并对留样物品进行统计和记录。为确保留样信息的正确性，提出了扫码留样的解决方案，通过PDA完成任务并在管理系统中显示统计信息。功能设计包括留样管理、新增/修改、留样记录查询和PDA留样任务。数据库设计则详细列出了两个表：pro_retention_param和pro_retention_log，分别用于存储留样管理和留样记录的相关信息。
总结：本文全面探讨了留样管理的各个方面，从需求分析到流程设计、功能设计和数据库设计。通过扫码留样的解决方案，确保了留样信息的正确性。同时，详细的功能设计和数据库设计为实际操作提供了明确的指导。此方案有助于工厂或公司对留样产品进行高效管理，确保留样与真实产品一致，为生产UDI管理提供有力支持。

http://192.168.1.14:5000/d/f/xLh5mabvdCEDmETkIwrG1ifDmVnDhkMw



## 系统日志管理

系统日志管理数据库设计包含多个字段，如操作人ID、姓名、租户ID、路径地址、状态、请求时间等。为满足基本接口设计需求，应添加日志删除一条日志条件分页查询日志无标签等功能。该设计可帮助用户高效管理日志信息，提高系统稳定性和安全性。

http://192.168.1.14:5000/d/f/xLh5jPtuTyTWACrH6QV8mptJClIcZk0p



## 防伪管理

防伪管理功能设计基础规则包括记录每一次扫描的记录表、查询码的扫描次数、超过三次警报、三层list查询、基于电话号码和扫描人查询当前扫描次数、电话作为参数传入、IP地址获取和码信息从CodeInfo中取值。数据库设计字段包括id、code_id、complete_code、product_task_id、phone、address、ip等。接口设计包括分页查询防伪列表和防伪详情查询。整个设计旨在实现防伪管理的功能，保障产品的真实性和可靠性。

http://192.168.1.14:5000/d/f/xLh5nqxDXAvxo5HUpZvCfLd6jS9ZA7ra



## 需求扩展：多模板绑定

该文章主要讨论了多模板绑定接口的设计与实现，涉及到需求扩展、接口设计、数据库设计和原型设计等多个方面。首先，需求扩展中提到了查看模板绑定列表、选择模板页面列表查询、关联模板、解除模板、预览和更换按钮等需求。接着，接口设计部分详细列出了每个功能点的接口地址和相关说明。数据库设计部分则描述了物料编码唯一标识与模板关系表的字段名称、字段类型、长度、小数点和注释等信息。最后，原型设计部分描述了编码管理中的模板绑定和新建任务时的物料绑定模板与包装绑定模板的场景，并给出了相应的逻辑说明。
总结来说，该文章对多模板绑定接口的设计和实现进行了全面的探讨，从需求分析、接口设计、数据库设计和原型设计等多个方面进行了详细阐述。通过分析需求和场景，文章为读者提供了一个完整的解决方案，有助于更好地理解和实现多模板绑定接口的设计和开发。同时，文章还强调了接口设计中的关键点，如查看模板绑定列表、选择模板页面列表查询、关联模板、解除模板、预览和更换按钮等，这些关键点对于实现多模板绑定接口至关重要。数据库设计部分则提供了详细的表结构和字段说明，有助于读者更好地理解如何存储和管理模板绑定的相关数据。最后，原型设计部分通过描述具体场景和逻辑说明，为读者提供了一个完整的原型设计示例，有助于更好地理解和实现多模板绑定接口的设计和开发。

http://192.168.1.14:5000/d/f/xLh5oUh3kI7tW9c9KDjMDvrSZK4Z61w2



## 异步翻译 状态机

状态机是用于管理翻译流程中的不同状态的机制。根据表格中的信息，状态机有以下几种状态：正常、发生异常、中止和完成。在翻译过程中，状态机会根据不同的操作进行状态变更。例如，设置总进度和已完成进度，附加翻译内容和异常原因等。在完成翻译后，需要清空所有状态。状态判断是根据不同的状态采取不同的处理方式。例如，如果已完成进度为null，则表示已完成翻译，前端需要刷新页面。如果异常状态不为null，则表示发生异常，前端显示继续翻译按钮。如果总进度为null，则表示中止翻译，同样显示继续翻译按钮。其他状态则为进行中，前端需要轮询新的状态。总之，状态机是用于管理翻译流程的重要工具，能够根据不同的状态采取相应的处理方式。

http://192.168.1.14:5000/d/f/xLh5i8HQUg55H6BNbWyLAlBHfvLeE9Jc



## 文本翻译系分文档

数据库设计包括术语；文本翻译；文档管理、翻译；文档审核

http://192.168.1.14:5000/d/f/xLh5ijK4yBKhzN6mj9SZnyYdrpYDzseX



## 系统授权安全设计

生信智能分析平台采用了系统授权安全设计，以确保软件不被盗版。授权策略支持多种方式，包括按试用期、按使用次数以及试用期与使用次数混合。授权码管控范围包括可分析的应用和项目数量，以及试用期或使用次数达到额度后不能创建新项目的限制。授权实现逻辑基于VirboxLM的Runtime API，将核心授权数据存放在安全数据区。系统在执行项目分析时会先读取授权数据，判断是否授权失效，如果失效则不允许用户使用系统进行项目分析。此外，还提供了一个使用次数计数流程，用于更新内存中的授权信息并确保同一时刻只能有一个项目更新。这种设计有助于保护软件版权，并支持前端销售不同的销售策略。

http://192.168.1.14:5000/d/f/xLh97aIwYZSnsUbvGVPeypVqXFqtUjrC






> Written with [睿展知识库].
<!--stackedit_data:
eyJoaXN0b3J5IjpbMTY0OTcxMjU2Nl19
-->